package constant

const (
	// 设备类型
	DeviceTypeWeb = 1 // web

	// 权限端
	SystemTerminalAdmin = 1 // 管理后台
	SystemTerminalSale  = 2 // 业务员

	// 编号前缀
	NoPrefixContractConsignment    = "c1_" // 寄卖合同编号
	NoPrefixOrderConsignment       = ""    // 寄卖订单编号
	NoPrefixOrderDealerConsignment = ""    // 车商寄卖订单编号
	NoPrefixContractPurchase       = "c2_" // 收购合同编号
	NoPrefixOrderSale              = ""    // 出售订单编号
	NoPrefixContractSale           = "c3_" // 出售合同编号
	NoPrefixOrderAssess            = ""    // 充值订单编号
	NoPrefixOrderEstimatePay       = ""    // 付费估价编号
	NoPrefixOrderCallCar           = ""    // 叫车订单编号
	NoPrefixPaySn                  = ""    // 付款编号
	NoPrefixContractBroker         = ""    // 独立合伙人合同编号
	NoPrefixPayBroker              = ""    // 独立合伙人付款编号
	NoPrefixBrokerBusiness         = ""    // 入驻商编号
	NoPrefixBrokerBusinessStore    = ""    // 入驻商门店编号
	NoPrefixDealer                 = ""    // 车商编号
	NoPrefixBrokerCertify          = ""    // 实名认证编号
	NoPrefixCar                    = ""    // 车辆编号

	// 车辆类型
	CarBaseTypeSecondCarNormal = 1 // 二手车(中规)
	CarBaseTypeSecondCarImport = 2 // 二手车(平行进口)
	CarBaseTypeFirstCar        = 3 // 一手车
	CarBaseTypeNewCarNormal    = 4 // 新车(中规)
	CarBaseTypeNewCarImport    = 5 // 新车(平行进口)

	// 车辆使用性质
	CarBaseUseCharacterNonCommercial             = 1 // 非运营
	CarBaseUseCharacterCommercial                = 2 // 运营
	CarBaseUseCharacterCommercialToNonCommercial = 3 // 营转非
	CarBaseUseCharacterTenancyNonCommercial      = 4 // 租赁非运营
	CarBaseUseCharacterTenancyCommercial         = 5 // 租赁运营

	// 合同状态
	ContractStatusCreate         = 1  // 未签名
	ContractStatusSign           = 2  // 已签名
	ContractStatusReject         = 3  // 已拒签
	ContractStatusCancel         = 4  // 已撤回
	ContractStatusDeadline       = 5  // 已过期
	ContractStatusException      = 6  // 异常
	ContractStatusDealerAuditing = 11 // 车商审核中
	ContractStatusDealerAdopt    = 12 // 车商审核通过
	ContractStatusDealerReject   = 13 // 车商审核拒绝

	// 审核流程
	AuditStatusWaiting = 1 // 待审核
	AuditStatusAdopt   = 2 // 审核通过
	AuditStatusReject  = 3 // 审核拒绝

)

func GetContractStatusName(status uint) (result string) {
	switch status {
	case ContractStatusCreate:
		return "未签名"
	case ContractStatusSign:
		return "已签名"
	case ContractStatusReject:
		return "已拒签"
	case ContractStatusCancel:
		return "已撤回"
	case ContractStatusDeadline:
		return "已过期"
	case ContractStatusException:
		return "异常"
	case ContractStatusDealerAuditing:
		return "车商审核中"
	case ContractStatusDealerAdopt:
		return "车商审核通过"
	case ContractStatusDealerReject:
		return "车商审核拒绝"
	default:
		return "未知"
	}
}

func GetCarTypeName(tp uint) (result string) {
	switch tp {
	case CarBaseTypeSecondCarNormal:
		return "二手车(中规)"
	case CarBaseTypeSecondCarImport:
		return "二手车(平行进口)"
	case CarBaseTypeFirstCar:
		return "一手车"
	case CarBaseTypeNewCarNormal:
		return "新车(中规)"
	case CarBaseTypeNewCarImport:
		return " 新车(平行进口)"
	default:
		return "未知"
	}
}

func GetCarUseCharacterName(uc uint) (result string) {
	switch uc {
	case CarBaseUseCharacterNonCommercial:
		return "非运营"
	case CarBaseUseCharacterCommercial:
		return "运营"
	case CarBaseUseCharacterCommercialToNonCommercial:
		return "营转非"
	case CarBaseUseCharacterTenancyNonCommercial:
		return "租赁非运营"
	case CarBaseUseCharacterTenancyCommercial:
		return " 租赁运营"
	default:
		return "未知"
	}
}

func GetAuditStatusName(status uint) (result string) {
	switch status {
	case AuditStatusWaiting:
		return "待审核"
	case AuditStatusAdopt:
		return "审核通过"
	case AuditStatusReject:
		return "审核拒绝"
	default:
		return "未知"
	}
}
