package business

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/business"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Staff struct {
}

type argsStaffAll struct {
	business.StaffAllSearch
}

// All @Title 全部员工
func (s *Staff) All(c *gin.Context) {
	var args = argsStaffAll{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	bean.Response.ResultSuc(c, "操作成功", business.StaffLogic.All(user.UserLogic.GetBrokerInfo(c).BusinessId, args.StaffAllSearch))
}

// Add @Title 添加员工
func (s *Staff) Add(c *gin.Context) {
	args := business.StaffAddData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	staffInfo := user.UserLogic.GetStaffInfo(c)
	if err := business.StaffLogic.Add(staffInfo.RoleId, staffInfo.StoreId, staffInfo.BusinessId, args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsStaffInfo struct {
	StaffId uint `binding:"required" label:"员工"`
}

// Info @Title 员工详情
func (s *Staff) Info(c *gin.Context) {
	args := argsStaffInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := business.StaffLogic.Info(user.UserLogic.GetBrokerInfo(c).BusinessId, args.StaffId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

// Edit @Title 编辑员工
func (s *Staff) Edit(c *gin.Context) {
	args := business.StaffEdit{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := business.StaffLogic.Edit(user.UserLogic.GetBrokerInfo(c).BusinessId, args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsStaffDelete struct {
	StaffId uint `binding:"required" label:"员工"`
}

// Delete @Title 删除员工
func (s *Staff) Delete(c *gin.Context) {
	args := argsStaffDelete{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := business.StaffLogic.Delete(user.UserLogic.GetBrokerInfo(c).BusinessId, args.StaffId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
