package business

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/business"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Store struct {
}

type argsStructAll struct {
	business.StaffSearch
}

// StructAll @Title 获取组织架构
func (s *Store) StructAll(c *gin.Context) {
	var args = argsStructAll{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	bean.Response.ResultSuc(c, "操作成功", business.StoreLogic.StructAll(user.UserLogic.GetBrokerInfo(c).BusinessId, args.StaffSearch))
}

type argsStoreAll struct {
	business.StoreSearch
}

// All @Title 全部门店
func (s *Store) All(c *gin.Context) {
	var args = argsStoreAll{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	bean.Response.ResultSuc(c, "操作成功", business.StoreLogic.All(user.UserLogic.GetBrokerInfo(c).BusinessId, args.StoreSearch))
}

// Add @Title 添加门店
func (s *Store) Add(c *gin.Context) {
	args := business.StoreAddData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	if err := business.StoreLogic.Add(brokerInfo.Level, brokerInfo.BusinessId, args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Select @Title 门店筛选
func (s *Store) Select(c *gin.Context) {
	bean.Response.ResultSuc(c, "操作成功", business.StoreLogic.Select(user.UserLogic.GetBrokerInfo(c).BusinessId))
}
