package car

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/car"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Base struct {
}

// Publish @Title 申请发布车辆
func (*Base) Publish(c *gin.Context) {
	args := car.PublishData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	staffInfo := user.UserLogic.GetStaffInfo(c)
	if err := car.BaseLogic.Publish(staffInfo.BrokerId, staffInfo.RoleId, staffInfo.StoreId, args); err != nil {
		bean.Response.ResultFail(c, 10001, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCarBaseBrokerLists struct {
	car.CarBaseSearch
	car.CarBaseBrokerSearch
	bean.Page
}

// Lists @Title 发布列表
func (b *Base) Lists(c *gin.Context) {
	args := argsCarBaseBrokerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.BaseLogic.BrokerLists(user.UserLogic.GetBrokerId(c), args.CarBaseSearch, args.CarBaseBrokerSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCarBaseDealerLists struct {
	car.CarBaseSearch
	car.CarBaseDealerSearch
	bean.Page
}

// DealerLists @Title 车商审批车辆发布列表
func (b *Base) DealerLists(c *gin.Context) {
	args := argsCarBaseDealerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.BaseLogic.DealerLists(user.UserLogic.GetStaffInfo(c).StoreId, args.CarBaseSearch, args.CarBaseDealerSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCarBaseInfo struct {
	CarBaseId uint `binding:"required" label:"车辆发布id"`
}

// Info @Title 详情
func (b *Base) Info(c *gin.Context) {
	args := argsCarBaseInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := car.BaseLogic.Info(args.CarBaseId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsCarBaseAdopt struct {
	CarBaseId uint `binding:"required" label:"车辆发布id"`
}

// Adopt @Title 审核通过
func (b *Base) Adopt(c *gin.Context) {
	args := argsCarBaseAdopt{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.BaseLogic.Audit(user.UserLogic.GetStaffInfo(c).StoreId, args.CarBaseId, 1, ""); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCarBaseReject struct {
	CarBaseId uint   `binding:"required" label:"车辆发布id"`
	Reason    string `binding:"required" label:"驳回理由"`
}

// Reject @Title 审核驳回
func (b *Base) Reject(c *gin.Context) {
	args := argsCarBaseReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.BaseLogic.Audit(user.UserLogic.GetStaffInfo(c).StoreId, args.CarBaseId, 2, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
