package car

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/car"
	"base/app/logic/broker/user"
	car2 "base/app/logic/car"
	"github.com/gin-gonic/gin"
)

type Car struct {
}
type argsCarLists struct {
	//Search car2.CarSearch
	Search car.CarSelfSearch
	car2.CarOrder
	bean.Page
}

// Lists @Title 车辆列表
func (*Car) Lists(c *gin.Context) {
	args := argsCarLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.CarLogic.Lists(user.UserLogic.GetBrokerId(c), args.Search, args.CarOrder, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCarSelf struct {
	Search car.CarSelfSearch
	car2.CarOrder
	bean.Page
}

// Self @Title 我的车辆列表
func (*Car) Self(c *gin.Context) {
	args := argsCarSelf{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	lists, total := car.CarLogic.Self(brokerInfo.Id, brokerInfo.BusinessId, brokerInfo.StoreId, args.Search, args.CarOrder, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// CarCount @Title 车辆统计
func (*Car) CarCount(c *gin.Context) {
	bean.Response.ResultSuc(c, "操作成功", car.CarLogic.CarCount())
}

// SelfCount @Title 我的车辆统计
func (*Car) SelfCount(c *gin.Context) {
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	bean.Response.ResultSuc(c, "操作成功", car.CarLogic.SelfCount(brokerInfo.Id, brokerInfo.StoreId, brokerInfo.BusinessId))
}

type argsCarInfo struct {
	CarId uint `binding:"required" label:"车辆"`
}

// Info @Title 车辆详情
func (*Car) Info(c *gin.Context) {
	args := argsCarInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	result, err := car.CarLogic.Info(brokerInfo.Id, brokerInfo.Level, args.CarId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsCarParameter struct {
	CarId uint `binding:"required" label:"车辆"`
}

// Parameter @Title 车辆参数
func (*Car) Parameter(c *gin.Context) {
	args := argsCarParameter{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := car2.CarLogic.Parameter(args.CarId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsCarVin struct {
	Vin string `binding:"required" label:"vin码"`
}

// VinCheck @Title 验证vin合理性
func (*Car) VinCheck(c *gin.Context) {
	args := argsCarVin{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	bean.Response.ResultSuc(c, "操作成功", car2.CarLogic.VinCheck(args.Vin))
}

// AdjustPrice @Title 调价
func (*Car) AdjustPrice(c *gin.Context) {
	args := car.AdjustPriceData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.CarLogic.AdjustPrice(user.UserLogic.GetBrokerInfo(c).StoreId, user.UserLogic.GetBrokerId(c), args.CarId, args.InteriorPrice, args.ExteriorPrice); err != nil {
		bean.Response.ResultFail(c, 10001, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCarPriceHistory struct {
	CarId uint `binding:"required" label:"车辆"`
}

// PriceHistory @Title 价格历史（至多10次）
func (*Car) PriceHistory(c *gin.Context) {
	args := argsCarPriceHistory{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := car.CarLogic.PriceHistory(args.CarId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

// Upper @Title 申请上架车辆
func (*Car) Upper(c *gin.Context) {
	args := car.UpperDownData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info := user.UserLogic.GetBrokerInfo(c)
	if err := car.CarLogic.Upper(info.StoreId, info.Id, args); err != nil {
		bean.Response.ResultFail(c, 10001, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Down @Title 申请下架车辆
func (*Car) Down(c *gin.Context) {
	args := car.UpperDownData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info := user.UserLogic.GetBrokerInfo(c)
	if err := car.CarLogic.Down(info.StoreId, info.Id, args); err != nil {
		bean.Response.ResultFail(c, 10001, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
