package car

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/car"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Edit struct {
}

// Add @Title 申请编辑车辆
func (*Edit) Add(c *gin.Context) {
	args := car.CarEditAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	staffInfo := user.UserLogic.GetStaffInfo(c)
	if err := car.EditLogic.Add(staffInfo.BrokerId, staffInfo.StoreId, args); err != nil {
		bean.Response.ResultFail(c, 10001, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCarEditBrokerLists struct {
	car.CarEditSearch
	car.CarEditBrokerSearch
	bean.Page
}

// Lists @Title 经纪人编辑记录
func (e *Edit) Lists(c *gin.Context) {
	args := argsCarEditBrokerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.EditLogic.BrokerLists(user.UserLogic.GetBrokerId(c), args.CarEditSearch, args.CarEditBrokerSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCarEditDealerLists struct {
	car.CarEditSearch
	car.CarEditDealerSearch
	bean.Page
}

// DealerLists @Title 车商审批车辆编辑记录
func (e *Edit) DealerLists(c *gin.Context) {
	args := argsCarEditDealerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.EditLogic.DealerLists(user.UserLogic.GetStaffInfo(c).StoreId, args.CarEditSearch, args.CarEditDealerSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCarEditInfo struct {
	CarEditId uint `binding:"required" label:"车辆发布id"`
}

// Info @Title 详情
func (e *Edit) Info(c *gin.Context) {
	args := argsCarEditInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := car.EditLogic.Info(args.CarEditId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsCarEditAdopt struct {
	CarEditId uint `binding:"required" label:"车辆编辑id"`
}

// Adopt @Title 审核通过
func (e *Edit) Adopt(c *gin.Context) {
	args := argsCarEditAdopt{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.EditLogic.Audit(user.UserLogic.GetStaffInfo(c).StoreId, args.CarEditId, 1, ""); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCarEditReject struct {
	CarEditId uint   `binding:"required" label:"车辆编辑id"`
	Reason    string `binding:"required" label:"驳回理由"`
}

// Reject @Title 审核驳回
func (e *Edit) Reject(c *gin.Context) {
	args := argsCarEditReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.EditLogic.Audit(user.UserLogic.GetStaffInfo(c).StoreId, args.CarEditId, 2, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
