package car

import (
    "base/app/common"
    "base/app/lib/bean"
    "base/app/logic/broker/car"
    "base/app/logic/broker/user"
    car2 "base/app/logic/car"
    "github.com/gin-gonic/gin"
    "github.com/shopspring/decimal"
)

type Price struct {
}

// Estimate @Title 估算价格
func (p *Price) Estimate(c *gin.Context) {
    args := car.PriceEstimateData{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    result, err := car.PriceLogic.Estimate(user.UserLogic.GetBrokerId(c), args)
    if err != nil {
        bean.Response.ResultFail(c, 10002, err.Error())
        return
    }
    bean.Response.ResultSuc(c, "操作成功", result)
}

// FastEstimate @Title 快速估算价格
func (p *Price) FastEstimate(c *gin.Context) {
    args := car.FastEstimateData{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    result, err := car.PriceLogic.FastEstimate(user.UserLogic.GetBrokerId(c), args)
    if err != nil {
        bean.Response.ResultFail(c, 10002, err.Error())
        return
    }
    bean.Response.ResultSuc(c, "操作成功", result)
}

type argsPriceAmount struct {
    Amount decimal.Decimal
}

// Amount @Title 费用计算
func (p *Price) Amount(c *gin.Context) {
    args := argsPriceAmount{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    bean.Response.ResultSuc(c, "操作成功", car2.PriceLogic.Amount(args.Amount))
}

type argsPriceFastLists struct {
    car2.PriceFastListsSearch
    bean.Page
}

// FastLists @Title 快速估价列表
func (p *Price) FastLists(c *gin.Context) {
    args := argsPriceFastLists{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    lists, total := car2.PriceLogic.FastLists(user.UserLogic.GetBrokerId(c), args.PriceFastListsSearch, args.Page)
    bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
        List:  lists,
        Total: total,
    })
}

type argsPriceLists struct {
    car2.PriceListsSearch
    bean.Page
}

// Lists @Title 估价列表
func (p *Price) Lists(c *gin.Context) {
    args := argsPriceLists{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    lists, total := car2.PriceLogic.Lists(user.UserLogic.GetBrokerId(c), args.PriceListsSearch, args.Page)
    bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
        List:  lists,
        Total: total,
    })
}

type argsPriceInfo struct {
    PriceId uint `binding:"required" label:"估价id"`
}

// Info @Title 估价详情
func (p *Price) Info(c *gin.Context) {
    args := argsPriceInfo{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    brokerInfo := user.UserLogic.GetBrokerInfo(c)
    result, err := car2.PriceLogic.Info(brokerInfo.Id, args.PriceId)
    if err != nil {
        bean.Response.ResultFail(c, 10002, err.Error())
        return
    }
    bean.Response.ResultSuc(c, "操作成功", result)
}
