package contract

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/contract"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Consignment struct {
}

type argsConsignmentLists struct {
	contract.ConsignmentSearch
	bean.Page
}

// Lists @Title 寄卖合同列表
func (*Consignment) Lists(c *gin.Context) {
	args := argsConsignmentLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := contract.ConsignmentLogic.Lists(user.UserLogic.GetBrokerId(c), args.ConsignmentSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// Add @Title 添加合同
func (*Consignment) Add(c *gin.Context) {
	args := contract.ConsignmentAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := contract.ConsignmentLogic.Add(user.UserLogic.GetBrokerId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsConsignmentCancel struct {
	ContractId uint   `binding:"required" label:"寄售合同id"`
	Reason     string `binding:"required" label:"取消理由"`
}

// Cancel @Title 取消
func (*Consignment) Cancel(c *gin.Context) {
	args := argsConsignmentCancel{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := contract.ConsignmentLogic.Cancel(user.UserLogic.GetBrokerId(c), args.ContractId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
