package contract

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/contract"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Purchase struct {
}

type argsPurchaseBrokerLists struct {
	contract.PurchaseSearch
	contract.PurchaseBrokerSearch
	bean.Page
}

// Lists @Title 收购合同列表
func (*Purchase) Lists(c *gin.Context) {
	args := argsPurchaseBrokerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := contract.PurchaseLogic.BrokerLists(user.UserLogic.GetBrokerId(c), args.PurchaseSearch, args.PurchaseBrokerSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsPurchaseDealerLists struct {
	contract.PurchaseSearch
	contract.PurchaseDealerSearch
	bean.Page
}

// DealerLists @Title 车商审批收购合同列表
func (*Purchase) DealerLists(c *gin.Context) {
	args := argsPurchaseDealerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := contract.PurchaseLogic.DealerLists(user.UserLogic.GetStaffInfo(c).StoreId, args.PurchaseSearch, args.PurchaseDealerSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// Add @Title 添加收购合同
func (*Purchase) Add(c *gin.Context) {
	args := contract.PurchaseAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := contract.PurchaseLogic.Add(user.UserLogic.GetBrokerId(c), user.UserLogic.GetStaffInfo(c).BusinessId, user.UserLogic.GetStaffInfo(c).StoreId, args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsPurchaseInfo struct {
	ContractId uint `binding:"required" label:"收购合同id"`
}

// Info @Title 详情
func (*Purchase) Info(c *gin.Context) {
	args := argsPurchaseInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := contract.PurchaseLogic.Info(args.ContractId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsPurchaseAdopt struct {
	ContractId uint `binding:"required" label:"收购合同id"`
}

// Adopt @Title 审核通过
func (*Purchase) Adopt(c *gin.Context) {
	args := argsPurchaseAdopt{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := contract.PurchaseLogic.Audit(user.UserLogic.GetStaffInfo(c).StoreId, args.ContractId, 1, ""); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsPurchaseReject struct {
	ContractId uint   `binding:"required" label:"收购合同id"`
	Reason     string `binding:"required" label:"驳回理由"`
}

// Reject @Title 审核驳回
func (*Purchase) Reject(c *gin.Context) {
	args := argsPurchaseReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := contract.PurchaseLogic.Audit(user.UserLogic.GetStaffInfo(c).StoreId, args.ContractId, 2, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsPurchaseCancel struct {
	ContractId uint   `binding:"required" label:"收购合同id"`
	Reason     string `binding:"required" label:"取消理由"`
}

// Cancel @Title 取消
func (*Purchase) Cancel(c *gin.Context) {
	args := argsPurchaseCancel{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	staffInfo := user.UserLogic.GetStaffInfo(c)
	if err := contract.PurchaseLogic.Cancel(brokerInfo.Id, brokerInfo.StoreId, staffInfo.RoleId, args.ContractId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
