package contract

import (
    "base/app/common"
    "base/app/lib/bean"
    "base/app/logic/broker/contract"
    "base/app/logic/broker/user"
    "github.com/gin-gonic/gin"
)

type Sale struct {
}

type argsSaleLists struct {
    contract.SaleSearch
    contract.SaleBrokerSearch
    bean.Page
}

// Lists @Title 售车合同列表
func (s *Sale) Lists(c *gin.Context) {
    args := argsSaleLists{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    lists, total := contract.SaleLogic.BrokerLists(user.UserLogic.GetBrokerId(c), args.SaleSearch, args.SaleBrokerSearch, args.Page)
    bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
        List:  lists,
        Total: total,
    })
}

type argsSaleDealerLists struct {
    contract.SaleSearch
    contract.SaleDealerSearch
    bean.Page
}

// DealerLists @Title 车商审批售车合同列表
func (s *Sale) DealerLists(c *gin.Context) {
    args := argsSaleDealerLists{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    lists, total := contract.SaleLogic.DealerLists(user.UserLogic.GetStaffInfo(c).StoreId, args.SaleSearch, args.SaleDealerSearch, args.Page)
    bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
        List:  lists,
        Total: total,
    })
}

type argsSaleInfo struct {
    ContractId uint `binding:"required" label:"出售合同id"`
}

// Info @Title 详情
func (*Sale) Info(c *gin.Context) {
    args := argsSaleInfo{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    info, err := contract.SaleLogic.Info(args.ContractId)
    if err != nil {
        bean.Response.ResultFail(c, 10002, err.Error())
        return
    }
    bean.Response.ResultSuc(c, "操作成功", info)
}

// Add @Title 添加车辆售出合同
func (s *Sale) Add(c *gin.Context) {
    args := contract.SaleAdd{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    if err := contract.SaleLogic.Add(user.UserLogic.GetBrokerId(c), args); err != nil {
        bean.Response.ResultFail(c, 10002, err.Error())
        return
    }
    bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsSaleAdopt struct {
    ContractId uint `binding:"required" label:"出售合同id"`
}

// Adopt @Title 审核通过
func (*Sale) Adopt(c *gin.Context) {
    args := argsSaleAdopt{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    if err := contract.SaleLogic.Audit(user.UserLogic.GetStaffInfo(c).StoreId, args.ContractId, 1, ""); err != nil {
        bean.Response.ResultFail(c, 10002, err.Error())
        return
    }
    bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsSaleReject struct {
    ContractId uint   `binding:"required" label:"出售合同id"`
    Reason     string `binding:"required" label:"驳回理由"`
}

// Reject @Title 审核驳回
func (*Sale) Reject(c *gin.Context) {
    args := argsSaleReject{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    if err := contract.SaleLogic.Audit(user.UserLogic.GetStaffInfo(c).StoreId, args.ContractId, 2, args.Reason); err != nil {
        bean.Response.ResultFail(c, 10002, err.Error())
        return
    }
    bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsSaleCancel struct {
    ContractId uint   `binding:"required" label:"出售合同id"`
    Reason     string `binding:"required" label:"取消理由"`
}

// Cancel @Title 取消
func (*Sale) Cancel(c *gin.Context) {
    args := argsSaleCancel{}
    if err := c.ShouldBind(&args); err != nil {
        bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
        return
    }
    if err := contract.SaleLogic.Cancel(user.UserLogic.GetBrokerId(c), args.ContractId, args.Reason); err != nil {
        bean.Response.ResultFail(c, 10002, err.Error())
        return
    }
    bean.Response.ResultSuc(c, "操作成功", nil)
}
