package customer

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/customer"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Customer struct {
}
type argsCustomerLists struct {
	Search customer.CustomerSearch
	customer.CustomerOrder
	bean.Page
}

// Lists @Title 客户列表
func (*Customer) Lists(c *gin.Context) {
	args := argsCustomerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := customer.CustomerLogic.Lists([]uint{user.UserLogic.GetBrokerId(c)}, args.Search, args.CustomerOrder, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// Count @Title 客户统计
func (*Customer) Count(c *gin.Context) {
	bean.Response.ResultSuc(c, "操作成功", customer.CustomerLogic.Count([]uint{user.UserLogic.GetBrokerId(c)}))
}

type argsCustomerInfo struct {
	CustomerId uint `binding:"required" label:"客户"`
}

// Info @Title 客户详情
func (*Customer) Info(c *gin.Context) {
	args := argsCustomerInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := customer.CustomerLogic.Info([]uint{user.UserLogic.GetBrokerId(c)}, args.CustomerId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsCustomerImportant struct {
	CustomerIds []uint `binding:"required" label:"客户"`
}

// Important @Title 设为重要
func (*Customer) Important(c *gin.Context) {
	args := argsCustomerImportant{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := customer.CustomerLogic.Important([]uint{user.UserLogic.GetBrokerId(c)}, args.CustomerIds); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCustomerImportantCancel struct {
	CustomerIds []uint `binding:"required" label:"客户"`
}

// ImportantCancel @Title 取消重要
func (*Customer) ImportantCancel(c *gin.Context) {
	args := argsCustomerImportantCancel{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := customer.CustomerLogic.ImportantCancel([]uint{user.UserLogic.GetBrokerId(c)}, args.CustomerIds); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Select @Title 客户筛选
func (*Customer) Select(c *gin.Context) {
	bean.Response.ResultSuc(c, "操作成功", customer.CustomerLogic.Select([]uint{user.UserLogic.GetBrokerId(c)}))
}
