package broker

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker"
	user2 "base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Login struct {
}
type argsLoginLoginPhone struct {
	Token      string `binding:"required" label:"token"`
	InviteCode string
}

// LoginPhone @Title 手机号一键登录
func (l *Login) LoginPhone(c *gin.Context) {
	args := argsLoginLoginPhone{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := broker.LoginLogic.LoginPhone(args.Token, args.InviteCode)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsLoginWechat struct {
	Code string `binding:"required" label:"code"`
}

// LoginWechat @Title 微信登录
func (l *Login) LoginWechat(c *gin.Context) {
	args := argsLoginWechat{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := broker.LoginLogic.LoginWechat(args.Code)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsLoginApple struct {
	broker.LoginAppleData
}

// LoginApple @Title 苹果登录
func (l *Login) LoginApple(c *gin.Context) {
	args := argsLoginApple{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := broker.LoginLogic.LoginApple(args.LoginAppleData)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsLoginLoginPhoneCode struct {
	Phone string `binding:"required" label:"手机号"`
	Code  string `binding:"required" label:"验证码"`
}

// LoginPhoneCode @Title 验证码登录
func (l *Login) LoginPhoneCode(c *gin.Context) {
	args := argsLoginLoginPhoneCode{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := broker.LoginLogic.AutoCode(args.Phone, args.Code); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	info, err := broker.LoginLogic.LoginPhoneCode(args.Phone)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsLoginBind struct {
	Phone      string `binding:"required" label:"手机号"`
	Code       string `binding:"required" label:"验证码"`
	BindToken  string `binding:"required" label:"验证"`
	InviteCode string
}

// WechatBindBroker @Title 微信绑定账号
func (l *Login) WechatBindBroker(c *gin.Context) {
	args := argsLoginBind{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := broker.LoginLogic.AutoCode(args.Phone, args.Code); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	info, err := broker.LoginLogic.WechatBindBroker(args.Phone, args.BindToken, args.InviteCode)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

// AppleBindBroker @Title 微信绑定账号
func (l *Login) AppleBindBroker(c *gin.Context) {
	args := argsLoginBind{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := broker.LoginLogic.AutoCode(args.Phone, args.Code); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	info, err := broker.LoginLogic.AppleBindBroker(args.Phone, args.BindToken, args.InviteCode)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsLoginSms struct {
	Phone string `binding:"required" label:"手机号"`
}

// Sms @Title 发送短信
func (l *Login) Sms(c *gin.Context) {
	args := argsLoginSms{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := broker.LoginLogic.Sms(args.Phone); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Logout @Title 退出登录
func (l *Login) Logout(c *gin.Context) {
	userId := user2.UserLogic.GetBrokerId(c)
	if userId == 0 {
		bean.Response.ResultSuc(c, "退出成功", nil)
		return
	}
	broker.LoginLogic.Logout(userId)
	bean.Response.ResultSuc(c, "退出成功", nil)
}
