package order

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/order"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type CallCar struct {
}
type argsCallCarLists struct {
	order.CallCarSearch
	bean.Page
}

// Lists @Title 叫车订单列表
func (*CallCar) Lists(c *gin.Context) {
	args := argsCallCarLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := order.CallCarLogic.Lists(user.UserLogic.GetBrokerId(c), args.CallCarSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCallCarInfo struct {
	OrderId uint `binding:"required" label:"订单"`
}

// Info @Title 订单详情
func (CallCar) Info(c *gin.Context) {
	args := argsCallCarInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := order.CallCarLogic.Info(user.UserLogic.GetBrokerId(c), args.OrderId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

// Add @Title 添加叫车订单
func (*CallCar) Add(c *gin.Context) {
	args := order.CallCarAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.CallCarLogic.Add(user.UserLogic.GetBrokerId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCallCarFinal struct {
	OrderId uint `binding:"required" label:"订单"`
}

// Final @Title 交车完成
func (*CallCar) Final(c *gin.Context) {
	args := argsCallCarFinal{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.CallCarLogic.Final(user.UserLogic.GetBrokerId(c), args.OrderId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
