package order

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/order"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Consignment struct {
}
type argsConsignmentLists struct {
	order.ConsignmentListsSearch
	bean.Page
}

// Lists @Title 寄卖订单列表
func (*Consignment) Lists(c *gin.Context) {
	args := argsConsignmentLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := order.ConsignmentLogic.Lists([]uint{user.UserLogic.GetBrokerId(c)}, args.ConsignmentListsSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// BusinessLists @Title 入驻商订单列表
func (*Consignment) BusinessLists(c *gin.Context) {
	args := argsConsignmentLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := order.ConsignmentLogic.BusinessLists(user.UserLogic.GetBrokerId(c), args.ConsignmentListsSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsConsignmentInfo struct {
	OrderId uint `binding:"required" label:"订单"`
}

// Info @Title 车辆详情
func (*Consignment) Info(c *gin.Context) {
	args := argsConsignmentInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := order.ConsignmentLogic.Info([]uint{user.UserLogic.GetBrokerId(c)}, args.OrderId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsConsignmentInfoCar struct {
	OrderId uint `binding:"required" label:"订单"`
}

// InfoCar @Title 订单车辆详情
func (*Consignment) InfoCar(c *gin.Context) {
	args := argsConsignmentInfoCar{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := order.ConsignmentLogic.InfoCar([]uint{user.UserLogic.GetBrokerId(c)}, args.OrderId)
	if err != nil {
		bean.Response.ResultFail(c, 10001, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}
