package order

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/order"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type DealerConsignment struct {
}
type argsDealerConsignmentLists struct {
	order.DealerConsignmentSearch
	bean.Page
}

// Lists @Title 寄卖订单列表
func (d *DealerConsignment) Lists(c *gin.Context) {
	args := argsDealerConsignmentLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := order.DealerConsignmentLogic.Lists([]uint{user.UserLogic.GetBrokerId(c)}, args.DealerConsignmentSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsDealerConsignmentAdd struct {
	PriceId uint `binding:"required" label:"估价记录"`
	order.DealerConsignmentAdd
}

// Add @Title 添加车商寄卖订单
func (d *DealerConsignment) Add(c *gin.Context) {
	args := argsDealerConsignmentAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.DealerConsignmentLogic.Add(user.UserLogic.GetBrokerId(c), args.PriceId, args.DealerConsignmentAdd); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
