package order

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/order"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type Sale struct {
}

type argsSaleLists struct {
	order.SaleSearchLists
	bean.Page
}

// Lists @Title 售车订单
func (s *Sale) Lists(c *gin.Context) {
	args := argsSaleLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := order.SaleLogic.Lists([]uint{user.UserLogic.GetBrokerId(c)}, args.SaleSearchLists, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsSaleTestReport struct {
	OrderId uint   `binding:"required" label:"订单"`
	Report  string `binding:"required" label:"报告"`
}

// TestReport @Title 检车报告
func (s *Sale) TestReport(c *gin.Context) {
	args := argsSaleTestReport{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.SaleLogic.TestReport(user.UserLogic.GetBrokerId(c), args.OrderId, args.Report); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Transfer @Title 过户
func (s *Sale) Transfer(c *gin.Context) {
	args := order.SaleTransfer{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.SaleLogic.Transfer(user.UserLogic.GetBrokerId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// OfflineTransfer @Title 线下客户过户
func (s *Sale) OfflineTransfer(c *gin.Context) {
	args := order.OfflineTransferInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.SaleLogic.OfflineTransfer(user.UserLogic.GetBrokerId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsOfflineBalancePayment struct {
	OrderId uint   `binding:"required" label:"订单"`
	Proof   string `binding:"required" label:"尾款凭证"`
}

// OfflineBalancePayment @Title 线下订单上传尾款支付
func (s *Sale) OfflineBalancePayment(c *gin.Context) {
	args := argsOfflineBalancePayment{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.SaleLogic.OfflineBalancePayment(user.UserLogic.GetBrokerId(c), args.OrderId, args.Proof); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsSaleFinal struct {
	OrderId uint `binding:"required" label:"订单"`
}

// Final @Title 完结订单
func (s *Sale) Final(c *gin.Context) {
	args := argsSaleFinal{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.SaleLogic.Final(user.UserLogic.GetBrokerId(c), args.OrderId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsSaleInfo struct {
	OrderId uint `binding:"required" label:"订单"`
}

// Info @Title 订单详情
func (s *Sale) Info(c *gin.Context) {
	args := argsSaleInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := order.SaleLogic.Info([]uint{user.UserLogic.GetBrokerId(c)}, args.OrderId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}
