package split

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/split"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
	"github.com/shopspring/decimal"
)

type Account struct {
}

type argsAccountLists struct {
	Status uint `label:"状态"`
	bean.Page
}

// List @Title 列表
func (a *Account) List(c *gin.Context) {
	var args = argsAccountLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	list, total := split.AccountLogic.List(user.UserLogic.GetBrokerId(c), args.Status, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  list,
		Total: total,
	})
}

type argsCreateData struct {
	split.CreateData
}

// Create @Title 创建分账
func (a *Account) Create(c *gin.Context) {
	var args = argsCreateData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := split.AccountLogic.Create(user.UserLogic.GetBrokerId(c), args.CreateData); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsAddBill struct {
	split.BillData
}

// AddBill @Title 添加账单
func (a *Account) AddBill(c *gin.Context) {
	var args = argsAddBill{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := split.AccountLogic.AddBill(user.UserLogic.GetBrokerId(c), args.BillData); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}

	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsAccountInfo struct {
	AccountId uint `binding:"required" label:"分账id"`
}

// AccountInfo @Title 分账明细
func (a *Account) AccountInfo(c *gin.Context) {
	var args = argsAccountInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := split.AccountLogic.AccountInfo(args.AccountId, user.UserLogic.GetBrokerId(c))
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsEditName struct {
	Name      string `binding:"required" label:"名称"`
	AccountId uint   `binding:"required" label:"分账"`
}

// EditName @Title 	编辑名称
func (a *Account) EditName(c *gin.Context) {
	var args = argsEditName{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := split.AccountLogic.EditName(args.AccountId, user.UserLogic.GetBrokerId(c), args.Name); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
	}

	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsProfit struct {
}

// Profit @Title 利润统计
func (a *Account) Profit(c *gin.Context) {
	//var args = argsProfit{}
	//if err := c.ShouldBind(&args); err != nil {
	//	bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
	//	return
	//}
	result, err := split.AccountLogic.Profit(user.UserLogic.GetBrokerId(c))
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}

	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsFinish struct {
	AccountId uint            `binding:"required" label:"分账id"`
	Amount    decimal.Decimal `binding:"required" label:"金额"`
}

// Finish @Title 结束分账
func (a *Account) Finish(c *gin.Context) {
	var args = argsFinish{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := split.AccountLogic.Finish(user.UserLogic.GetBrokerId(c), args.AccountId, args.Amount); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
