package user

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/customer/user"
	"github.com/gin-gonic/gin"
)

type Car struct {
}

// All @Title 获取车辆
func (*Car) All(c *gin.Context) {
	bean.Response.ResultSuc(c, "操作成功", user.CarLogic.All(user.UserLogic.GetCustomerId(c)))
}

// Add @Title 添加车辆
func (*Car) Add(c *gin.Context) {
	args := user.CarAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := user.CarLogic.Add(user.UserLogic.GetCustomerId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCarEdit struct {
	CarId uint `binding:"required" label:"车辆"`
	user.CarAdd
}

// Edit @Title 编辑车辆
func (*Car) Edit(c *gin.Context) {
	args := argsCarEdit{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := user.CarLogic.Edit(user.UserLogic.GetCustomerId(c), args.CarId, args.CarAdd); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCarDelete struct {
	CarId uint `binding:"required" label:"车辆"`
}

// Delete @Title 删除车辆
func (*Car) Delete(c *gin.Context) {
	args := argsCarDelete{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := user.CarLogic.Delete(user.UserLogic.GetCustomerId(c), args.CarId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
