package user

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/user"
	"base/app/model"
	"github.com/gin-gonic/gin"
)

type Certify struct {
}

// Ali @Title 支付宝实名认证
func (*Certify) Ali(c *gin.Context) {
	args := user.CertifyData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	if brokerInfo.IsReal == model.BrokerIsRealTrue {
		bean.Response.ResultFail(c, 10002, "已实名认证")
		return
	}
	result, err := user.CertifyLogic.Ali(brokerInfo.Id, args)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsCertifyAliResult struct {
	CertifyId string `binding:"required" label:"认证"`
}

// AliResult @Title 获取支付宝实名认证结果
func (*Certify) AliResult(c *gin.Context) {
	args := argsCertifyAliResult{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := user.CertifyLogic.AliResult(user.UserLogic.GetBrokerId(c), args.CertifyId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}
