package user

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/user"
	"base/app/model"
	"github.com/gin-gonic/gin"
)

type Partner struct {
}

type argsPartnerOrderCreate struct {
	Kind uint `binding:"required,oneof=1 2" label:"业务类型"` // 1=加入 2=续费
}

// CreateOrder @Title 创建订单
func (p *Partner) CreateOrder(c *gin.Context) {
	args := argsPartnerOrderCreate{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	switch args.Kind {
	case model.OrderPartnerKindJoin:
		if brokerInfo.Level != model.BrokerLevelBase {
			bean.Response.ResultFail(c, 10002, "非基础经纪人用户")
			return
		}
	case model.OrderPartnerKindDelay:
		if brokerInfo.Level != model.BrokerLevelPartner {
			bean.Response.ResultFail(c, 10002, "非合伙人身份无法续费")
			return
		}
	}
	result, err := user.PartnerLogic.CreateOrder(brokerInfo.Id, args.Kind)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsPartnerContractSign struct {
	Sign string `binding:"required" label:"签名"`
}

// ContractSign @Title 合同签订
func (p *Partner) ContractSign(c *gin.Context) {
	args := argsPartnerContractSign{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	if brokerInfo.Level == model.BrokerLevelBusiness {
		bean.Response.ResultFail(c, 10002, "已加入入驻商")
		return
	}
	result, err := user.PartnerLogic.ContractSign(brokerInfo.Id, args.Sign)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsPartnerPay struct {
	OrderId uint
	PayType uint `binding:"required,oneof=1 2" label:"支付方式"` // 1=支付宝 2=微信
}

// Pay @Title app支付
func (p *Partner) Pay(c *gin.Context) {
	args := argsPartnerPay{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	var payType uint
	switch args.PayType {
	case 1:
		payType = model.PayTypeAli
	case 2:
		payType = model.PayTypeWx
	}
	result, err := user.PartnerLogic.Pay(user.UserLogic.GetBrokerId(c), args.OrderId, payType)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsOrderPartner struct {
	OrderId uint
}

// OrderInfo @Title 订单详情
func (p *Partner) OrderInfo(c *gin.Context) {
	args := argsOrderPartner{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := user.PartnerLogic.OrderInfo(user.UserLogic.GetBrokerId(c), args.OrderId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}
