package user

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/user"
	"github.com/gin-gonic/gin"
)

type User struct {
}

type argsBrokerAll struct {
	user.BrokerAllSearch
}

// All @Title 全部经纪人
func (u *User) All(c *gin.Context) {
	var args = argsBrokerAll{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	bean.Response.ResultSuc(c, "操作成功", user.UserLogic.AllBroker(args.BrokerAllSearch))
}

type argsSearch struct {
	Phone string `binding:"required" label:"手机号"`
}

// Search @Title 搜索经纪人
func (u *User) Search(c *gin.Context) {
	args := argsSearch{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := user.UserLogic.Search(args.Phone)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

// Info @Title 用户详情
func (u *User) Info(c *gin.Context) {
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	bean.Response.ResultSuc(c, "操作成功", user.UserLogic.Info(&brokerInfo))
}

// Update @Title 更新用户信息
func (u *User) Update(c *gin.Context) {
	args := user.UserUpdate{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := user.UserLogic.Update(user.UserLogic.GetBrokerId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsLogoutPhoneCode struct {
	Code string `binding:"required" label:"验证码"`
}

// Logoff @Title 注销
func (u *User) Logoff(c *gin.Context) {
	args := argsLogoutPhoneCode{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	brokerInfo := user.UserLogic.GetBrokerInfo(c)
	if err := user.UserLogic.Logoff(&brokerInfo, args.Code); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
