package wallet

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/broker/user"
	"base/app/logic/broker/user/wallet"
	"github.com/gin-gonic/gin"
)

type Assess struct {
}

type argsAssessCount struct {
	Kind uint `binding:"required,oneof=1 2" label:"余量种类(1=评估;2=合同)"`
}

// Count @Title 获取剩余评估次数
func (a *Assess) Count(c *gin.Context) {
	args := argsAssessCount{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	bean.Response.ResultSuc(c, "操作成功", gin.H{
		"count": wallet.AssessLogic.Count(user.UserLogic.GetBrokerInfo(c), args.Kind),
	})
}

type argsAssessRecharge struct {
	Count   uint `binding:"required" label:"充值次数"`
	PayType uint `binding:"required" label:"付款类型"`
	Kind    uint `binding:"required,oneof=1 2" label:"余量种类(1=评估;2=合同)"`
}

// Recharge @Title 充值
func (a *Assess) Recharge(c *gin.Context) {
	args := argsAssessRecharge{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := wallet.AssessLogic.Recharge(user.UserLogic.GetBrokerInfo(c), args.Count, args.PayType, args.Kind)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", gin.H{
		"content": result,
	})
}

type argsAssessHistory struct {
	wallet.AssessHistorySearch
	bean.Page
}

// History @Title 评估记录列表
func (a *Assess) History(c *gin.Context) {
	args := argsAssessHistory{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := wallet.AssessLogic.History(user.UserLogic.GetBrokerInfo(c), args.AssessHistorySearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}
