package callback

import (
	"base/app/common"
	pay2 "base/app/logic/pay"
	"git.oa00.com/go/logger"
	"git.oa00.com/go/pay"
	"github.com/gin-gonic/gin"
	"github.com/smartwalle/alipay/v3"
	"go.uber.org/zap"
)

type Alipay struct {
}

// Notify @Title 回调
func (a *Alipay) Notify(c *gin.Context) {
	body, _ := common.GetRequestBody(c.Request)
	logger.Logger.Info("支付宝付款回调", zap.Any("body", body))
	notify, err := pay.Alipay.GetTradeNotification(c.Request)
	if err != nil {
		logger.Logger.Error("支付宝付款回调错误", zap.Any("notify", notify), zap.Error(err))
		return
	}
	if notify.TradeStatus == alipay.TradeStatusSuccess {
		// 付款成功
		if err := pay2.PayLogic.Success(notify.OutTradeNo, notify.GmtPayment); err != nil {
			logger.Logger.Error("支付宝付款回调错误", zap.Any("notify", notify), zap.Error(err))
			return
		}
	}
	if notify.TradeStatus == alipay.TradeStatusClosed {
		// 付款超时或退款
		if err := pay2.PayLogic.Fail(notify.OutTradeNo); err != nil {
			logger.Logger.Error("支付宝付款回调错误", zap.Any("notify", notify), zap.Error(err))
			return
		}
	}
	alipay.AckNotification(c.Writer)
}
