package callback

import (
	"base/app/common"
	pay2 "base/app/logic/pay"
	"context"
	"git.oa00.com/go/logger"
	"git.oa00.com/go/pay"
	"github.com/gin-gonic/gin"
	"github.com/wechatpay-apiv3/wechatpay-go/services/payments"
	"go.uber.org/zap"
	"time"
)

type Wxpay struct {
}

// Notify @Title 回调
func (w *Wxpay) Notify(c *gin.Context) {
	body, _ := common.GetRequestBody(c.Request)
	logger.Logger.Info("微信付款回调", zap.Any("body", body))
	transaction := new(payments.Transaction)
	notify, err := pay.Wxpay.Handler.ParseNotifyRequest(context.Background(), c.Request, &transaction)
	if err != nil {
		logger.Logger.Error("微信付款回调错误", zap.Any("notify", notify), zap.Any("transaction", transaction), zap.Error(err))
		return
	}
	logger.Logger.Info("回调", zap.Any("notify", notify))
	logger.Logger.Info("回调", zap.Any("transaction", transaction))
	switch notify.Resource.OriginalType {
	case "transaction": // 支付通知
		switch *transaction.TradeState {
		case "SUCCESS": // 付款成功
			location, _ := time.ParseInLocation("2006-01-02T15:04:05-07:00", *transaction.SuccessTime, time.Local)
			if err := pay2.PayLogic.Success(*transaction.OutTradeNo, location.Format("2006-01-02 15:04:05")); err != nil {
				logger.Logger.Error("微信付款回调错误", zap.Any("notify", notify), zap.Any("transaction", transaction), zap.Error(err))
				return
			}
		}
	case "refund": // 退款通知
		location, _ := time.ParseInLocation("2006-01-02T15:04:05-07:00", *transaction.SuccessTime, time.Local)
		if err := pay2.PayLogic.RefundSuccess(*transaction.OutTradeNo, location.Format("2006-01-02 15:04:05")); err != nil {
			logger.Logger.Error("微信付款回调错误", zap.Any("notify", notify), zap.Any("transaction", transaction), zap.Error(err))
			return
		}
	}
}
