package car

import (
	"base/app/common"
	"base/app/lib/bean"
	car2 "base/app/logic/car"
	"base/app/logic/customer/car"
	"base/app/logic/customer/user"
	"github.com/gin-gonic/gin"
)

type Car struct {
}
type argsCarLists struct {
	Search car2.CarSearch
	car2.CarOrder
	bean.Page
}

// Lists @Title 车辆列表
func (*Car) Lists(c *gin.Context) {
	args := argsCarLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.CarLogic.Lists(user.UserLogic.GetCustomerId(c), args.Search, args.CarOrder, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCarInfo struct {
	CarId      uint `binding:"required" label:"车辆"`
	InviteCode string
}

// Info @Title 车辆详情
func (*Car) Info(c *gin.Context) {
	args := argsCarInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := car.CarLogic.Info(user.UserLogic.GetCustomerId(c), args.CarId, args.InviteCode)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsCarParameter struct {
	CarId uint `binding:"required" label:"车辆"`
}

// Parameter @Title 车辆参数
func (*Car) Parameter(c *gin.Context) {
	args := argsCarParameter{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := car2.CarLogic.Parameter(args.CarId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}
