package car

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/customer/car"
	"base/app/logic/customer/user"
	"github.com/gin-gonic/gin"
)

type Collect struct {
}

// Lists @Title 收藏列表
func (*Collect) Lists(c *gin.Context) {
	args := bean.Page{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.CollectLogic.Lists(user.UserLogic.GetCustomerId(c), args)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCollectAdd struct {
	CarId uint `binding:"required" label:"车辆"`
}

// Add @Title 收藏车辆
func (*Collect) Add(c *gin.Context) {
	args := argsCollectAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.CollectLogic.Add(user.UserLogic.GetCustomerId(c), args.CarId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCollectCancel struct {
	CarId uint `binding:"required" label:"车辆"`
}

// Cancel @Title 取消收藏车辆
func (*Collect) Cancel(c *gin.Context) {
	args := argsCollectCancel{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.CollectLogic.Cancel(user.UserLogic.GetCustomerId(c), args.CarId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
