package car

import (
	"base/app/common"
	"base/app/lib/bean"
	car2 "base/app/logic/car"
	"base/app/logic/customer/car"
	"base/app/logic/customer/user"
	"github.com/gin-gonic/gin"
)

type Price struct {
}

type argsPriceLists struct {
	bean.Page
}

// List @Title 估算价格记录
func (p *Price) List(c *gin.Context) {
	args := argsPriceLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.PriceLogic.List(user.UserLogic.GetCustomerId(c), args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCarPriceId struct {
	CarPriceId uint `binding:"required" label:"估价id"`
}

// Info @Title 估算价格详情
func (p *Price) Info(c *gin.Context) {
	args := argsCarPriceId{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := car.PriceLogic.Info(user.UserLogic.GetCustomerId(c), args.CarPriceId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

// Result @Title 查询估算价格结果
func (p *Price) Result(c *gin.Context) {
	args := argsCarPriceId{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := car.PriceLogic.Result(user.UserLogic.GetCustomerId(c), args.CarPriceId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

// EstimatePay @Title 付费估价
func (p *Price) EstimatePay(c *gin.Context) {
	args := car2.EstimateData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	customerInfo := user.UserLogic.GetCustomerInfo(c)
	result, err := car.PriceLogic.EstimatePay(customerInfo.Id, customerInfo.OpenId, args)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", gin.H{
		"content": result,
	})
}

// Estimate @Title 估算价格
func (p *Price) Estimate(c *gin.Context) {
	args := car2.EstimateData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := car.PriceLogic.Estimate(user.UserLogic.GetCustomerId(c), args)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}
