package customer

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/customer"
	"base/app/logic/customer/user"
	"github.com/gin-gonic/gin"
)

type Login struct {
}
type argsLogin struct {
	Code       string `binding:"required" label:"code"`
	InviteCode string
}

// Login @Title 登录
func (l *Login) Login(c *gin.Context) {
	args := argsLogin{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	login, err := customer.LoginLogic.Login(args.Code)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "登录成功", &login)
}

// Register @Title 注册绑定
func (l *Login) Register(c *gin.Context) {
	args := customer.RegisterData{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	login, err := customer.LoginLogic.Register(args)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "登录成功", &login)
}

type argsLogoutWXCode struct {
	Code string `binding:"required" label:"loginCode"`
}

// Logoff @Title 注销
func (l *Login) Logoff(c *gin.Context) {
	args := argsLogoutWXCode{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	userInfo := user.UserLogic.GetCustomerInfo(c)
	if err := customer.LoginLogic.Logoff(&userInfo, args.Code); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
