package message

import (
	"base/app/common"
	"base/app/lib/bean"
	websocket2 "base/app/lib/websocket"
	"base/app/logic/customer/message"
	"base/app/logic/customer/user"
	"fmt"
	"git.oa00.com/go/logger"
	"github.com/gin-gonic/gin"
	"github.com/gorilla/websocket"
	uuid "github.com/satori/go.uuid"
	"net/http"
)

type Message struct {
}

// Message @Title 消息websocket
func (m *Message) Message(c *gin.Context) {
	// 升级http为websocket
	upGrader := websocket.Upgrader{
		// cross origin domain
		CheckOrigin: func(r *http.Request) bool {
			return true
		},
		// 处理 Sec-WebSocket-Protocol Header
		Subprotocols: []string{c.GetHeader("Sec-WebSocket-Protocol")},
	}
	conn, err := upGrader.Upgrade(c.Writer, c.Request, nil)
	if err != nil {
		logger.Logger.Error(fmt.Sprintf("websocket connect error: %s", err))
		return
	}

	logger.Logger.Info(fmt.Sprintf("customer register begin"))

	// 注册客户端
	client := &websocket2.Client{
		Id:      uuid.NewV4().String(),
		Group:   fmt.Sprintf(websocket2.CustomerKey, user.UserLogic.GetCustomerId(c)),
		Socket:  conn,
		Message: make(chan []byte, 1024),
	}
	websocket2.WebsocketManager.RegisterClient(client, func(messageType int, message []byte) {
		// 处理客户端消息
		if string(message) == "ping" {
			//写入ws数据
			client.Message <- []byte("pong")
			return
		}
	})
}

type argsMessageLists struct {
	Type uint `binding:"oneof=0 1 2 3 4" label:"消息类型"` // 1=常规消息 2=合同提示 3=订单提示 4=邀约提示
	bean.Page
}

// Lists @Title 消息列表
func (m *Message) Lists(c *gin.Context) {
	args := argsMessageLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := message.MessageLogic.Lists([]uint{user.UserLogic.GetCustomerId(c)}, args.Type, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// Count @Title 未读消息统计
func (m *Message) Count(c *gin.Context) {
	bean.Response.ResultSuc(c, "操作成功", message.MessageLogic.Count([]uint{user.UserLogic.GetCustomerId(c)}))
}

type argsMessageInfo struct {
	MessageId uint `binding:"required" label:"消息"`
}

// Info @Title 消息详情
func (m *Message) Info(c *gin.Context) {
	args := argsMessageInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := message.MessageLogic.Info([]uint{user.UserLogic.GetCustomerId(c)}, args.MessageId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsMessageItem struct {
	Title   string
	Content string
	Extras  map[string]interface{}
}

func (m *Message) TestSend(c *gin.Context) {
	var args = argsMessageItem{}

	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	message.MessageLogic.TestSend([]uint{user.UserLogic.GetCustomerId(c)}, message.MessageItem{
		Title:   args.Title,
		Content: args.Content,
	})
	bean.Response.ResultSuc(c, "操作成功", nil)
}
