package user

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/customer/user"
	"github.com/gin-gonic/gin"
)

type Broker struct {
}

type argsSearch struct {
	Phone string `binding:"required" label:"手机号"`
}

// Info @Title 获取用户经纪人信息
func (b *Broker) Info(c *gin.Context) {
	customerInfo := user.UserLogic.GetCustomerInfo(c)
	info, err := user.BrokerLogic.Info(customerInfo.BrokerId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

// Change @Title 提交更换经纪人申请
func (b *Broker) Change(c *gin.Context) {
	args := user.BrokerChange{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	customerInfo := user.UserLogic.GetCustomerInfo(c)
	if err := user.BrokerLogic.Change(customerInfo.Id, customerInfo.BrokerId, args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Search @Title 搜索经纪人
func (b *Broker) Search(c *gin.Context) {
	args := argsSearch{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := user.BrokerLogic.Search(args.Phone)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}
