package user

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/customer/user"
	"github.com/gin-gonic/gin"
)

type Center struct {
}

// Info @Title 用户详情
func (*Center) Info(c *gin.Context) {
	customerInfo := user.UserLogic.GetCustomerInfo(c)
	bean.Response.ResultSuc(c, "操作成功", user.CenterLogic.Info(&customerInfo))
}

// RealInfo @Title 实名认证信息
func (*Center) RealInfo(c *gin.Context) {
	customerInfo := user.UserLogic.GetCustomerInfo(c)
	info, err := user.CenterLogic.RealInfo(customerInfo.Id)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

// RealName @Title 实名认证
func (*Center) RealName(c *gin.Context) {
	args := user.RealNameInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	customerInfo := user.UserLogic.GetCustomerInfo(c)
	if err := user.CenterLogic.RealName(customerInfo.Id, args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsLogoutPhoneCode struct {
	Code string `binding:"required" label:"验证码"`
}

// Logoff @Title 注销
func (*Center) Logoff(c *gin.Context) {
	args := argsLogoutPhoneCode{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	customerInfo := user.UserLogic.GetCustomerInfo(c)
	if err := user.CenterLogic.Logoff(&customerInfo, args.Code); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
