package wallet

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/customer/user"
	"base/app/logic/customer/user/wallet"
	"github.com/gin-gonic/gin"
)

type Assess struct {
}

// Count @Title 获取剩余评估次数
func (a *Assess) Count(c *gin.Context) {
	bean.Response.ResultSuc(c, "操作成功", gin.H{
		"count": wallet.AssessLogic.Count(user.UserLogic.GetCustomerId(c)),
	})
}

type argsAssessRecharge struct {
	Count uint `binding:"required" label:"充值次数"`
}

// Recharge @Title 充值
func (a *Assess) Recharge(c *gin.Context) {
	args := argsAssessRecharge{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	customerInfo := user.UserLogic.GetCustomerInfo(c)
	result, err := wallet.AssessLogic.Recharge(customerInfo.Id, args.Count, customerInfo.OpenId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", gin.H{
		"content": result,
	})
}

type argsAssessHistory struct {
	wallet.AssessHistorySearch
	bean.Page
}

// History @Title 评估记录列表
func (a *Assess) History(c *gin.Context) {
	args := argsAssessHistory{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := wallet.AssessLogic.History(user.UserLogic.GetCustomerId(c), args.AssessHistorySearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}
