package app

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/app"
	"github.com/gin-gonic/gin"
)

type Feedback struct {
}
type argsFeedbackLists struct {
	app.FeedbackSearch
	bean.Page
}

// Lists @Title 意见列表
func (f *Feedback) Lists(c *gin.Context) {
	args := argsFeedbackLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := app.FeedbackLogic.Lists(args.FeedbackSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsFeedbackInfo struct {
	FeedbackId uint `binding:"required" label:"意见"`
}

// Info @Title 详情
func (f *Feedback) Info(c *gin.Context) {
	args := argsFeedbackInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := app.FeedbackLogic.Info(args.FeedbackId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsFeedbackDelete struct {
	FeedbackId uint `binding:"required" label:"意见"`
}

// Delete @Title 删除意见
func (f *Feedback) Delete(c *gin.Context) {
	args := argsFeedbackDelete{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := app.FeedbackLogic.Delete(args.FeedbackId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
