package broker

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/banner/broker"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type App struct {
}
type argsAppLists struct {
	broker.AppListsSearch
	bean.Page
}

// Lists @Title 经纪人app轮播图列表
func (a *App) Lists(c *gin.Context) {
	args := argsAppLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := broker.AppLogic.Lists(args.AppListsSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// Add @Title 添加轮播图
func (a *App) Add(c *gin.Context) {
	args := broker.AppAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := broker.AppLogic.Add(user.ManageLogic.GetManageId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
}

type argsAppInfo struct {
	BannerId uint `binding:"required" label:"轮播图"`
}

// Info @Title 轮播图详情
func (a *App) Info(c *gin.Context) {
	args := argsAppInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := broker.AppLogic.Info(args.BannerId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsAppEdit struct {
	BannerId uint `binding:"required" label:"轮播图"`
	broker.AppAdd
}

// Edit @Title 轮播图编辑
func (a *App) Edit(c *gin.Context) {
	args := argsAppEdit{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := broker.AppLogic.Edit(args.BannerId, args.AppAdd); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
