package customer

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/banner/customer"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type Wxapp struct {
}
type argsWxappLists struct {
	customer.WxappListsSearch
	bean.Page
}

// Lists @Title 客户wxapp轮播图列表
func (a *Wxapp) Lists(c *gin.Context) {
	args := argsWxappLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := customer.WxappLogic.Lists(args.WxappListsSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// Add @Title 添加轮播图
func (a *Wxapp) Add(c *gin.Context) {
	args := customer.WxappAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := customer.WxappLogic.Add(user.ManageLogic.GetManageId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsWxappInfo struct {
	BannerId uint `binding:"required" label:"轮播图"`
}

// Info @Title 轮播图详情
func (a *Wxapp) Info(c *gin.Context) {
	args := argsWxappInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := customer.WxappLogic.Info(args.BannerId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsWxappEdit struct {
	BannerId uint `binding:"required" label:"轮播图"`
	customer.WxappAdd
}

// Edit @Title 轮播图编辑
func (a *Wxapp) Edit(c *gin.Context) {
	args := argsWxappEdit{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := customer.WxappLogic.Edit(args.BannerId, args.WxappAdd); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsDeleteInfo struct {
	BannerId uint `binding:"required" label:"轮播图"`
}

// Delete @Title 删除轮播图
func (a *Wxapp) Delete(c *gin.Context) {
	args := argsDeleteInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := customer.WxappLogic.Delete(user.ManageLogic.GetManageId(c), args.BannerId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
