package broker

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/broker"
	"github.com/gin-gonic/gin"
)

type Broker struct {
}
type argsBrokerLists struct {
	broker.BrokerListsSearch
	bean.Page
}

// Lists @Title 经纪人列表
func (*Broker) Lists(c *gin.Context) {
	args := argsBrokerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := broker.BrokerLogic.Lists(args.BrokerListsSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsBrokerInfo struct {
	BrokerId uint `binding:"required" label:"经纪人"`
}

// Info @Title 经纪人详情
func (*Broker) Info(c *gin.Context) {
	args := argsBrokerInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := broker.BrokerLogic.Info(args.BrokerId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsAssessRecharge struct {
	BrokerId uint `binding:"required" label:"经纪人"`
	Count    int  `binding:"required" label:"充值次数"`
	Kind     uint `binding:"required,oneof=1 2" label:"余量种类(1=评估;2=合同)"`
}

// Recharge @Title 充值
func (*Broker) Recharge(c *gin.Context) {
	args := argsAssessRecharge{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := broker.BrokerLogic.Recharge(args.BrokerId, args.Kind, args.Count); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
