package business

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/business"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type Business struct {
}
type argsBusinessLists struct {
	business.BusinessSearch
	bean.Page
}

// Lists @Title 入驻商列表
func (b *Business) Lists(c *gin.Context) {
	args := argsBusinessLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := business.BusinessLogic.Lists(args.BusinessSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// Add @Title 添加入驻商
func (b *Business) Add(c *gin.Context) {
	args := business.BusinessAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := business.BusinessLogic.Add(user.ManageLogic.GetManageId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsBusinessInfo struct {
	BusinessId uint `binding:"required" label:"入驻商id"`
}

// Info @Title 详情
func (b *Business) Info(c *gin.Context) {
	args := argsBusinessInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := business.BusinessLogic.Info(args.BusinessId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsBusinessEdit struct {
	BusinessId uint `binding:"required" label:"入驻商"`
	business.BusinessAdd
}

// Edit @Title 编辑入驻商数据
func (b *Business) Edit(c *gin.Context) {
	args := argsBusinessEdit{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := business.BusinessLogic.Edit(args.BusinessId, args.BusinessAdd); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsAuditingLists struct {
	business.AuditingSearch
	bean.Page
}

// AuditLists @Title 入驻商审核列表
func (b *Business) AuditLists(c *gin.Context) {
	args := argsAuditingLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := business.BusinessLogic.AuditLists(args.AuditingSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsAuditingAdopt struct {
	BusinessId uint `binding:"required" label:"入驻商id"`
}

// Adopt @Title 审核通过
func (b *Business) Adopt(c *gin.Context) {
	args := argsAuditingAdopt{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := business.BusinessLogic.Adopt(user.ManageLogic.GetManageId(c), args.BusinessId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsAuditingReject struct {
	BusinessId uint   `binding:"required" label:"入驻商id"`
	Reason     string `binding:"required" label:"驳回理由"`
}

// Reject @Title 审核驳回
func (b *Business) Reject(c *gin.Context) {
	args := argsAuditingReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := business.BusinessLogic.Reject(user.ManageLogic.GetManageId(c), args.BusinessId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
