package business

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/business"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type Staff struct {
}
type argsStaffLists struct {
	business.StaffSearch
	bean.Page
}

// Lists @Title 子账户审核列表
func (s *Staff) Lists(c *gin.Context) {
	args := argsStaffLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := business.StaffLogic.Lists(args.StaffSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsStaffInfo struct {
	StaffId uint `binding:"required" label:"员工id"`
}

// Info @Title 详情
func (s *Staff) Info(c *gin.Context) {
	args := argsStaffInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := business.StaffLogic.Info(args.StaffId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

type argsStaffAdopt struct {
	StaffId uint `binding:"required" label:"员工id"`
}

// Adopt @Title 审核通过
func (s *Staff) Adopt(c *gin.Context) {
	args := argsStaffAdopt{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := business.StaffLogic.Adopt(user.ManageLogic.GetManageId(c), args.StaffId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsStaffReject struct {
	StaffId uint   `binding:"required" label:"员工id"`
	Reason  string `binding:"required" label:"驳回理由"`
}

// Reject @Title 审核驳回
func (s *Staff) Reject(c *gin.Context) {
	args := argsStaffReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := business.StaffLogic.Reject(user.ManageLogic.GetManageId(c), args.StaffId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Direct @Title 直营经纪人
func (s *Staff) Direct(c *gin.Context) {
	bean.Response.ResultSuc(c, "操作成功", business.StaffLogic.Direct())
}
