package car

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/car"
	"github.com/gin-gonic/gin"
)

type Brand struct {
}
type argsBrandLists struct {
	car.BrandSearch
	bean.Page
}

// Lists @Title 品牌列表
func (b *Brand) Lists(c *gin.Context) {
	args := argsBrandLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.BrandLogic.Lists(args.BrandSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsBrandEdit struct {
	BrandId uint   `binding:"required" label:"品牌"`
	Status  uint   `binding:"required,oneof=1 2" label:"状态"`
	Name    string `binding:"required" label:"品牌名称"`
	Icon    string `binding:"required" label:"品牌图标"`
}

// Edit @Title 修改品牌信息
func (b *Brand) Edit(c *gin.Context) {
	args := argsBrandEdit{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.BrandLogic.Edit(args.BrandId, args.Status, args.Name, args.Icon); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsBrandIsHot struct {
	BrandId uint `binding:"required" label:"品牌"`
	IsHot   uint `binding:"oneof=0 1" label:"热门"`
}

// IsHot @Title 修改热门品牌
func (b *Brand) IsHot(c *gin.Context) {
	args := argsBrandIsHot{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.BrandLogic.IsHot(args.BrandId, args.IsHot); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
