package car

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/car"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type CarBase struct {
}
type argsCarBaseLists struct {
	car.CarBaseSearch
	bean.Page
}

// Lists @Title 车辆审核列表
func (*CarBase) Lists(c *gin.Context) {
	args := argsCarBaseLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.CarBaseLogic.Lists(args.CarBaseSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCarBaseInfo struct {
	ConsignmentCarId uint `binding:"required" label:"车辆"`
}

// Info @Title 审核车辆详情
func (*CarBase) Info(c *gin.Context) {
	args := argsCarBaseInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := car.CarBaseLogic.Info(args.ConsignmentCarId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsCarBase struct {
	ConsignmentCarId uint `binding:"required" label:"车辆"`
}

// Adopt @Title 审核通过
func (*CarBase) Adopt(c *gin.Context) {
	args := argsCarBase{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.CarBaseLogic.Adopt(user.ManageLogic.GetManageId(c), args.ConsignmentCarId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCarBaseReject struct {
	ConsignmentCarId uint   `binding:"required" label:"车辆"`
	Reason           string `binding:"required" label:"驳回原因"`
}

// Reject @Title 审核驳回
func (*CarBase) Reject(c *gin.Context) {
	args := argsCarBaseReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.CarBaseLogic.Reject(user.ManageLogic.GetManageId(c), args.ConsignmentCarId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
