package car

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/car"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type DealerConsignment struct {
}
type argsDealerConsignmentLists struct {
	car.DealerConsignmentSearch
	bean.Page
}

// Lists @Title 车辆审核列表
func (*DealerConsignment) Lists(c *gin.Context) {
	args := argsDealerConsignmentLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.DealerConsignmentLogic.Lists(args.DealerConsignmentSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsDealerConsignment struct {
	DealerConsignmentCarId uint `binding:"required" label:"车辆"`
}

// Adopt @Title 审核通过
func (*DealerConsignment) Adopt(c *gin.Context) {
	args := argsDealerConsignment{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.DealerConsignmentLogic.Adopt(user.ManageLogic.GetManageId(c), args.DealerConsignmentCarId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsDealerConsignmentReject struct {
	DealerConsignmentCarId uint   `binding:"required" label:"车辆"`
	Reason                 string `binding:"required" label:"驳回原因"`
}

// Reject @Title 审核驳回
func (*DealerConsignment) Reject(c *gin.Context) {
	args := argsDealerConsignmentReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.DealerConsignmentLogic.Reject(user.ManageLogic.GetManageId(c), args.DealerConsignmentCarId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
