package car

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/car"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type Second struct {
}

type argsSecondLists struct {
	car.SecondSearch
	bean.Page
}

// Lists @Title 二手车列表
func (s *Second) Lists(c *gin.Context) {
	args := argsSecondLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := car.SecondLogic.Lists(args.SecondSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsSecondCarInfo struct {
	CarId uint `binding:"required" label:"车辆"`
}

// Info @Title 二手车详情
func (s *Second) Info(c *gin.Context) {
	args := argsSecondCarInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := car.SecondLogic.Info(args.CarId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsSecondCar struct {
	CarId uint `binding:"required" label:"车辆"`
}

// Upper @Title 二手车上架
func (s *Second) Upper(c *gin.Context) {
	args := argsSecondCar{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.SecondLogic.Upper(user.ManageLogic.GetManageId(c), args.CarId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Down @Title 二手车下架
func (s *Second) Down(c *gin.Context) {
	args := argsSecondCar{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := car.SecondLogic.Down(user.ManageLogic.GetManageId(c), args.CarId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
