package customer

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/customer"
	"base/app/model"
	"github.com/gin-gonic/gin"
)

type Customer struct {
}
type argsCustomerLists struct {
	customer.CustomerListsSearch
	bean.Page
}

// Lists @Title 客户列表
func (*Customer) Lists(c *gin.Context) {
	args := argsCustomerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := customer.CustomerLogic.Lists(args.CustomerListsSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCustomerDistribute struct {
	CustomerIds []uint `binding:"required" label:"客户"`
	Phone       string `binding:"required" label:"经纪人电话"`
}

// Distribute @Title 分配经纪人
func (*Customer) Distribute(c *gin.Context) {
	args := argsCustomerDistribute{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := customer.CustomerLogic.Distribute(args.CustomerIds, model.Broker{Phone: args.Phone}); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCustomerInfo struct {
	CustomerId uint `binding:"required" label:"客户"`
}

// Info @Title 客户详情
func (*Customer) Info(c *gin.Context) {
	args := argsCustomerInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := customer.CustomerLogic.Info(args.CustomerId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}
