package customer

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/customer"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type CustomerBroker struct {
}

type argsCustomerBrokerLists struct {
	Search customer.CustomerBrokerSearch
	bean.Page
}

// Lists @Title 申请列表
func (*CustomerBroker) Lists(c *gin.Context) {
	args := argsCustomerBrokerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := customer.CustomerBrokerLogic.Lists(args.Search, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsAuditInfo struct {
	AuditId uint `binding:"required" label:"审核单"`
}

// Info @Title 审核详情
func (*CustomerBroker) Info(c *gin.Context) {
	args := argsAuditInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := customer.CustomerBrokerLogic.Info(args.AuditId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsAuditAdopt struct {
	AuditId uint `binding:"required" label:"审核单"`
}

// Adopt @Title 审核通过
func (a *CustomerBroker) Adopt(c *gin.Context) {
	args := argsAuditAdopt{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := customer.CustomerBrokerLogic.Adopt(user.ManageLogic.GetManageId(c), args.AuditId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsAuditReject struct {
	AuditId uint   `binding:"required" label:"审核单"`
	Reason  string `binding:"required" label:"驳回原因"`
}

// Reject @Title 审核驳回
func (a *CustomerBroker) Reject(c *gin.Context) {
	args := argsAuditReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := customer.CustomerBrokerLogic.Reject(user.ManageLogic.GetManageId(c), args.AuditId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
