package dealer

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/dealer"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type Audit struct {
}
type argsAuditLists struct {
	dealer.AuditSearch
	bean.Page
}

// Lists @Title 款项审核列表
func (a *Audit) Lists(c *gin.Context) {
	args := argsAuditLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := dealer.AuditLogic.Lists(args.AuditSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsAuditAdopt struct {
	AuditId uint `binding:"required" label:"审核单"`
}

// Adopt @Title 审核通过
func (a *Audit) Adopt(c *gin.Context) {
	args := argsAuditAdopt{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := dealer.AuditLogic.Adopt(user.ManageLogic.GetManageId(c), args.AuditId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsAuditReject struct {
	AuditId uint   `binding:"required" label:"审核单"`
	Reason  string `binding:"required" label:"驳回原因"`
}

// Reject @Title 审核驳回
func (a *Audit) Reject(c *gin.Context) {
	args := argsAuditReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := dealer.AuditLogic.Reject(user.ManageLogic.GetManageId(c), args.AuditId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsAuditInfo struct {
	AuditId uint `binding:"required" label:"审核单"`
}

// Info @Title 车商审核详情
func (a *Audit) Info(c *gin.Context) {
	args := argsAuditInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := dealer.AuditLogic.Info(args.AuditId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}
