package dealer

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/dealer"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type Dealer struct {
}

type argsDealerLists struct {
	dealer.DealerSearch
	bean.Page
}

// Lists @Title 车商列表
func (d *Dealer) Lists(c *gin.Context) {
	args := argsDealerLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := dealer.DealerLogic.Lists(user.ManageLogic.GetManageId(c), args.DealerSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// Add @Title 添加车商
func (d *Dealer) Add(c *gin.Context) {
	args := dealer.DealerAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := dealer.DealerLogic.Add(user.ManageLogic.GetManageId(c), args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsDealerInfo struct {
	DealerId uint `binding:"required" label:"车商"`
}

// Info @Title 车商详情
func (d *Dealer) Info(c *gin.Context) {
	args := argsDealerInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := dealer.DealerLogic.Info(args.DealerId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsDealerAble struct {
	DealerId uint `binding:"required" label:"车商"`
	Status   uint `binding:"oneof=1 2" label:"状态"` // 1=启用 2=停用
}

// Able @Title 车商启用停用
func (d *Dealer) Able(c *gin.Context) {
	args := argsDealerAble{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := dealer.DealerLogic.Able(args.DealerId, args.Status); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsDealerDelete struct {
	DealerId uint `binding:"required" label:"车商"`
}

// Delete @Title 删除车商
func (d *Dealer) Delete(c *gin.Context) {
	args := argsDealerDelete{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := dealer.DealerLogic.Delete(args.DealerId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
