package order

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/order"
	"base/app/logic/manage/user"
	"base/app/logic/pay"
	"git.oa00.com/go/mysql"
	"github.com/gin-gonic/gin"
)

type CallCarRefund struct {
}

type argsCallCarRefundLists struct {
	order.CallCarRefundSearch
	bean.Page
}

// Lists @Title 叫车退款审核
func (*CallCarRefund) Lists(c *gin.Context) {
	args := argsCallCarRefundLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := order.CallCarRefundLogic.Lists(args.CallCarRefundSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsCallCarRefundInfo struct {
	RefundId uint `binding:"required" label:"退款单"`
}

// Info @Title 订单详情
func (*CallCarRefund) Info(c *gin.Context) {
	args := argsCallCarRefundInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := order.CallCarRefundLogic.Info(args.RefundId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsCallCarRefundAdopt struct {
	RefundId uint `binding:"required" label:"退款单"`
}

// Adopt @Title 审核通过
func (*CallCarRefund) Adopt(c *gin.Context) {
	args := argsCallCarRefundAdopt{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.CallCarRefundLogic.Adopt(user.ManageLogic.GetManageId(c), args.RefundId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCallCarRefundReject struct {
	RefundId uint   `binding:"required" label:"退款单"`
	Reason   string `binding:"required" label:"驳回原因"`
}

// Reject @Title 审核驳回
func (*CallCarRefund) Reject(c *gin.Context) {
	args := argsCallCarRefundReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.CallCarRefundLogic.Reject(user.ManageLogic.GetManageId(c), args.RefundId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsCRefundReject struct {
	PayId uint `json:"payId"`
}

// Refund @Title 退款测试
func (*CallCarRefund) Refund(c *gin.Context) {
	args := argsCRefundReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := pay.PayLogic.Refund(mysql.Db, args.PayId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
