package order

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/order"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
	"github.com/shopspring/decimal"
)

type Consignment struct {
}
type argsConsignmentLists struct {
	order.ConsignmentListsSearch
	bean.Page
}

// Lists @Title 寄卖订单列表
func (*Consignment) Lists(c *gin.Context) {
	args := argsConsignmentLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := order.ConsignmentLogic.Lists(args.ConsignmentListsSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsConsignmentInfo struct {
	ConsignmentId uint `binding:"required" label:"订单"`
}

// Info @Title 寄卖订单详情
func (*Consignment) Info(c *gin.Context) {
	args := argsConsignmentInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := order.ConsignmentLogic.Info(args.ConsignmentId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsConsignmentCancel struct {
	ConsignmentId uint `binding:"required" label:"订单"`
}

// Cancel @Title 寄卖订单取消
func (*Consignment) Cancel(c *gin.Context) {
	args := argsConsignmentCancel{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.ConsignmentLogic.Cancel(user.ManageLogic.GetManageId(c), args.ConsignmentId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsConsignmentPayment struct {
	OrderId uint            `binding:"required" label:"订单"`
	Amount  decimal.Decimal `binding:"required" label:"金额"`
	Proof   string          `binding:"required" label:"打款凭证"`
}

// Payment @Title 打款
func (*Consignment) Payment(c *gin.Context) {
	args := argsConsignmentPayment{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.ConsignmentLogic.Payment(user.ManageLogic.GetManageId(c), args.OrderId, args.Amount, args.Proof); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
