package order

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/order"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type SalePaymentAudit struct {
}
type argsSalePaymentAuditLists struct {
	order.SalePaymentAuditSearch
	bean.Page
}

// Lists @Title 款项审核列表
func (s *SalePaymentAudit) Lists(c *gin.Context) {
	args := argsSalePaymentAuditLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := order.SalePaymentAuditLogic.Lists(args.SalePaymentAuditSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsSalePaymentAuditInfo struct {
	AuditId uint `binding:"required" label:"审核单"`
}

// Info @Title 款项审核详情
func (s *SalePaymentAudit) Info(c *gin.Context) {
	args := argsSalePaymentAuditInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := order.SalePaymentAuditLogic.Info(args.AuditId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsSalePaymentAuditAdopt struct {
	AuditId uint `binding:"required" label:"审核单"`
}

// Adopt @Title 审核通过
func (s *SalePaymentAudit) Adopt(c *gin.Context) {
	args := argsSalePaymentAuditAdopt{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.SalePaymentAuditLogic.Adopt(user.ManageLogic.GetManageId(c), args.AuditId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsSalePaymentAuditReject struct {
	AuditId uint   `binding:"required" label:"审核单"`
	Reason  string `binding:"required" label:"驳回原因"`
}

// Reject @Title 审核驳回
func (s *SalePaymentAudit) Reject(c *gin.Context) {
	args := argsSalePaymentAuditReject{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := order.SalePaymentAuditLogic.Reject(user.ManageLogic.GetManageId(c), args.AuditId, args.Reason); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
