package playbill

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/playbill"
	"github.com/gin-gonic/gin"
)

type Playbill struct {
}
type argsPlaybillLists struct {
	playbill.PlaybillSearch
	bean.Page
}

// Lists @Title 海报列表
func (p *Playbill) Lists(c *gin.Context) {
	args := argsPlaybillLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := playbill.PlaybillLogic.Lists(args.PlaybillSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

// Add @Title 添加海报
func (p *Playbill) Add(c *gin.Context) {
	args := playbill.PlaybillAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := playbill.PlaybillLogic.Add(args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsPlaybillInfo struct {
	PlaybillId uint `binding:"required" label:"海报"`
}

// Info @Title 海报详情
func (p *Playbill) Info(c *gin.Context) {
	args := argsPlaybillInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	result, err := playbill.PlaybillLogic.Info(args.PlaybillId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", result)
}

type argsPlaybillEdit struct {
	PlaybillId uint `binding:"required" label:"海报"`
	playbill.PlaybillAdd
}

// Edit @Title 编辑海报
func (p *Playbill) Edit(c *gin.Context) {
	args := argsPlaybillEdit{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := playbill.PlaybillLogic.Edit(args.PlaybillId, args.PlaybillAdd); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Delete @Title 删除海报
func (p *Playbill) Delete(c *gin.Context) {
	args := argsPlaybillInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := playbill.PlaybillLogic.Delete(args.PlaybillId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
