package popularize

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/popularize"
	"base/app/logic/manage/user"
	"github.com/gin-gonic/gin"
)

type Brand struct {
}
type argsBrandLLists struct {
	popularize.BrandSearch
	bean.Page
}

// Lists @Title 品牌推广列表
func (b *Brand) Lists(c *gin.Context) {
	args := argsBrandLLists{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	lists, total := popularize.BrandLogic.Lists(args.BrandSearch, args.Page)
	bean.Response.ResultSuc(c, "操作成功", bean.ResultLists{
		List:  lists,
		Total: total,
	})
}

type argsBrandAdd struct {
	BrandId uint `binding:"required" label:"品牌"`
}

// Add @Title 添加品牌
func (b *Brand) Add(c *gin.Context) {
	args := argsBrandAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := popularize.BrandLogic.Add(user.ManageLogic.GetManageId(c), args.BrandId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsBrandEditBrand struct {
	PopularizeBrandId uint `binding:"required" label:"推广品牌"`
	BrandId           uint `binding:"required" label:"品牌"`
}

// EditBrand @Title 编辑品牌
func (b *Brand) EditBrand(c *gin.Context) {
	args := argsBrandEditBrand{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := popularize.BrandLogic.EditBrand(args.PopularizeBrandId, args.BrandId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsBrandEditSort struct {
	PopularizeBrandId uint `binding:"required" label:"推广品牌"`
	Sort              uint `binding:"required" label:"排序"`
}

// EditSort @Title 编辑排序
func (b *Brand) EditSort(c *gin.Context) {
	args := argsBrandEditSort{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := popularize.BrandLogic.EditSort(args.PopularizeBrandId, args.Sort); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsBrandDelete struct {
	PopularizeBrandId uint `binding:"required" label:"推广品牌"`
}

// Delete @Title 删除
func (b *Brand) Delete(c *gin.Context) {
	args := argsBrandDelete{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := popularize.BrandLogic.Delete(args.PopularizeBrandId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
