package setting

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/logic/manage/setting"
	"github.com/gin-gonic/gin"
)

type Menu struct {
}

// All @Title 获取全部菜单
func (m *Menu) All(c *gin.Context) {
	all := setting.MenuLogic.All()
	bean.Response.ResultSuc(c, "操作成功", all)
}

// Add @Title 添加菜单
func (m *Menu) Add(c *gin.Context) {
	args := setting.MenuAdd{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := setting.MenuLogic.Add(args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

type argsMenuInfo struct {
	MenuId uint `binding:"required" label:"菜单"`
}

// Info @Title 菜单详情
func (m *Menu) Info(c *gin.Context) {
	args := argsMenuInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	info, err := setting.MenuLogic.Info(args.MenuId)
	if err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", info)
}

// Edit @Title 编辑菜单
func (m *Menu) Edit(c *gin.Context) {
	args := setting.MenuEdit{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := setting.MenuLogic.Edit(args); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}

// Delete @Title 删除菜单
func (m *Menu) Delete(c *gin.Context) {
	args := argsMenuInfo{}
	if err := c.ShouldBind(&args); err != nil {
		bean.Response.ResultFail(c, 10001, common.GetVerErr(err))
		return
	}
	if err := setting.MenuLogic.Delete(args.MenuId); err != nil {
		bean.Response.ResultFail(c, 10002, err.Error())
		return
	}
	bean.Response.ResultSuc(c, "操作成功", nil)
}
