package task

import (
	"base/app/constant"
	"base/app/lib/bean"
	"base/app/lib/opensearch"
	"base/app/model"
	"base/app/model/es"
	"bytes"
	"encoding/json"
	"fmt"
	"git.oa00.com/go/logger"
	"git.oa00.com/go/mysql"
	"go.uber.org/zap"
	"log"
	"time"
)

var Task = &task{}

type task struct {
}

// PushESTaskRun @Title 更新数据到ES
func (*task) PushESTaskRun() {
	go func() {
		for {
			log.Println("任务定时运行")
			push()
			time.Sleep(time.Minute * 10)
		}
	}()
}

func push() {
	page := bean.Page{Page: 1, Limit: 100}
	var cars []model.Car
circulate:
	mysql.Db.Preload("Model").Preload("Model.Brand").Offset(page.GetStart()).Limit(page.GetLimit()).Find(&cars)
	if len(cars) == 0 {
		return
	}
	for _, car := range cars {
		data := es.Car{
			Id:            car.Id,
			BrokerId:      car.BrokerId,
			ModelId:       car.ModelId,
			ModelName:     car.Model.Name,
			BrandId:       car.Model.BrandId,
			BrandName:     car.Model.Brand.Name,
			Status:        car.Status,
			TheUpper:      car.TheUpper,
			Type:          car.Type,
			MainPhoto:     car.MainPhoto,
			LicensingDate: car.LicensingDate.Time.Unix(),
			Price:         car.Price,
			InteriorPrice: car.InteriorPrice,
			ExteriorPrice: car.ExteriorPrice,
			DownPayment:   car.DownPayment,
			Mileage:       car.Mileage,
			Transfer:      car.Transfer,
		}
		marshal, err := json.Marshal(data)
		if err != nil {
			logger.Logger.Error("车辆信息同步至ES失败", zap.Error(err))
			continue
		}
		if err := opensearch.Api.PushDoc(constant.CarIndex, fmt.Sprintf("%d", car.Id), bytes.NewBuffer(marshal)); err != nil {
			logger.Logger.Error("车辆信息同步至ES失败", zap.Error(err))
			continue
		}
	}
	page.Page++
	goto circulate
}
