package excel

import (
	"github.com/xuri/excelize/v2"
	"log"
	"strconv"
)

var Excel = &excelLib{}

type excelLib struct {
}
type Row struct {
	Value   interface{}
	ColSpan uint
	RowSpan uint
	Style   int
}

// SetRowItem @Title 设置单元格数据
func (e *excelLib) SetRowItem(file *excelize.File, sheet string, rowIndex, colIndex int, item Row) error {
	celName := e.excelColName(colIndex, rowIndex)
	return file.SetCellValue(sheet, celName, item.Value)
}

// SetRow @Title 设置列数据
func (e *excelLib) SetRow(file *excelize.File, sheet string, rowIndex int, row []Row) {
	colIndex := 0
	for index, data := range row {
		celName := e.excelColName(index+colIndex, rowIndex)
		newRowIndex := rowIndex
		if data.ColSpan > 1 {
			colIndex += int(data.ColSpan) - 1
		}
		if data.RowSpan > 1 {
			newRowIndex += int(data.RowSpan) - 1
		}
		mergeName := e.excelColName(index+colIndex, newRowIndex)
		if celName != mergeName {
			file.MergeCell(sheet, celName, mergeName)
		}
		file.SetCellValue(sheet, celName, data.Value)
		if data.Style > 0 {
			log.Println(sheet, celName, mergeName, data.Style)
			log.Println(file.SetCellStyle(sheet, celName, mergeName, data.Style))
		}
	}
}

func (e *excelLib) excelColName(colIndex, rowIndex int) (result string) {
	return e.excelCol(uint(colIndex)) + strconv.Itoa(rowIndex)
}

func (e *excelLib) excelCol(colIndex uint) (result string) {
	for {
		if result != "" {
			colIndex--
		}
		result = string(rune(65+colIndex%26)) + result
		colIndex /= 26
		if colIndex == 0 {
			break
		}
	}
	return
}
