package area

import (
	"base/app/model"
	"fmt"
	"git.oa00.com/go/mysql"
)

var AreaLogic = &areaLogic{}

type areaLogic struct {
}

type cityItem struct {
	Id       uint   `json:"id"`
	ProvId   uint   `json:"provId"`
	ProvName string `json:"provName"`
	CityId   uint   `json:"cityId"`
	CityName string `json:"cityName"`
}

// City @Title 获取城市数据
func (a *areaLogic) City() (result []cityItem) {
	var citys []model.City
	mysql.Db.Find(&citys)
	for _, city := range citys {
		result = append(result, cityItem{
			Id:       city.Id,
			ProvId:   city.ProvId,
			ProvName: city.ProvName,
			CityId:   city.CityId,
			CityName: city.CityName,
		})
	}
	return
}

type areaItem struct {
	Id       uint        `json:"id"`
	ParentId uint        `json:"parentId"`
	Name     string      `json:"name"`
	Code     string      `json:"code"`
	Level    uint        `json:"level"`
	Children []*areaItem `json:"children"`
}

// All @Title 获取省市区数据
func (a *areaLogic) All() (result []areaItem) {
	var areas []model.Area
	mysql.Db.Find(&areas)
	for _, area := range areas {
		result = append(result, areaItem{
			Id:       area.Id,
			Name:     area.Name,
			Code:     area.Code,
			Level:    area.Level,
			ParentId: area.ParentId,
		})
	}
	result = a.getTree(result)
	return
}

// List @Title 筛选省市区数据
func (a *areaLogic) List(level uint, name string) (result []areaItem) {
	where := mysql.Db
	if level > 0 {
		where = where.Where("level = ?", level)
	}
	if name != "" {
		where = where.Where("name like ?", fmt.Sprintf("%%%s%%", name))
	}
	var areas []model.Area
	mysql.Db.Where(where).Find(&areas)
	for _, area := range areas {
		result = append(result, areaItem{
			Id:       area.Id,
			Name:     area.Name,
			Code:     area.Code,
			Level:    area.Level,
			ParentId: area.ParentId,
		})
	}
	return
}

type Version struct {
	Version uint `json:"version"`
}

// Version @Title 获取省市区数据版本
func (a *areaLogic) Version() *Version {
	return &Version{
		Version: 1,
	}
}

// @Title 获取树
func (a *areaLogic) getTree(datas []areaItem) (result []areaItem) {
	result = []areaItem{}
	for i, item := range datas {
		if item.ParentId > 0 {
			for index, value := range datas {
				if item.ParentId == value.Id {
					datas[index].Children = append(datas[index].Children, &datas[i])
					break
				}
			}
		}
	}
	for _, item := range datas {
		if item.ParentId == 0 {
			result = append(result, item)
		}
	}
	return
}
