package app

import (
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
)

var HandbookLogic = &handbookLogic{}

type handbookLogic struct {
}
type handhook struct {
	Items []handhookItem `json:"items"`
	Name  string         `json:"name"`
}
type handhookItem struct {
	Id        uint   `json:"id"`
	Name      string `json:"name"`
	UpdatedAt int64  `json:"updatedAt"`
}

// All @Title 获取手册
func (h *handbookLogic) All() (result []handhook) {
	var handbooks []model.BrokerAppHandbook
	mysql.Db.Preload("HandbookItem").Order("sort").Find(&handbooks)
	for _, handbook := range handbooks {
		if len(handbook.HandbookItem) == 0 {
			continue
		}
		resultItem := handhook{
			Name: handbook.Name,
		}
		for _, item := range handbook.HandbookItem {
			resultItem.Items = append(resultItem.Items, handhookItem{
				Id:        item.Id,
				Name:      item.Name,
				UpdatedAt: item.UpdatedAt.Unix(),
			})
		}
		result = append(result, resultItem)
	}
	return
}

type handbookInfo struct {
	Id        uint   `json:"id"`
	Name      string `json:"name"`
	Content   string `json:"content"`
	CreatedAt int64  `json:"createdAt"`
	UpdatedAt int64  `json:"updatedAt"`
}

// Info @Title 手册详情
func (h *handbookLogic) Info(itemId uint) (result handbookInfo, err error) {
	handbookItem := model.BrokerAppHandbookItem{Id: itemId}
	if mysql.Db.First(&handbookItem).Error != nil {
		return result, errors.New("手册错误")
	}
	result = handbookInfo{
		Id:        handbookItem.Id,
		Name:      handbookItem.Name,
		Content:   handbookItem.Content,
		CreatedAt: handbookItem.CreatedAt.Unix(),
		UpdatedAt: handbookItem.UpdatedAt.Unix(),
	}
	return
}
