package business

import (
	"base/app/model"
	"fmt"
	"git.oa00.com/go/mysql"
)

var BusinessLogic = &businessLogic{}

type businessLogic struct {
}

type BusinessSearch struct {
	Staff StaffSearch
	Name  string
	Phone string
}

type businessAllItem struct {
	Id     uint        `json:"id"`
	Name   string      `json:"name"`
	Staffs []staffItem `json:"staffs"`
}

// AllBusiness @Title 获取全部入驻商
func (b *businessLogic) AllBusiness(searchData BusinessSearch) (result []businessAllItem) {
	var businesses []model.BrokerBusiness
	where := mysql.Db
	{
		staffWhere := mysql.Db.Model(&model.BrokerBusinessStoreStaff{}).Select("business_id")
		if searchData.Staff.Name != "" {
			staffWhere = staffWhere.Where("name like ?", fmt.Sprintf("%%%s%%", searchData.Staff.Name))
		}
		if searchData.Staff.Phone != "" {
			staffWhere = staffWhere.Where("phone like ?", fmt.Sprintf("%%%s%%", searchData.Staff.Phone))
		}
		if _, ok := staffWhere.Statement.Clauses["WHERE"]; ok {
			where = where.Where("id in (?)", staffWhere)
		}
	}
	if searchData.Name != "" {
		where = where.Where("name like ?", fmt.Sprintf("%%%s%%", searchData.Name))
	}
	if searchData.Phone != "" {
		where = where.Where("telephone like ?", fmt.Sprintf("%%%s%%", searchData.Phone))
	}
	mysql.Db.Preload("Staffs.Role").Where(where).Find(&businesses)
	for _, item := range businesses {
		businessesItem := businessAllItem{
			Id:     item.Id,
			Name:   item.Name,
			Staffs: []staffItem{},
		}
		for _, staff := range item.Staffs {
			businessesItem.Staffs = append(businessesItem.Staffs, staffItem{
				Id:          staff.Id,
				Name:        staff.Name,
				Phone:       staff.Phone,
				Gender:      staff.Gender,
				AuditStatus: staff.Audit.Status,
				RoleId:      staff.RoleId,
				RoleName:    staff.Role.Name,
				BrokerId:    staff.BrokerId,
			})
		}
		result = append(result, businessesItem)
	}
	return

}

// AllStaff @Title 获取全部入驻商员工
func (b *businessLogic) AllStaff(searchData StaffAllSearch) (result []businessAllItem) {
	var businessStaffs []model.BrokerBusinessStoreStaff
	where := mysql.Db
	if searchData.Name != "" {
		where = where.Where("name like ?", fmt.Sprintf("%%%s%%", searchData.Name))
	}
	if searchData.Phone != "" {
		where = where.Where("telephone like ?", fmt.Sprintf("%%%s%%", searchData.Phone))
	}
	if searchData.Status > 0 {
		switch searchData.Status {
		case 1: // 审核中
			where = where.Where("audit_id in (?)", mysql.Db.Model(&model.BrokerBusinessStoreStaffAudit{}).Where("status = ?", model.BrokerBusinessStoreStaffAuditStatusSubmit).Select("id"))
		case 2: // 审核通过
			where = where.Where("audit_id in (?)", mysql.Db.Model(&model.BrokerBusinessStoreStaffAudit{}).Where("status = ?", model.BrokerBusinessStoreStaffAuditStatusSuc).Select("id"))
		case 3: // 审核驳回
			where = where.Where("audit_id in (?)", mysql.Db.Model(&model.BrokerBusinessStoreStaffAudit{}).Where("status = ?", model.BrokerBusinessStoreStaffAuditStatusFail).Select("id"))
		}
	}
	mysql.Db.Preload("Role").Preload("Business").Where(where).Find(&businessStaffs)

	var resultStaffs = map[uint][]staffItem{}
	var resultBusiness = map[uint]businessAllItem{}
	for _, staff := range businessStaffs {
		resultBusiness[staff.BusinessId] = businessAllItem{
			Id:   staff.Business.Id,
			Name: staff.Business.Name,
		}
		resultStaffs[staff.BusinessId] = append(resultStaffs[staff.BusinessId], staffItem{
			Id:          staff.Id,
			Name:        staff.Name,
			Phone:       staff.Phone,
			Gender:      staff.Gender,
			AuditStatus: staff.Audit.Status,
			RoleId:      staff.RoleId,
			RoleName:    staff.Role.Name,
			BrokerId:    staff.BrokerId,
		})
	}

	for u, item := range resultBusiness {
		result = append(result, businessAllItem{
			Id:     item.Id,
			Name:   item.Name,
			Staffs: resultStaffs[u],
		})
	}

	return

}
