package business

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"fmt"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
	"gorm.io/gorm"
)

var StoreLogic = &storeLogic{}

type storeLogic struct {
}
type storeAllItem struct {
	Id     uint        `json:"id"`
	Name   string      `json:"name"`
	Staffs []staffItem `json:"staffs"`
}
type staffItem struct {
	Id          uint   `json:"id"`
	Name        string `json:"name"`
	Phone       string `json:"phone"`
	AuditStatus uint   `json:"auditStatus"`
	RoleId      uint   `json:"roleId"`
	RoleName    string `json:"roleName"`
	Gender      uint   `json:"gender"`
	BrokerId    uint   `json:"brokerId"`
}

type StaffSearch struct {
	Name   string
	Status uint
	Phone  string
}

// StructAll @Title 获取组织架构
func (s *storeLogic) StructAll(businessId uint, searchData StaffSearch) (result []storeAllItem) {
	//var businessStores []model.BrokerBusinessStore
	//where := mysql.Db.Where("business_id = ?", businessId)
	//var ids []uint
	//if searchData.Name != "" {
	//	mysql.Db.Model(&model.BrokerBusinessStoreStaff{}).Where("name like ?", fmt.Sprintf("%%%s%%", searchData.Name)).Select("id").Scan(&ids)
	//	where = where.Where("id in (?)", mysql.Db.Model(&model.BrokerBusinessStoreStaff{}).Where("name like ?", fmt.Sprintf("%%%s%%", searchData.Name)).Select("store_id"))
	//}
	//mysql.Db.Preload("Staffs.Role").Preload("Staffs.Audit").Where(where).Find(&businessStores)
	//for _, store := range businessStores {
	//	storeItem := storeAllItem{
	//		Id:   store.Id,
	//		Name: store.Name,
	//	}
	//	for _, staff := range store.Staffs {
	//		switch searchData.Status {
	//		case 1: // 审核中
	//			if staff.Audit.Status != model.BrokerBusinessStoreStaffAuditStatusSubmit {
	//				continue
	//			}
	//		case 2: // 审核通过
	//			if staff.Audit.Status != model.BrokerBusinessStoreStaffAuditStatusSuc {
	//				continue
	//			}
	//		}
	//
	//		storeItem.Staffs = append(storeItem.Staffs, staffItem{
	//			Id:          staff.Id,
	//			Name:        staff.Name,
	//			Phone:       staff.Phone,
	//			Gender:      staff.Gender,
	//			AuditStatus: staff.Audit.Status,
	//			RoleId:      staff.RoleId,
	//			RoleName:    staff.Role.Name,
	//		})
	//
	//	}
	//	result = append(result, storeItem)
	//}
	//return

	var staffs []model.BrokerBusinessStoreStaff
	var stores []model.BrokerBusinessStore
	var business model.BrokerBusiness
	mysql.Db.Where("id = ?", businessId).Find(&business)
	mysql.Db.Where("business_id = ?", businessId).Find(&stores)
	var mStore = map[uint]storeAllItem{}
	var storeIds []uint
	for _, item := range stores {
		storeIds = append(storeIds, item.Id)
		mStore[item.Id] = storeAllItem{
			Id:   item.Id,
			Name: item.Name,
		}
	}
	where := mysql.Db.Where("store_id in (?)", storeIds).Where("business_id = ?", businessId)
	if searchData.Name != "" {
		where.Where("name like ?", fmt.Sprintf("%%%s%%", searchData.Name))
	}
	if searchData.Status > 0 {
		switch searchData.Status {
		case 1: // 审核中
			where = where.Where("audit_id in (?)", mysql.Db.Model(&model.BrokerBusinessStoreStaffAudit{}).Where("status = ?", model.BrokerBusinessStoreStaffAuditStatusSubmit).Select("id"))
		case 2: // 审核通过
			where = where.Where("audit_id in (?)", mysql.Db.Model(&model.BrokerBusinessStoreStaffAudit{}).Where("status = ?", model.BrokerBusinessStoreStaffAuditStatusSuc).Select("id"))
		case 3: // 审核驳回
			where = where.Where("audit_id in (?)", mysql.Db.Model(&model.BrokerBusinessStoreStaffAudit{}).Where("status = ?", model.BrokerBusinessStoreStaffAuditStatusFail).Select("id"))
		}
	}
	mysql.Db.Preload("Role").Preload("Audit").Where(where).Find(&staffs)

	var mStoreStaffs = map[uint][]staffItem{}
	for _, staff := range staffs {
		//mStore[staff.StoreId] = storeAllItem{
		//	Id:   staff.Store.Id,
		//	Name: staff.Store.Name,
		//}
		mStoreStaffs[staff.StoreId] = append(mStoreStaffs[staff.StoreId], staffItem{
			Id:          staff.Id,
			Name:        staff.Name,
			Phone:       staff.Phone,
			Gender:      staff.Gender,
			AuditStatus: staff.Audit.Status,
			RoleId:      staff.RoleId,
			RoleName:    staff.Role.Name,
			BrokerId:    staff.BrokerId,
		})
	}

	for u, item := range mStore {
		result = append(result, storeAllItem{
			Id:     item.Id,
			Name:   item.Name,
			Staffs: mStoreStaffs[u],
		})
	}
	return

}

type StoreSearch struct {
	Name string
}

type AllItem struct {
	Id             uint   `json:"id"`
	Name           string `json:"name"`
	OwnerBrokerId  uint   `json:"ownerBrokerId"`
	OwnBrokerName  string `json:"ownBrokerName"`
	OwnerBrokerTel string `json:"ownerBrokerTel"`
	CreatedAt      int64  `json:"createdAt"`
}

// All @Title 全部门店
func (s *storeLogic) All(businessId uint, searchData StoreSearch) (result []AllItem) {
	var businessStores []model.BrokerBusinessStore
	where := mysql.Db.Where("business_id = ? and auditing_status = ?", businessId, model.BrokerBusinessStoreAuditStatusSuc)
	mysql.Db.Preload("OwnerBroker").Where(where).Find(&businessStores)
	for _, store := range businessStores {
		item := AllItem{
			Id:             store.Id,
			Name:           store.Name,
			OwnerBrokerId:  store.OwnerBroker.Id,
			OwnBrokerName:  store.OwnerBroker.Nickname,
			OwnerBrokerTel: store.OwnerBroker.Phone,
			CreatedAt:      store.CreatedAt.Unix(),
		}
		result = append(result, item)
	}
	return
}

type StoreAddData struct {
	Name       string          `binding:"required" label:"名称"`
	Address    string          `binding:"required" label:"地址"`
	CreditCode string          `binding:"required" label:"信用代码"`
	Commission decimal.Decimal `binding:"required" label:"提成"`
	Owner      StoreOwnerData  `binding:"required" label:"店长信息"`
}
type StoreOwnerData struct {
	Name        string `binding:"required" label:"姓名"`
	Gender      uint   `binding:"required,oneof=1 2" label:"性别"`
	Phone       string `binding:"required" label:"手机号"`
	IdCard      string `binding:"required" label:"身份证号码"`
	IdCardFront string // 身份证正面
	IdCardBack  string // 身份证反面
	BankCard    string `binding:"required" label:"银行卡号"`
	Bank        string `binding:"required" label:"银行名"`
	BankAccount string `binding:"required" label:"银行账户"`
}

// Add @Title 添加门店
func (s *storeLogic) Add(brokerLevel, businessId uint, data StoreAddData) error {
	if brokerLevel != model.BrokerLevelBusiness {
		return errors.New("权限不足")
	}
	broker := model.Broker{Phone: data.Owner.Phone}
	mysql.Db.Where(&broker).First(&broker)
	if broker.Id > 0 && broker.Level != model.BrokerLevelBase {
		return errors.New("手机号已使用")
	}
	//storeNo, err := common.GenNo(constant.NoPrefixBrokerBusinessStore)
	//if err != nil {
	//	return errors.New("生成门店编号失败")
	//}
	store := model.BrokerBusinessStore{
		BusinessId: businessId,
		//StoreNo:    storeNo,
		Name:       data.Name,
		Address:    data.Address,
		Commission: data.Commission,
		Company: model.BrokerDealerCompany{
			Name:              data.Name,
			BusinessLicenseNo: data.CreditCode,
			LegalPerson:       data.Owner.Name,
			LegalTel:          data.Owner.Phone,
			LegalPersonCard:   data.Owner.IdCard,
			IdCardFront:       data.Owner.IdCardFront,
			IdCardBack:        data.Owner.IdCardBack,
			BankCard:          data.Owner.BankCard,
			Bank:              data.Owner.Bank,
			BankAccount:       data.Owner.BankAccount,
		},
		Status:         model.BrokerBusinessStoreStatusDisabled,
		AuditingStatus: model.BrokerBusinessStoreAuditStatusSubmit,
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if broker.Id == 0 {
			broker.Nickname = data.Owner.Name
			broker.Gender = data.Owner.Gender
			broker.Level = model.BrokerLevelBase
			if tx.Create(&broker).Error != nil {
				return errors.New("创建店长身份失败")
			}
		}
		store.OwnerBrokerId = broker.Id
		if tx.Create(&store).Error != nil {
			return errors.New("添加失败")
		}
		storeNo, err := common.GenNo6(store.Id)
		if err != nil {
			return err
		}
		if tx.Model(&model.BrokerBusinessStore{}).Where("id = ?", store.Id).Updates(map[string]interface{}{
			"store_no": storeNo,
		}).RowsAffected != 1 {
			return errors.New("添加失败")
		}
		return nil
	})
}

// Select @Title 门店筛选
func (s *storeLogic) Select(businessId uint) (result []bean.SelectItem) {
	result = []bean.SelectItem{}
	var stores []model.BrokerBusinessStore
	mysql.Db.Where("business_id = ?", businessId).Find(&stores)
	for _, store := range stores {
		result = append(result, bean.SelectItem{
			Id:   store.Id,
			Name: store.Name,
		})
	}
	return
}
