package customer

import (
	"base/app/model"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
)

var TrailLogic = &trailLogic{}

type trailLogic struct {
}
type trailItem struct {
	Type          string      `json:"type"`
	InitiatorName string      `json:"initiatorName"`
	ContentType   uint        `json:"contentType"`
	Content       string      `json:"content"`
	CreatedAt     int64       `json:"createdAt"`
	Invite        inviteInfo  `json:"invite"`
	Reserve       reserveInfo `json:"reserve"`
}
type inviteInfo struct {
	InviteAt      int64           `json:"inviteAt"`
	Address       string          `json:"address"`
	Remark        string          `json:"remark"`
	CarId         uint            `json:"carId"`
	MainPhoto     string          `json:"mainPhoto"`
	ModelName     string          `json:"modelName"`
	LicensingDate int64           `json:"licensingDate"`
	Mileage       decimal.Decimal `json:"mileage"`
	Price         decimal.Decimal `json:"price"`
	CarType       uint            `json:"carType"`
}
type reserveInfo struct {
	ReserveAt     int64           `json:"reserveAt"`
	Address       string          `json:"address"`
	ModelName     string          `json:"modelName"`
	LicensingDate int64           `json:"licensingDate"`
	Mileage       decimal.Decimal `json:"mileage"`
	Price         decimal.Decimal `json:"price"`
}

// All @Title 客户轨迹
func (t *trailLogic) All(customerId uint) (result []trailItem) {
	result = []trailItem{}
	var trails []model.CustomerTrail
	mysql.Db.Where("customer_id = ?", customerId).Order("id desc").Find(&trails)
	var inviteIds []uint
	var reserves []uint
	for _, trail := range trails {
		switch trail.ContentType {
		case model.CustomerTrailContentTypeInvite: // 邀约看车
			inviteIds = append(inviteIds, trail.ContentId)
		case model.CustomerTrailContentTypeReserve: // 邀约卖车
			reserves = append(reserves, trail.ContentId)
		}
	}
	// 看车邀约
	mInvite := map[uint]inviteInfo{}
	if len(inviteIds) > 0 {
		var invites []model.OrderInvite
		mysql.Db.Preload("Car.Model").Where("customer_id = ?", customerId).Find(&invites)
		for _, invite := range invites {
			mInvite[invite.Id] = inviteInfo{
				InviteAt:      invite.InviteAt.Unix(),
				Address:       invite.Address,
				Remark:        invite.Remark,
				CarId:         invite.CarId,
				MainPhoto:     invite.Car.MainPhoto,
				ModelName:     invite.Car.Model.Name,
				LicensingDate: invite.Car.LicensingDate.Time.Unix(),
				Mileage:       invite.Car.Mileage,
				Price:         invite.Car.Price,
				CarType:       invite.Car.Type,
			}
		}
	}
	// 卖车邀约
	mReserve := map[uint]reserveInfo{}
	if len(reserves) > 0 {
		var orderReserves []model.OrderReserve
		mysql.Db.Preload("Price.Model").Where("customer_id = ?", customerId).Find(&orderReserves)
		for _, orderReserve := range orderReserves {
			mReserve[orderReserve.Id] = reserveInfo{
				ReserveAt:     orderReserve.ReserveAt.Unix(),
				Address:       orderReserve.Address,
				ModelName:     orderReserve.Price.Model.Name,
				LicensingDate: orderReserve.Price.LicensingDate.Unix(),
				Mileage:       orderReserve.Price.Mileage,
				Price:         orderReserve.Price.Price,
			}
		}
	}
	for _, trail := range trails {
		item := trailItem{
			Type:          trail.Type,
			InitiatorName: trail.InitiatorName,
			ContentType:   trail.ContentType,
			Content:       trail.Content,
			CreatedAt:     trail.CreatedAt.Unix(),
		}
		switch trail.ContentType {
		case model.CustomerTrailContentTypeInvite: // 邀约看车
			item.Invite = mInvite[trail.ContentId]
		case model.CustomerTrailContentTypeReserve: // 邀约卖车
			item.Reserve = mReserve[trail.ContentId]
		}
		result = append(result, item)
	}
	return
}
