package order

import (
	"base/app/lib/bean"
	"base/app/logic/broker/message"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"gorm.io/gorm"
	"time"
)

var InviteLogic = &inviteLogic{}

type inviteLogic struct {
}
type inviteItem struct {
	Id uint
}

// Lists @Title 邀约列表
func (i *inviteLogic) Lists(brokerId uint, page bean.Page) (lists []inviteItem, total int64) {
	lists = []inviteItem{}
	var invites []model.OrderInvite
	where := mysql.Db.Where("broker_id = ?", brokerId)
	mysql.Db.Model(&invites).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Find(&invites)
		for _, invite := range invites {
			lists = append(lists, inviteItem{
				Id: invite.Id,
			})
		}
	}
	return
}

type InviteAdd struct {
	CustomerId uint   `binding:"required" label:"客户"`
	CarId      uint   `binding:"required" label:"预定车辆"`
	InviteAt   string `binding:"required" label:"邀约时间"`
	Address    string `binding:"required" label:"邀约地址"`
	Remark     string // 备注
}

// Add @Title 发起邀约
func (i *inviteLogic) Add(brokerId uint, data InviteAdd) error {
	invite, err := time.ParseInLocation("2006-01-02 15:04:05", data.InviteAt, time.Local)
	if err != nil {
		return errors.New("邀约时间错误")
	}
	orderInvite := model.OrderInvite{
		CustomerId: data.CustomerId,
		BrokerId:   brokerId,
		CarId:      data.CarId,
		InviteAt:   invite,
		Address:    data.Address,
		Remark:     data.Remark,
		Status:     model.OrderInviteStatusIng,
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Create(&orderInvite).Error != nil {
			return errors.New("发起失败")
		}
		if tx.Model(&model.Customer{}).Where("id = ? and level < ?", data.CustomerId, model.CustomerLevelIntention).UpdateColumn("level", model.CustomerLevelIntention).Error != nil {
			return errors.New("客户特征修改失败")
		}
		message.MessageLogic.MessageToCustomer(tx, []uint{data.CustomerId}, brokerId, model.CustomerMessageTypeInvite, message.MessageItem{
			Title:   "邀约提醒",
			Content: "您有一个新的邀约"})
		return nil
	})
}
