package task

import (
	"base/app/lib/bean"
	"base/app/logic/customer/record"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"gorm.io/gorm"
	"time"
)

var InviteLogic = &inviteLogic{}

type inviteLogic struct {
}
type inviteItem struct {
	Id               uint   `json:"id"`
	CustomerId       uint   `json:"customerId"`
	Type             uint   `json:"type"`
	CustomerNickname string `json:"customerNickname"`
	InviteAt         int64  `json:"inviteAt"`
}

// Lists @Title 客户邀约列表
func (i *inviteLogic) Lists(brokerId uint, inviteType uint, page bean.Page) (lists []inviteItem, total int64) {
	lists = []inviteItem{}
	var invites []model.CustomerInvite
	where := mysql.Db.Where("broker_id = ?", brokerId)
	//  邀约类型
	{
		switch inviteType {
		case 1: // 看车
			where = where.Where("type = ?", model.CustomerInviteTypeInvite)
		case 2: // 检车
			where = where.Where("type = ?", model.CustomerInviteTypeReserve)
		}
	}
	mysql.Db.Model(&invites).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("Customer").Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).
			Order(`IF(invite_at > now(),invite_at, invite_at * -1 +  now()) `).Find(&invites)
		for _, invite := range invites {
			lists = append(lists, inviteItem{
				Id:               invite.Id,
				CustomerId:       invite.CustomerId,
				Type:             invite.Type,
				CustomerNickname: invite.Customer.Nickname,
				InviteAt:         invite.InviteAt.Unix(),
			})
		}
	}
	return
}

type InviteAdd struct {
	CustomerId uint   `binding:"required" label:"客户"`
	InviteTime string `binding:"required" label:"邀约时间"`
	CarId      uint   `binding:"required" label:"车辆"`
	Address    string `binding:"required" label:"邀约地址"`
	Remark     string
}

// Add @Title 看车邀约
func (i *inviteLogic) Add(brokerId uint, data InviteAdd) error {
	customer := model.Customer{Id: data.CustomerId, BrokerId: brokerId}
	if mysql.Db.Where(&customer).First(&customer).Error != nil {
		return errors.New("客户错误")
	}
	inviteAt, err := time.ParseInLocation("2006-01-02 15:04:05", data.InviteTime, time.Local)
	if err != nil {
		return errors.New("预约时间错误")
	}
	invite := model.OrderInvite{
		CustomerId: data.CustomerId,
		BrokerId:   brokerId,
		CarId:      data.CarId,
		InviteAt:   inviteAt,
		Address:    data.Address,
		Remark:     data.Remark,
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Create(&invite).Error != nil {
			return errors.New("预约失败")
		}
		if err = record.TrailLogic.Add(tx, record.TrailData{
			CustomerId:    data.CustomerId,
			Type:          "看车邀约",
			InitiatorId:   brokerId,
			InitiatorType: model.CustomerTrailInitiatorTypeBroker,
			ContentType:   model.CustomerTrailContentTypeInvite,
			ContentId:     invite.Id,
			Content:       "发起客户邀约",
		}); err != nil {
			return err
		}
		if err = record.InviteLogic.Add(tx, record.InviteData{
			CustomerId: data.CustomerId,
			BrokerId:   brokerId,
			Type:       model.CustomerInviteTypeInvite,
			InviteAt:   inviteAt,
		}); err != nil {
			return err
		}
		return nil
	})
}
