package user

import (
	"base/app/common"
	"base/app/config"
	"base/app/constant"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"git.oa00.com/go/pay"
	"github.com/smartwalle/alipay/v3"
	"gorm.io/gorm"
	"log"
)

var CertifyLogic = &certifyLogic{}

type certifyLogic struct {
}
type CertifyData struct {
	Name        string `binding:"required" label:"姓名"`
	IdCard      string `binding:"required" label:"身份证号"`
	IdCardFront string `binding:"required" label:"身份证正面"`
	IdCardBack  string `binding:"required" label:"身份证背面"`
}
type certifyAli struct {
	CertifyId string `json:"certifyId"`
	Url       string `json:"url"`
}

// Ali @Title 支付宝实名认证
func (c *certifyLogic) Ali(brokerId uint, data CertifyData) (result certifyAli, err error) {
	certifyNo, err := common.GenNo(constant.NoPrefixBrokerCertify)
	if err != nil {
		return result, err
	}
	initialize, err := pay.Alipay.UserCertifyOpenInitialize(alipay.UserCertifyOpenInitialize{
		OuterOrderNo: certifyNo,
		BizCode:      "FACE",
		IdentityParam: alipay.IdentityParam{
			IdentityType: "CERT_INFO",
			CertType:     "IDENTITY_CARD",
			CertName:     data.Name,
			CertNo:       data.IdCard,
		},
		MerchantConfig: alipay.MerchantConfig{
			ReturnURL: config.Config.Alipay.CertifyReturnURL,
		},
	})
	if err != nil {
		return result, errors.New("实名认证错误")
	}
	certify, err := pay.Alipay.UserCertifyOpenCertify(alipay.UserCertifyOpenCertify{
		CertifyId: initialize.Content.CertifyId,
	})
	if err != nil {
		return result, errors.New("实名认证错误")
	}
	result.CertifyId = initialize.Content.CertifyId
	result.Url = certify.String()
	brokerCertify := model.BrokerCertify{
		CertifyNo:   certifyNo,
		BrokerId:    brokerId,
		Name:        data.Name,
		IdCard:      data.IdCard,
		IdCardFront: data.IdCardFront,
		IdCardBack:  data.IdCardBack,
		CertifyId:   result.CertifyId,
		Status:      model.BrokerCertifyStatusIng,
	}
	if mysql.Db.Create(&brokerCertify).Error != nil {
		return result, errors.New("实名认证错误")
	}
	return
}

type certifyAliResult struct {
	Success uint `json:"success"`
}

// AliResult @Title 获取支付宝实名认证结果
func (c certifyLogic) AliResult(brokerId uint, certifyId string) (result certifyAliResult, err error) {
	//certify := model.BrokerCertify{BrokerId: brokerId}
	//if mysql.Db.Where(&certify).Order("id desc").First(&certify).Error != nil {
	//	return
	//}
	query, err := pay.Alipay.UserCertifyOpenQuery(alipay.UserCertifyOpenQuery{
		CertifyId: certifyId,
	})
	if err != nil {
		return result, errors.New("查询结果失败")
	}
	certify := model.BrokerCertify{BrokerId: brokerId, CertifyId: certifyId}
	if mysql.Db.Where(&certify).First(&certify).Error != nil {
		return result, errors.New("实名认证失败")
	}
	log.Println(query)
	if query.Content.Passed == "T" {
		// 认证成功
		if certify.Status != model.BrokerCertifyStatusSuc {
			mysql.Db.Transaction(func(tx *gorm.DB) error {
				if tx.Model(&certify).Where("status <> ?", model.BrokerCertifyStatusSuc).UpdateColumn("status", model.BrokerCertifyStatusSuc).RowsAffected != 1 {
				} else {
					brokerReal := model.BrokerReal{
						BrokerId:    brokerId,
						Name:        certify.Name,
						IdCard:      certify.IdCard,
						IdCardFront: certify.IdCardFront,
						IdCardBack:  certify.IdCardBack,
					}
					if tx.Create(&brokerReal).Error != nil {
						return errors.New("实名认证失败")
					}
					if tx.Model(&model.Broker{}).Where("id = ?", brokerId).UpdateColumns(
						map[string]interface{}{
							"is_real":   model.BrokerIsRealTrue,
							"master_id": brokerReal.Id,
						}).RowsAffected != 1 {
						return errors.New("实名认证失败")
					}
				}
				result.Success = 1
				return nil
			})
		}
	} else {
		// 认证失败
		if certify.Status == model.BrokerCertifyStatusIng {
			if mysql.Db.Model(&certify).Where(&certify).UpdateColumn("status", model.BrokerCertifyStatusFail).RowsAffected != 1 {
				return result, errors.New("实名认证失败")
			}
		}
	}
	return
}
