package user

import (
	"base/app/common"
	"base/app/constant"
	"base/app/logic/pay"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
	"gorm.io/gorm"
)

var PartnerLogic = &partnerLogic{}

type partnerLogic struct {
}
type contractSign struct {
	OrderId uint `json:"orderId"`
}

// CreateOrder @Title 创建订单
func (p *partnerLogic) CreateOrder(brokerId, kind uint) (result contractSign, err error) {
	amount := decimal.NewFromInt(2998)
	orderSn, err := common.GenNo(constant.NoPrefixPayBroker)
	if err != nil {
		return result, errors.New("单号生成失败")
	}
	orderPartner := model.OrderPartner{
		OrderSn:  orderSn,
		BrokerId: brokerId,
		Kind:     kind,
		Amount:   amount,
		Status:   model.OrderPartnerStatusUnPay,
	}
	if mysql.Db.Create(&orderPartner).Error != nil {
		return result, errors.New("合同生成失败")
	}
	result.OrderId = orderPartner.Id
	return
}

// ContractSign @Title 合同签订
func (p *partnerLogic) ContractSign(brokerId uint, sign string) (result contractSign, err error) {
	contractSn, err := common.GenNo(constant.NoPrefixContractBroker)
	if err != nil {
		return result, errors.New("签订失败")
	}
	contractPartner := model.ContractPartner{
		BrokerId:   brokerId,
		ContractSn: contractSn,
		Sign:       sign,
	}
	amount := decimal.NewFromInt(2998)
	orderSn, err := common.GenNo(constant.NoPrefixPayBroker)
	if err != nil {
		return result, errors.New("充值失败")
	}
	orderPartner := model.OrderPartner{
		OrderSn:  orderSn,
		BrokerId: brokerId,
		Amount:   amount,
		Status:   model.OrderPartnerStatusUnPay,
	}
	if err := mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Create(&contractPartner).Error != nil {
			return errors.New("签订失败")
		}
		orderPartner.ContractId = contractPartner.Id
		if tx.Create(&orderPartner).Error != nil {
			return errors.New("签订失败")
		}
		return nil
	}); err != nil {
		return result, err
	}
	result.OrderId = orderPartner.Id
	return
}

// Pay @Title app支付
func (p *partnerLogic) Pay(brokerId, orderId, payType uint) (result interface{}, err error) {
	orderPartner := model.OrderPartner{Id: orderId, BrokerId: brokerId}
	if mysql.Db.Where(&orderPartner).First(&orderPartner).Error != nil {
		return result, errors.New("订单错误")
	}
	if orderPartner.Status == model.OrderPartnerStatusPay {
		return result, errors.New("已支付，请勿重复操作")
	}
	return pay.PayLogic.Pay(orderId, model.PayOrderTypePartner, payType, orderPartner.Amount, "成为合伙人", "")
}

type orderInfo struct {
	BrokerId   uint   `json:"brokerId"`
	Kind       uint   `json:"kind"`
	OrderSn    string `json:"orderSn"`
	Status     uint   `json:"status"`
	StatusName string `json:"statusName"`
}

// OrderInfo @Title 订单详情
func (p *partnerLogic) OrderInfo(brokerId, orderId uint) (result orderInfo, err error) {
	orderPartner := model.OrderPartner{Id: orderId, BrokerId: brokerId}
	if mysql.Db.First(&orderPartner).Error != nil {
		return result, errors.New("订单错误")
	}
	result = orderInfo{
		BrokerId:   orderPartner.BrokerId,
		Kind:       orderPartner.Kind,
		OrderSn:    orderPartner.OrderSn,
		Status:     orderPartner.Status,
		StatusName: orderPartner.GetStatusName(orderPartner.Status),
	}
	return
}
