package user

import (
	"base/app/lib/invite"
	broker2 "base/app/logic/broker"
	"base/app/logic/broker/customer"
	"base/app/logic/broker/user/wallet"
	"base/app/model"
	"errors"
	"fmt"
	"git.oa00.com/go/mysql"
	"github.com/gin-gonic/gin"
	"github.com/shopspring/decimal"
)

var UserLogic = &userLogic{}

type userLogic struct {
}

type BrokerAllSearch struct {
	Name  string
	Phone string
}

type brokerAllItem struct {
	Id      uint         `json:"id"`
	Name    string       `json:"name"`
	Brokers []brokerItem `json:"brokers"`
}
type brokerItem struct {
	Id       uint   `json:"id"`
	NickName string `json:"nickName"`
	Phone    string `json:"phone"`
	Gender   uint   `json:"gender"`
}

// AllBroker @Title 全部经纪人
func (u *userLogic) AllBroker(searchData BrokerAllSearch) (result []brokerAllItem) {
	var brokers []model.Broker
	where := mysql.Db
	if searchData.Name != "" {
		where = where.Where("nickname like ?", fmt.Sprintf("%%%s%%", searchData.Name))
	}
	if searchData.Phone != "" {
		where = where.Where("phone like ?", fmt.Sprintf("%%%s%%", searchData.Phone))
	}
	mysql.Db.Preload("Business").Where(where).Find(&brokers)

	var resultBusinessBrokers = map[uint][]brokerItem{}
	var resultBaseBrokers []brokerItem
	var resultPartnerBrokers []brokerItem
	var resultAll = map[uint]brokerAllItem{}
	for _, broker := range brokers {
		switch broker.Level {
		case model.BrokerLevelBase: // 基础用户
			resultBaseBrokers = append(resultBaseBrokers, brokerItem{
				Id:       broker.Id,
				NickName: broker.Nickname,
				Phone:    broker.Phone,
				Gender:   broker.Gender,
			})
		case model.BrokerLevelPartner: // 独立合伙人
			resultPartnerBrokers = append(resultPartnerBrokers, brokerItem{
				Id:       broker.Id,
				NickName: broker.Nickname,
				Phone:    broker.Phone,
				Gender:   broker.Gender,
			})
		case model.BrokerLevelBusiness: // 入驻商
			resultAll[broker.BusinessId] = brokerAllItem{
				Id:   broker.Business.Id,
				Name: broker.Business.Name,
			}
			resultBusinessBrokers[broker.BusinessId] = append(resultBusinessBrokers[broker.BusinessId], brokerItem{
				Id:       broker.Id,
				NickName: broker.Nickname,
				Phone:    broker.Phone,
				Gender:   broker.Gender,
			})
		}

	}
	result = append(result, brokerAllItem{
		Name:    "基础用户",
		Brokers: resultBaseBrokers,
	})
	result = append(result, brokerAllItem{
		Name:    "独立合伙人",
		Brokers: resultPartnerBrokers,
	})
	for u, item := range resultAll {
		result = append(result, brokerAllItem{
			Id:      item.Id,
			Name:    item.Name,
			Brokers: resultBusinessBrokers[u],
		})
	}

	return

}

type brokerInfo struct {
	Id              uint   `json:"id"`
	Nickname        string `json:"nickname"` //昵称
	Phone           string `json:"phone"`    //手机号
	Gender          uint   `json:"gender"`
	BusinessId      uint   `json:"businessId"`      // 所属入驻商
	BusinessNo      string `json:"businessNo"`      // 入驻商编号
	BusinessName    string `json:"businessName"`    // 入驻商名称
	BusinessAddress string `json:"businessAddress"` // 公司地址
	BusinessPhone   string `json:"businessPhone"`   // 公司联系电话
	RoleName        string `json:"roleName"`        // 角色名称
}

// Search @Title 搜索经纪人
func (u *userLogic) Search(Phone string) (result brokerInfo, err error) {
	broker := model.Broker{Phone: Phone}
	if mysql.Db.Where(broker).Preload("Staff.Role").Preload("Business").First(&broker).Error != nil {
		return result, errors.New("经纪人查询错误")
	}
	//if broker.Staff != nil {
	result = brokerInfo{
		Id:              broker.Id,
		Nickname:        broker.Nickname,
		Phone:           broker.Phone,
		Gender:          broker.Gender,
		RoleName:        broker.Staff.Role.Name,
		BusinessId:      broker.BusinessId,
		BusinessNo:      broker.Business.BusinessNo,
		BusinessName:    broker.Business.Name,
		BusinessAddress: broker.Business.Address,
		BusinessPhone:   broker.Business.LiaisonPhone,
	}

	//}
	return
}

type userInfo struct {
	InviteCode string       `json:"inviteCode"`
	Nickname   string       `json:"nickname"`
	HeadImg    string       `json:"headImg"`
	Level      uint         `json:"level"`
	Phone      string       `json:"phone"`
	Gender     uint         `json:"gender"`
	IsReal     uint         `json:"isReal"`
	Data       userData     `json:"data"`
	Business   userBusiness `json:"business"`
	Partner    userPartner  `json:"partner"`
}

type userData struct {
	AssessCount         int             `json:"assessCount"`
	AssessContractCount int             `json:"assessContractCount"`
	Balance             decimal.Decimal `json:"balance"`
	InviteCount         int             `json:"inviteCount"`
}

type userBusiness struct {
	BusinessId      uint            `json:"businessId"`
	BusinessName    string          `json:"businessName"`
	BusinessAddress string          `json:"businessAddress"`
	BusinessCompany businessCompany `json:"BusinessCompany"`
	StoreId         uint            `json:"storeId"`
	StoreName       string          `json:"storeName"`
	RoleId          uint            `json:"roleId"`
	RoleName        string          `json:"roleName"`
}

type userPartner struct {
	IsPartner  uint  `json:"isPartner"`
	ExpireDate int64 `json:"expireDate"`
}

type businessCompany struct {
	Id                   uint            `json:"id"`
	Name                 string          `json:"name"`                 // 名称
	RegisteredCapital    decimal.Decimal `json:"registeredCapital"`    // 注册资本
	Quality              string          `json:"quality"`              // 性质 1=企业 2=个体工商户
	StorePhoto           string          `json:"storePhoto"`           // 门店照
	BusinessLicensePhoto string          `json:"businessLicensePhoto"` // 营业执照
	BusinessLicenseNo    string          `json:"businessLicenseNo"`    // 营业执照号
	BusinessTermStart    int64           `json:"businessTermStart"`    // 营业期限开始
	BusinessTermEnd      int64           `json:"businessTermEnd"`      // 营业期限截止
	LegalPerson          string          `json:"legalPerson"`          // 法人
	LegalPersonCard      string          `json:"legalPersonCard"`      // 法人身份证号
	IdCardFront          string          `json:"idCardFront"`          // 身份证正面
	IdCardBack           string          `json:"idCardBack"`           // 身份证反面
}

// Info @Title 用户详情
func (u *userLogic) Info(broker *model.Broker) (result userInfo) {

	result = userInfo{
		InviteCode: invite.Gen(int(broker.Id), 10),
		Nickname:   broker.Nickname,
		HeadImg:    broker.HeadImg,
		Level:      broker.Level,
		Phone:      broker.Phone,
		Gender:     broker.Gender,
		IsReal:     broker.IsReal,
		Data: userData{
			AssessCount:         wallet.AssessLogic.Count(*broker, model.WalletAssessKindEstimate),
			AssessContractCount: wallet.AssessLogic.Count(*broker, model.WalletAssessKindContract),
			Balance:             decimal.Zero,
			InviteCount:         int(customer.CustomerLogic.Count([]uint{broker.Id}).TotalCount),
		},
	}
	switch broker.Level {
	case model.BrokerLevelPartner:
		partner := model.BrokerPartner{BrokerId: broker.Id}
		mysql.Db.Where(&partner).First(&partner)
		result.Partner.IsPartner = 1
		result.Partner.ExpireDate = partner.ExpireDate.Unix()
	case model.BrokerLevelBusiness:
		staff := model.BrokerBusinessStoreStaff{BrokerId: broker.Id, Status: model.BrokerBusinessStoreStaffStatusEnabled}
		mysql.Db.Preload("Business").Preload("Store").Preload("Role").Where(&staff).First(&staff)
		if staff.Id > 0 {
			result.Business = userBusiness{
				BusinessId:      staff.Business.Id,
				BusinessName:    staff.Business.Name,
				BusinessAddress: staff.Business.Address,
				StoreId:         staff.Store.Id,
				StoreName:       staff.Store.Name,
				RoleId:          staff.Role.Id,
				RoleName:        staff.Role.Name,
			}
		}
		if staff.BrokerId == staff.Business.OwnerBrokerId {
			company := model.BrokerBusinessCompany{BusinessId: staff.Business.Id}
			if mysql.Db.Model(&company).First(&company).Error == nil {
				result.Business.BusinessCompany = businessCompany{
					Id:                   company.Id,
					Name:                 company.Name,
					RegisteredCapital:    company.RegisteredCapital,
					Quality:              company.GetQualityName(company.Quality),
					StorePhoto:           company.StorePhoto,
					BusinessLicensePhoto: company.BusinessLicensePhoto,
					BusinessLicenseNo:    company.BusinessLicenseNo,
					BusinessTermStart:    company.BusinessTermStart.Unix(),
					BusinessTermEnd:      company.BusinessTermEnd.Unix(),
					LegalPerson:          company.LegalPerson,
					LegalPersonCard:      company.LegalPersonCard,
					IdCardFront:          company.IdCardFront,
					IdCardBack:           company.IdCardBack,
				}
			}
		}
	}
	return
}

type UserUpdate struct {
	Nickname string
	HeadImg  string
	Gender   uint
}

// Update @Title 更新用户信息
func (u *userLogic) Update(brokerId uint, data UserUpdate) error {
	if mysql.Db.Updates(&model.Broker{
		Id:       brokerId,
		Nickname: data.Nickname,
		HeadImg:  data.HeadImg,
		Gender:   data.Gender,
	}).Error != nil {
		return errors.New("更新失败")
	}
	return nil
}

// GetBrokerId @Title 获取登录账号id
func (u *userLogic) GetBrokerId(c *gin.Context) (brokerId uint) {
	if val, ok := c.Get("brokerId"); ok && val != nil {
		brokerId, _ = val.(uint)
	}
	return brokerId
}

// GetBrokerInfo @Title 获取经纪人账号信息
func (u *userLogic) GetBrokerInfo(c *gin.Context) (broker model.Broker) {
	if val, ok := c.Get("broker"); ok && val != nil {
		broker, _ = val.(model.Broker)
	}
	return
}

// GetStaffInfo @Title 获取入驻商员工信息
func (u *userLogic) GetStaffInfo(c *gin.Context) (staff model.BrokerBusinessStoreStaff) {
	if val, ok := c.Get("staff"); ok && val != nil {
		staff, _ = val.(model.BrokerBusinessStoreStaff)
	}
	return
}

// Logoff @Title 注销
func (u *userLogic) Logoff(broker *model.Broker, code string) error {
	if broker.Level != model.BrokerLevelBase {
		return errors.New("非基础用户暂无法注销")
	}
	if err := broker2.LoginLogic.AutoCode(broker.Phone, code); err != nil {
		return errors.New("验证码无效")
	}
	if mysql.Db.Delete(&model.Broker{}, "id = ? and level = ?", broker.Id, model.BrokerLevelBase).RowsAffected != 1 {
		return errors.New("注销失败")
	}
	return nil
}
