package car

import (
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
)

var ModelLogic = &modelLogic{}

type modelLogic struct {
}
type modelAllItem struct {
	Id                uint            `json:"id"`
	ModelId           uint            `json:"modelId"`
	Name              string          `json:"name"`
	Year              uint            `json:"year"`
	GuidePrice        decimal.Decimal `json:"guidePrice"`
	DischargeStandard string          `json:"dischargeStandard"`
	MarketDate        string          `json:"marketDate"`
}

// All @Title 车系下所有车型
func (m *modelLogic) All(seriesId uint) (result []modelAllItem) {
	result = []modelAllItem{}
	var carModels []model.CarModel
	mysql.Db.Where("series_id = ?", seriesId).Order("year desc,id desc").Find(&carModels)
	for _, carModel := range carModels {
		result = append(result, modelAllItem{
			Id:                carModel.Id,
			ModelId:           carModel.ModelId,
			Name:              carModel.Name,
			Year:              carModel.Year,
			GuidePrice:        carModel.Price,
			DischargeStandard: carModel.DischargeStandard,
			MarketDate:        carModel.MarketDate,
		})
	}
	return
}

type ModelInfo struct {
	Year              uint            `json:"year"`              // 年份
	Price             decimal.Decimal `json:"price"`             // 指导价
	Liter             decimal.Decimal `json:"liter"`             // 排量
	DischargeStandard string          `json:"dischargeStandard"` // 排放标准
	FuelTypeName      string          `json:"fuelTypeName"`      // 燃料类型名称
	EnginePower       uint            `json:"enginePower"`       // 马力
	EnginePowerKw     uint            `json:"enginePowerKw"`     // 马力转换功率
	IsGreen           uint            `json:"isGreen"`           // 是否新能源车 0=否 1=是
	ModelCode         string          `json:"modelCode"`         // 汽车公告型号
	DriveName         string          `json:"driveName"`         // 驱动类型
	DriveType         string          `json:"driveType"`         // 驱动类型
	ModelStatus       string          `json:"modelStatus"`       // 车型状态 在售/停售等
	GearType          string          `json:"gearType"`          // 变速箱类型 手动/自动
	MarketDate        string          `json:"marketDate"`        // 生产日期
	MinRegYear        string          `json:"minRegYear"`        // 最小注册年
	MaxRegYear        string          `json:"maxRegYear"`        // 最大注册年
	StopMakeYear      string          `json:"stopMakeYear"`      // 车型停产年份
	Intake            string          `json:"intake"`            // 进气形式
	SeatNumber        string          `json:"seatNumber"`        // 座位数
	BodyType          string          `json:"bodyType"`          // 车身类型
	DoorNumber        uint            `json:"doorNumber"`        // 门数
	CarStruct         string          `json:"carStruct"`         // 车辆结构
	IsParallel        uint            `json:"isParallel"`        // 是否平行进口车 0=否 1=是
	PriceAllowance    string          `json:"priceAllowance"`    // 新能源车补贴
}

// Info @Title 车型详情
func (m *modelLogic) Info(modelId uint) (result ModelInfo, err error) {
	carModel := model.CarModel{ModelId: modelId}
	if mysql.Db.Where(carModel).Find(&carModel).Error != nil {
		err = errors.New("查找车型失败")
		return
	}
	result = ModelInfo{
		Year:              carModel.Year,
		Price:             carModel.Price,
		Liter:             carModel.Liter,
		DischargeStandard: carModel.DischargeStandard,
		FuelTypeName:      carModel.FuelTypeName,
		EnginePower:       carModel.EnginePower,
		EnginePowerKw:     carModel.EnginePowerKw,
		IsGreen:           carModel.IsGreen,
		ModelCode:         carModel.ModelCode,
		DriveName:         carModel.DriveName,
		DriveType:         carModel.DriveType,
		ModelStatus:       carModel.ModelStatus,
		GearType:          carModel.GearType,
		MarketDate:        carModel.MarketDate,
		MinRegYear:        carModel.MinRegYear,
		MaxRegYear:        carModel.MaxRegYear,
		StopMakeYear:      carModel.StopMakeYear,
		Intake:            carModel.Intake,
		SeatNumber:        carModel.SeatNumber,
		BodyType:          carModel.BodyType,
		DoorNumber:        carModel.DoorNumber,
		CarStruct:         carModel.CarStruct,
		IsParallel:        carModel.IsParallel,
		PriceAllowance:    carModel.PriceAllowance,
	}
	return
}

func (m *modelLogic) Find(vin string) {
	//vinModel, err := che300.Api.VinModel(vin)
}
