package car

import (
	"base/app/config"
	"base/app/lib/bean"
	"base/app/lib/invite"
	"base/app/logic/car"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
	"gorm.io/gorm"
)

var CarLogic = &carLogic{}

type carLogic struct {
}
type carItem struct {
	Id            uint            `json:"id"`
	ModelName     string          `json:"modelName"`
	Type          uint            `json:"type"`
	MainPhoto     string          `json:"mainPhoto"`
	LicensingDate int64           `json:"licensingDate"`
	Price         decimal.Decimal `json:"price"`
	DownPayment   decimal.Decimal `json:"downPayment"`
	Mileage       decimal.Decimal `json:"mileage"`
	Transfer      uint            `json:"transfer"`
	Collect       uint            `json:"collect"`
}

// Lists @Title 车辆列表
func (c *carLogic) Lists(customerId uint, search car.CarSearch, order car.CarOrder, page bean.Page) (lists []carItem, total int64) {
	lists = []carItem{}
	search.Status = []uint{model.CarStatusNormal}
	search.TheUpper = model.CarTheUpperTrue
	var carIds []uint
	var items []car.CarItem
	// 仅有status和keyword筛选参数时，才会走es搜索
	if search.BrokerId != 0 ||
		search.CarType != 0 ||
		search.BrandId != 0 ||
		search.SeriesId != 0 ||
		!search.MinPrice.IsZero() ||
		!search.MaxPrice.IsZero() ||
		search.MinMileage != 0 ||
		search.MaxMileage != 0 ||
		!search.MinLiter.IsZero() ||
		!search.MaxLiter.IsZero() ||
		search.MinTransfer != 0 ||
		search.MaxTransfer != 0 ||
		search.Struct != "" ||
		search.FuelType != 0 ||
		search.GearType != 0 ||
		search.MinSeat != 0 ||
		search.MaxSeat != 0 ||
		search.Year != 0 ||
		search.MinAge != 0 ||
		search.MaxAge != 0 ||
		search.MinLicensingDateYear != 0 ||
		search.LocationProvinceId != 0 ||
		search.LocationCityId != 0 ||
		search.DischargeStandard != "" ||
		search.Color != "" ||
		len(search.CarIds) > 0 ||
		len(search.StoreIds) > 0 ||
		len(config.Config.OpenSearch.Addresses) == 0 ||
		!config.IsProd() {
		items, total = car.CarLogic.Lists(search, order, page)
	} else {
		items, total = car.CarLogic.ListsEs(car.ListsEsSearch{
			Keyword:  search.Keyword,
			Status:   search.Status,
			TheUpper: search.TheUpper,
		}, page)
	}
	for _, item := range items {
		carIds = append(carIds, item.Id)
	}

	mCarCollect := map[uint]uint{}
	if len(carIds) > 0 && customerId > 0 {
		var collectCars []model.CustomerCollectCar
		mysql.Db.Where("customer_id = ? and car_id in ?", customerId, carIds).Find(&collectCars)
		for _, collectCar := range collectCars {
			mCarCollect[collectCar.CarId] = 1
		}
	}
	for _, item := range items {
		lists = append(lists, carItem{
			Id:            item.Id,
			ModelName:     item.ModelName,
			Type:          item.Type,
			MainPhoto:     item.MainPhoto,
			LicensingDate: item.LicensingDate,
			Price:         item.Price,
			DownPayment:   item.DownPayment,
			Mileage:       item.Mileage,
			Transfer:      item.Transfer,
			Collect:       mCarCollect[item.Id],
		})
	}
	return
}

// Info @Title 车辆详情
func (c *carLogic) Info(customerId, carId uint, inviteCode string) (interface{}, error) {
	info, err := car.CarLogic.Info(false, carId)
	car.CarLogic.BrowserEvent(mysql.Db, carId)
	if customerId > 0 && err == nil {
		collectCar := model.CustomerCollectCar{}
		if mysql.Db.Where("customer_id = ? and car_id = ?", customerId, carId).First(&collectCar).Error == nil {
			info.IsCollect = 1
		}
		// 已注册
		var shareId uint
		if inviteCode != "" {
			shareId = uint(invite.Decode(inviteCode))
		}
		mysql.Db.Transaction(func(tx *gorm.DB) error {
			if tx.Create(&model.CustomerBrowseCar{
				CarId:      carId,
				CustomerId: customerId,
				ShareId:    shareId,
				Channel:    model.CustomerBrowseCarChannelWxapp,
			}).Error != nil {
				return errors.New("系统错误")
			}
			if tx.Model(&model.Customer{}).Where("id = ? and level < ?", customerId, model.CustomerLevelBrowse).UpdateColumn("level", model.CustomerLevelBrowse).Error != nil {
				return errors.New("系统错误")
			}
			return nil
		})
	}
	return info, err
}
