package car

import (
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
	"gorm.io/gorm"
)

var CollectLogic = &collectLogic{}

type collectLogic struct {
}
type collectListsItem struct {
	CarId       uint            `json:"carId"`
	ModelName   string          `json:"modelName"`
	MainPhoto   string          `json:"mainPhoto"`
	Type        uint            `json:"type"`
	Mileage     decimal.Decimal `json:"mileage"`
	Transfer    uint            `json:"transfer"`
	Price       decimal.Decimal `json:"price"`
	DownPayment decimal.Decimal `json:"downPayment"`
	CreatedAt   int64           `json:"createdAt"`
}

// Lists @Title 收藏列表
func (c *collectLogic) Lists(customerId uint, page bean.Page) (lists []collectListsItem, total int64) {
	lists = []collectListsItem{}
	var collectCars []model.CustomerCollectCar
	where := mysql.Db.Where("customer_id = ?", customerId)
	mysql.Db.Model(&collectCars).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("Car.Model").Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Find(&collectCars)
		for _, collectCar := range collectCars {
			lists = append(lists, collectListsItem{
				CarId:       collectCar.CarId,
				ModelName:   collectCar.Car.Model.Name,
				MainPhoto:   collectCar.Car.MainPhoto,
				Type:        collectCar.Car.Type,
				Mileage:     collectCar.Car.Mileage,
				Transfer:    collectCar.Car.Transfer,
				Price:       collectCar.Car.Price,
				DownPayment: collectCar.Car.DownPayment,
				CreatedAt:   collectCar.CreatedAt.Unix(),
			})
		}
	}
	return
}

// Add @Title 收藏车辆
func (c *collectLogic) Add(customerId, carId uint) error {
	car := model.Car{Id: carId}
	if mysql.Db.First(&car).Error != nil {
		return errors.New("车辆错误")
	}
	collectCar := model.CustomerCollectCar{
		CustomerId: customerId,
		CarId:      carId,
	}
	mysql.Db.Where(&collectCar).First(&collectCar)
	if collectCar.Id > 0 {
		return nil
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Create(&collectCar).Error != nil {
			return errors.New("收藏失败")
		}
		carDataUpd := tx.Model(&model.CarData{}).Where("car_id = ?", car.Id).UpdateColumns(map[string]interface{}{
			"collect": gorm.Expr("collect + ?", 1),
		})
		if carDataUpd.RowsAffected > 1 {
			return errors.New("车辆收藏数据更新失败")
		}
		if carDataUpd.RowsAffected == 0 {
			carData := model.CarData{CarId: car.Id, Collect: 1}
			if tx.Create(&carData).Error != nil {
				return errors.New("车辆收藏数据更新失败")
			}
		}

		return nil
	})

}

// Cancel @Title 取消收藏车辆
func (c *collectLogic) Cancel(customerId, carId uint) error {
	collectCar := model.CustomerCollectCar{
		CustomerId: customerId,
		CarId:      carId,
	}
	if mysql.Db.Where(&collectCar).First(&collectCar).Error != nil {
		return nil
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Delete(&collectCar).Error != nil {
			return errors.New("取消收藏失败")
		}
		if tx.Model(&model.CarData{}).Where("car_id = ?", carId).UpdateColumns(map[string]interface{}{
			"collect": gorm.Expr("collect - ?", 1),
		}).RowsAffected != 1 {
			return errors.New("车辆收藏数据更新失败")
		}
		return nil
	})
}
