package contract

import (
	"base/app/constant"
	"base/app/lib/bean"
	"base/app/model"
	"fmt"
	"git.oa00.com/go/mysql"
)

var ConsignmentLogic = &consignmentLogic{}

type consignmentLogic struct {
}

type contractItem struct {
	Id         uint   `json:"id"`
	ContractSn string `json:"contractSn"`
	ModelName  string `json:"modelName"`
	Status     uint   `json:"status"`
	StatusName string `json:"statusName"`
	SignAt     int64  `json:"signAt"`
	EssFileUrl string `json:"essFileUrl"`
}
type ConsignmentSearch struct {
	Status     uint
	ContractSn string
}

// Lists @Title 合同列表
func (c *consignmentLogic) Lists(customerId uint, search ConsignmentSearch, page bean.Page) (lists []contractItem, total int64) {
	lists = []contractItem{}
	var contracts []model.ContractConsignment
	where := mysql.Db.Where("customer_id = ?", customerId)
	if search.Status > 0 {
		var status []uint
		switch search.Status {
		case constant.ContractStatusCreate: // 未签名
			status = []uint{constant.ContractStatusCreate}
		case constant.ContractStatusSign: // 已签名
			status = []uint{constant.ContractStatusSign}
		case constant.ContractStatusReject: // 已拒签
			status = []uint{constant.ContractStatusReject}
		case constant.ContractStatusCancel: // 已撤回
			status = []uint{constant.ContractStatusCancel}
		case constant.ContractStatusDeadline: // 已过期
			status = []uint{constant.ContractStatusDeadline}
		case constant.ContractStatusException: // 异常
			status = []uint{constant.ContractStatusException}
		}
		if len(status) > 0 {
			where = where.Where("status in ?", status)
		}
	}
	if search.ContractSn != "" {
		where = where.Where("contract_sn like ?", fmt.Sprintf("%%%s%%", search.ContractSn))
	}
	mysql.Db.Model(&contracts).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("Model").Preload("EssFlow").Where(where).Offset(page.GetStart()).Order("id desc").Limit(page.GetLimit()).Find(&contracts)
		for _, item := range contracts {
			lists = append(lists, contractItem{
				Id:         item.Id,
				ContractSn: item.ContractSn,
				ModelName:  item.Model.Name,
				Status:     item.Status,
				StatusName: constant.GetContractStatusName(item.Status),
				SignAt:     item.SignAt.Time.Unix(),
				EssFileUrl: item.EssFlow.Url,
			})
		}
	}
	return
}
