package message

import (
	"base/app/lib/bean"
	"base/app/lib/websocket"
	"base/app/model"
	"encoding/json"
	"errors"
	"fmt"
	"git.oa00.com/go/mysql"
	"gorm.io/gorm"
	"log"
)

var MessageLogic = &messageLogic{}

type messageLogic struct {
}

type MessageItem struct {
	Title   string                 `json:"title"`
	Content string                 `json:"content"`
	Extras  map[string]interface{} `json:"extras"`
}

type messageListItem struct {
	Id           uint   `json:"id"`
	Type         uint   `json:"type"`
	Status       uint   `json:"status"`
	Title        string `json:"title"`
	Content      string `json:"content"`
	SenderUserId uint   `json:"senderUserId"`
	CreatedAt    int64  `json:"createdAt"`
}

// Lists @Title 消息列表
func (m *messageLogic) Lists(customerIds []uint, messageType uint, page bean.Page) (lists []messageListItem, total int64) {
	lists = []messageListItem{}
	var customerMessage []model.CustomerMessage
	where := mysql.Db.Where("customer_id in ?", customerIds)
	if messageType > 0 {
		where = where.Where("type = ?", messageType)
	}
	mysql.Db.Model(&customerMessage).Where(where).Count(&total)
	if page.HasPage(total) {
		queryModel := mysql.Db.Where(where).Offset(page.GetStart()).Limit(page.GetLimit())
		queryModel.Find(&customerMessage)
		for _, item := range customerMessage {
			lists = append(lists, messageListItem{
				Id:           item.Id,
				Type:         item.Type,
				Status:       item.Status,
				Title:        item.Title,
				Content:      item.Content,
				SenderUserId: item.SenderUserId,
				CreatedAt:    item.CreatedAt.Unix(),
			})
		}
	}
	return
}

type CountMessage struct {
	Type     uint   `json:"type"`
	TypeName string `json:"typeName"`
	Count    uint   `json:"count"`
	Title    string `json:"title"`
	Content  string `json:"content"`
}

// Count @Title 未读消息统计
func (m *messageLogic) Count(customerIds []uint) (result []CountMessage) {
	var messageCounts []CountMessage
	mysql.Db.Model(&model.CustomerMessage{}).
		Where("id in (?)", mysql.Db.Model(&model.CustomerMessage{}).
			Where("customer_id in ?", customerIds).
			Select("SUBSTRING_INDEX(group_concat( id order by created_at desc),',',1)").
			Group("type")).
		Select("type,title,content").
		Find(&messageCounts)
	cm := model.CustomerMessage{}
	for _, item := range messageCounts {
		item.TypeName = cm.GetTypeName(item.Type)
		result = append(result, item)
	}
	mysql.Db.Model(&model.CustomerMessage{}).Where("customer_id in ?", customerIds).
		Select("type,count(id) count").
		Group("type").Find(&messageCounts)
	for i, r := range result {
		for _, item := range messageCounts {
			if r.Type == item.Type {
				result[i].Count = item.Count
			}
		}
	}
	return
}

type messageInfo struct {
	Id           uint   `json:"id"`
	Type         uint   `json:"type"`
	Status       uint   `json:"status"`
	Title        string `json:"title"`
	Content      string `json:"content"`
	SenderUserId uint   `json:"senderUserId"`
	CreatedAt    int64  `json:"createdAt"`
}

// Info @Title 消息详情
func (m *messageLogic) Info(customerIds []uint, messageId uint) (result messageInfo, err error) {
	customerMessage := model.CustomerMessage{}
	if mysql.Db.Where("id = ? and customer_id in ?", messageId, customerIds).First(&customerMessage).Error != nil {
		return result, errors.New("客户错误")
	}
	result = messageInfo{
		Id:           customerMessage.Id,
		Type:         customerMessage.Type,
		Status:       customerMessage.Status,
		Title:        customerMessage.Title,
		Content:      customerMessage.Content,
		SenderUserId: customerMessage.SenderUserId,
		CreatedAt:    customerMessage.CreatedAt.Unix(),
	}
	return
}

// TestSend @Title 发送消息
func (m *messageLogic) TestSend(customerIds []uint, item MessageItem) {
	log.Println("测试发送消息")
	log.Println(customerIds)
	log.Println(item.Title)
	log.Println(item.Content)
	log.Println(item.Extras)
	m.sendToCustomer(customerIds, item)
	return
}

// MessageToBroker @Title 发送消息步骤
func (m *messageLogic) MessageToBroker(tx *gorm.DB, brokerId, customerId, messageType uint, item MessageItem) error {
	brokerMessage := model.BrokerMessage{
		BrokerId:     brokerId,
		Type:         messageType,
		Status:       model.BrokerMessageStatusNotRead,
		SenderUserId: customerId,
		Title:        item.Title,
		Content:      item.Content,
	}
	if tx.Create(&brokerMessage).Error != nil {
		return errors.New("发送消息失败")
	}
	m.sendToBroker([]uint{brokerId}, item)
	return nil
}

// sendToCustomer @Title 发送消息到客户
func (m *messageLogic) sendToCustomer(customerIds []uint, item MessageItem) {
	body, _ := json.Marshal(&item)
	for _, customerId := range customerIds {
		websocket.WebsocketManager.SendGroup(fmt.Sprintf(websocket.CustomerKey, customerId), body)
	}
}

// SendToBroker @Title 发送消息到经纪人
func (m *messageLogic) sendToBroker(brokerIds []uint, item MessageItem) {
	body, _ := json.Marshal(&item)
	for _, brokerIdItem := range brokerIds {
		websocket.WebsocketManager.SendGroup(fmt.Sprintf(websocket.BrokerKey, brokerIdItem), body)
	}
}

//// Send @Title 发送消息
//func (m *messageLogic) Send(manageIds []uint, item MessageItem) {
//	log.Println(m)
//	m.sendWebsocket(manageIds, item)
//	return
//}
//
//// @Title 发送websocket消息
//func (m *messageLogic) sendWebsocket(manageIds []uint, item MessageItem) {
//	body, _ := json.Marshal(&item)
//	for _, manageId := range manageIds {
//		websocket.WebsocketManager.SendGroup(fmt.Sprintf(CustomerKey, manageId), body)
//	}
//}
