package order

import (
	"base/app/lib/bean"
	"base/app/logic/customer/message"
	"base/app/logic/customer/record"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
	"gorm.io/gorm"
	"time"
)

var ReserveLogic = &reserveLogic{}

type reserveLogic struct {
}
type reserveItem struct {
	Id            uint            `json:"id"`
	CreatedAt     int64           `json:"createdAt"`
	MainPhoto     string          `json:"mainPhoto"`
	ModelName     string          `json:"modelName"`
	LicensingDate int64           `json:"licensingDate"`
	Mileage       decimal.Decimal `json:"mileage"`
	Price         decimal.Decimal `json:"price"`
	Transfer      uint            `json:"transfer"`
	ReserveAt     int64           `json:"reserveAt"`
	Address       string          `json:"address"`
}

// Lists @Title 直卖预约
func (r *reserveLogic) Lists(customerId uint, page bean.Page) (lists []reserveItem, total int64) {
	lists = []reserveItem{}
	var reserves []model.OrderReserve
	where := mysql.Db.Where("customer_id = ?", customerId)
	mysql.Db.Model(&reserves).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("Price.Model.Brand").Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("id desc").Find(&reserves)
		for _, reserve := range reserves {
			lists = append(lists, reserveItem{
				Id:            reserve.Id,
				CreatedAt:     reserve.CreatedAt.Unix(),
				MainPhoto:     reserve.Price.Model.Brand.Icon,
				ModelName:     reserve.Price.Model.Name,
				LicensingDate: reserve.Price.LicensingDate.Unix(),
				Mileage:       reserve.Price.Mileage,
				Price:         reserve.Price.Price,
				Transfer:      reserve.Price.Transfer,
				ReserveAt:     reserve.ReserveAt.Unix(),
				Address:       reserve.Address,
			})
		}
	}
	return
}

// Add @Title 预约卖车
func (r *reserveLogic) Add(customerId, brokerId, priceId uint, reserveTime, address string) error {
	broker := model.Broker{Id: brokerId}
	mysql.Db.First(&broker)
	if broker.Level != model.BrokerLevelBusiness {
		// 随机经纪人
	}
	reserveAt, err := time.ParseInLocation("2006-01-02 15:04:05", reserveTime, time.Local)
	if err != nil {
		return errors.New("预约时间错误")
	}
	reserve := model.OrderReserve{
		CustomerId: customerId,
		BrokerId:   brokerId,
		PriceId:    priceId,
		ReserveAt:  reserveAt,
		Address:    address,
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Create(&reserve).Error != nil {
			return errors.New("预约失败")
		}
		if err = record.TrailLogic.Add(tx, record.TrailData{
			CustomerId:    customerId,
			Type:          "直卖预约",
			InitiatorId:   customerId,
			InitiatorType: model.CustomerTrailInitiatorTypeCustomer,
			ContentType:   model.CustomerTrailContentTypeReserve,
			ContentId:     reserve.Id,
			Content:       "收到客户直卖预约",
		}); err != nil {
			return err
		}
		if err = record.InviteLogic.Add(tx, record.InviteData{
			CustomerId: customerId,
			BrokerId:   brokerId,
			Type:       model.CustomerInviteTypeReserve,
			InviteAt:   reserveAt,
		}); err != nil {
			return err
		}
		message.MessageLogic.MessageToBroker(tx, brokerId, customerId, model.BrokerMessageTypeCustomerInvite, message.MessageItem{
			Title:   "直卖预约",
			Content: "收到客户直卖预约",
		})
		return nil
	})
}
