package order

import (
	"base/app/lib/bean"
	"base/app/logic/customer/message"
	"base/app/logic/manage/setting"
	"base/app/logic/pay"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
	"gorm.io/gorm"
)

var SaleLogic = &saleLogic{}

type saleLogic struct {
}

type saleItem struct {
	Id             uint            `json:"id"`
	Status         uint            `json:"status"`
	StatusName     string          `json:"statusName"`
	CreatedAt      int64           `json:"createdAt"`
	SignAt         int64           `json:"signAt"`
	MainPhoto      string          `json:"mainPhoto"`
	ModelName      string          `json:"modelName"`
	LicensingDate  int64           `json:"licensingDate"`
	Mileage        decimal.Decimal `json:"mileage"`
	Amount         decimal.Decimal `json:"amount"`
	Deposit        decimal.Decimal `json:"deposit"`
	DownPayment    decimal.Decimal `json:"downPayment"`
	BalancePayment decimal.Decimal `json:"balancePayment"`
}
type SaleListsSearch struct {
	Status uint // 1=待签订 2=支付定金 3=待检测 4=支付首付 5=过户 6=支付尾款 7=完成 8=取消
}

// Lists @Title 买车订单
func (s *saleLogic) Lists(customerId uint, search SaleListsSearch, page bean.Page) (lists []saleItem, total int64) {
	lists = []saleItem{}
	var orderSales []model.OrderSale
	where := mysql.Db.Where("customer_id = ?", customerId)
	if search.Status > 0 {
		var status []uint
		switch search.Status {
		case 1: // 待签订
			status = []uint{model.OrderSaleStatusUnSign}
		case 2: // 支付定金
			status = []uint{model.OrderSaleStatusSign}
		case 3: // 待检测
			status = []uint{model.OrderSaleStatusDeposit, model.OrderSaleStatusTestReport}
		case 4: // 支付首付
			status = []uint{model.OrderSaleStatusUploadTestReport, model.OrderSaleStatusDownPaymentAudit, model.OrderSaleStatusDownPaymentAdopt}
		case 5: // 过户
			status = []uint{model.OrderSaleStatusTransfer}
		case 6: // 支付尾款
			status = []uint{model.OrderSaleStatusTransferFinal, model.OrderSaleStatusBalancePaymentAudit, model.OrderSaleStatusBalancePaymentAdopt}
		case 7: // 完成
			status = []uint{model.OrderSaleStatusFinal}
		case 8: // 取消
			status = []uint{model.OrderSaleStatusCancel}
		}
		if len(status) > 0 {
			where = where.Where("status in ?", status)
		}
	}
	mysql.Db.Model(&orderSales).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("Car.Model").Preload("Contract").Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("updated_at desc,id desc").Find(&orderSales)
		for _, orderSale := range orderSales {
			lists = append(lists, saleItem{
				Id:             orderSale.Id,
				Status:         orderSale.Status,
				StatusName:     orderSale.GetStatusName(orderSale.Status),
				CreatedAt:      orderSale.CreatedAt.Unix(),
				SignAt:         orderSale.Contract.SignAt.Time.Unix(),
				MainPhoto:      orderSale.Car.MainPhoto,
				ModelName:      orderSale.Car.Model.Name,
				LicensingDate:  orderSale.Car.LicensingDate.Time.Unix(),
				Mileage:        orderSale.Car.Mileage,
				Amount:         orderSale.Contract.Amount,
				Deposit:        orderSale.Contract.Deposit,
				DownPayment:    orderSale.Contract.DownPayment,
				BalancePayment: orderSale.Contract.BalancePayment,
			})
		}
	}
	return
}

//// Sign @Title 签订合同
//func (s *saleLogic) Sign(customerId, orderId uint, sign string) error {
//	orderSale := model.OrderSale{CustomerId: customerId, Id: orderId}
//	if mysql.Db.Where(&orderSale).First(&orderSale).Error != nil {
//		return errors.New("订单错误")
//	}
//	if orderSale.Status == model.OrderSaleStatusCancel {
//		return errors.New("订单已取消")
//	}
//	if orderSale.Status != model.OrderSaleStatusUnSign {
//		return errors.New("合同已签订")
//	}
//	return mysql.Db.Transaction(func(tx *gorm.DB) error {
//		if tx.Model(&orderSale).Where(&orderSale).Updates(map[string]interface{}{
//			"status": model.OrderSaleStatusSign,
//		}).RowsAffected != 1 {
//			return errors.New("签订失败")
//		}
//		if tx.Model(&model.ContractSale{}).Where("id = ?", orderSale.ContractId).Updates(map[string]interface{}{
//			"sign":    sign,
//			"status":  constant.ContractStatusSign,
//			"sign_at": sql.NullTime{Time: time.Now(), Valid: true},
//		}).RowsAffected != 1 {
//			return errors.New("签订失败")
//		}
//		message.MessageLogic.MessageToBroker(tx, orderSale.BrokerId, customerId, model.BrokerMessageTypeCustomerNormal, message.MessageItem{
//			Title:   "合同提示",
//			Content: "您的卖车合同已被用户签字"})
//		return nil
//	})
//}

// Deposit @Title 定金支付
func (s *saleLogic) Deposit(customerId, orderId uint, openId string) (result interface{}, err error) {
	orderSale := model.OrderSale{CustomerId: customerId, Id: orderId}
	if mysql.Db.Preload("Contract.Car").Where(&orderSale).First(&orderSale).Error != nil {
		return result, errors.New("订单错误")
	}
	if orderSale.Status == model.OrderSaleStatusCancel {
		return result, errors.New("订单已取消")
	}
	if orderSale.Status == model.OrderSaleStatusUnSign {
		return result, errors.New("请先签订合同")
	}
	if orderSale.Status != model.OrderSaleStatusSign {
		return result, errors.New("定金已支付")
	}
	result, err = pay.PayLogic.Pay(orderId, model.PayOrderTypeSaleDeposit, model.PayTypeWxapp, orderSale.Contract.Deposit, "买车定金", openId)
	return
}

// TestReport @Title 申请测试报告
func (s *saleLogic) TestReport(customerId, orderId uint) error {
	orderSale := model.OrderSale{Id: orderId, CustomerId: customerId}
	if mysql.Db.Where(&orderSale).First(&orderSale).Error != nil {
		return errors.New("订单错误")
	}
	if orderSale.Status == model.OrderSaleStatusTestReport {
		return errors.New("已申请，请勿重复操作")
	}
	if orderSale.Status != model.OrderSaleStatusDeposit {
		return errors.New("无法申请")
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Model(&orderSale).Where(&orderSale).UpdateColumns(map[string]interface{}{
			"status": model.OrderSaleStatusTestReport,
		}).RowsAffected != 1 {
			return errors.New("申请失败")
		}
		message.MessageLogic.MessageToBroker(tx, orderSale.BrokerId, customerId, model.BrokerMessageTypeCustomerNormal, message.MessageItem{
			Title:   "合同提示",
			Content: "您的卖车合同用户正在申请检测报告"})
		return nil
	})
}

// DownPayment @Title 支付首付
func (s *saleLogic) DownPayment(customerId, orderId uint, proof string) error {
	orderSale := model.OrderSale{Id: orderId, CustomerId: customerId}
	if mysql.Db.Preload("DownPaymentAudit").Where(&orderSale).First(&orderSale).Error != nil {
		return errors.New("订单错误")
	}
	if orderSale.Status == model.OrderSaleStatusTestReport {
		return errors.New("请等待检车报告")
	}
	if orderSale.Status < model.OrderSaleStatusDeposit {
		return errors.New("订单状态错误")
	}
	if orderSale.Status >= model.OrderSaleStatusDownPaymentAdopt {
		return errors.New("已支付首付，请勿重复操作")
	}
	if orderSale.DownPaymentAudit.Status == model.OrderSaleAuditStatusAudit {
		return errors.New("系统审核中，请等待")
	}
	saleAudit := model.OrderSaleAudit{
		OrderId: orderId,
		Type:    model.OrderSaleAuditTypeDownPayment,
		Status:  model.OrderSaleAuditStatusAudit,
		Proof:   proof,
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Create(&saleAudit).Error != nil {
			return errors.New("提交失败")
		}
		if tx.Model(&model.OrderSale{}).Where(&orderSale).UpdateColumns(map[string]interface{}{
			"down_payment_audit_id": saleAudit.Id,
			"status":                model.OrderSaleStatusDownPaymentAudit,
		}).RowsAffected != 1 {
			return errors.New("提交失败")
		}
		message.MessageLogic.MessageToBroker(tx, orderSale.BrokerId, customerId, model.BrokerMessageTypeCustomerNormal, message.MessageItem{
			Title:   "合同提示",
			Content: "您的卖车合同已被用户支付首付"})
		return nil
	})
}

// Transfer @Title 申请过户
func (s *saleLogic) Transfer(customerId, orderId uint) error {
	orderSale := model.OrderSale{Id: orderId, CustomerId: customerId}
	if mysql.Db.Where(&orderSale).First(&orderSale).Error != nil {
		return errors.New("订单错误")
	}
	if orderSale.Status < model.OrderSaleStatusDownPaymentAdopt {
		return errors.New("订单状态错误")
	}
	if orderSale.Status > model.OrderSaleStatusDownPaymentAdopt {
		return errors.New("已申请，请勿重复操作")
	}
	if mysql.Db.Model(&orderSale).Where(&orderSale).UpdateColumn("status", model.OrderSaleStatusTransfer).RowsAffected != 1 {
		return errors.New("申请失败")
	}
	message.MessageLogic.MessageToBroker(mysql.Db, orderSale.BrokerId, customerId, model.BrokerMessageTypeCustomerNormal, message.MessageItem{
		Title:   "合同提示",
		Content: "您的卖车合同用户正在申请过户"})
	return nil
}

// BalancePayment @Title 支付尾款
func (s *saleLogic) BalancePayment(customerId, orderId uint, proof string) error {
	orderSale := model.OrderSale{Id: orderId, CustomerId: customerId}
	if mysql.Db.Preload("BalancePaymentAudit").Where(&orderSale).First(&orderSale).Error != nil {
		return errors.New("订单错误")
	}
	if orderSale.Status < model.OrderSaleStatusTransferFinal {
		return errors.New("订单状态错误")
	}
	if orderSale.Status >= model.OrderSaleStatusBalancePaymentAdopt {
		return errors.New("已支付尾款，请勿重复操作")
	}
	if orderSale.BalancePaymentAudit.Status == model.OrderSaleAuditStatusAudit {
		return errors.New("系统审核中，请等待")
	}
	saleAudit := model.OrderSaleAudit{
		OrderId: orderId,
		Type:    model.OrderSaleAuditTypeBalancePayment,
		Status:  model.OrderSaleAuditStatusAudit,
		Proof:   proof,
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Create(&saleAudit).Error != nil {
			return errors.New("提交失败")
		}
		if tx.Model(&model.OrderSale{}).Where(&orderSale).UpdateColumns(map[string]interface{}{
			"balance_payment_audit_id": saleAudit.Id,
			"status":                   model.OrderSaleStatusBalancePaymentAudit,
		}).RowsAffected != 1 {
			return errors.New("提交失败")
		}
		message.MessageLogic.MessageToBroker(tx, orderSale.BrokerId, customerId, model.BrokerMessageTypeCustomerNormal, message.MessageItem{
			Title:   "合同提示",
			Content: "您的卖车合同已被用户支付尾款"})
		return nil
	})
}

type saleInfo struct {
	Id             uint               `json:"id"`
	Status         uint               `json:"status"`
	StatusName     string             `json:"statusName"`
	Car            saleCar            `json:"car"`
	Contract       saleContract       `json:"contract"`
	Bank           saleBank           `json:"bank"`
	Deposit        saleDeposit        `json:"deposit"`
	DownPayment    saleDownPayment    `json:"downPayment"`
	BalancePayment saleBalancePayment `json:"balancePayment"`
	Report         saleReport         `json:"report"`
	Means          saleMeans          `json:"means"`
}

type saleCar struct {
	CarId         uint            `json:"carId"`
	MainPhoto     string          `json:"mainPhoto"`
	ModelName     string          `json:"modelName"`
	LicensingDate int64           `json:"licensingDate"`
	Mileage       decimal.Decimal `json:"mileage"`
	Status        uint            `json:"status"`
}
type saleContract struct {
	Contract       uint            `json:"contract"`
	Amount         decimal.Decimal `json:"amount"`
	Deposit        decimal.Decimal `json:"deposit"`
	DownPayment    decimal.Decimal `json:"downPayment"`
	BalancePayment decimal.Decimal `json:"balancePayment"`
	ServiceFee     decimal.Decimal `json:"serviceFee"`
	TotalAmount    decimal.Decimal `json:"totalAmount"`
	SignAt         int64           `json:"signAt"`
}

type saleBank struct {
	AccountName string `json:"accountName"`
	BankName    string `json:"bankName"`
	BankAccount string `json:"bankAccount"`
}

type saleDeposit struct {
	Amount    decimal.Decimal `json:"amount"`
	PayType   string          `json:"payType"`
	CreatedAt int64           `json:"createdAt"`
}

type saleDownPayment struct {
	Amount    decimal.Decimal `json:"amount"`
	Proof     string          `json:"proof"`
	CreatedAt int64           `json:"createdAt"`
}

type saleBalancePayment struct {
	Amount    decimal.Decimal `json:"amount"`
	Proof     string          `json:"proof"`
	CreatedAt int64           `json:"createdAt"`
}

type saleReport struct {
	ReportId uint   `json:"reportId"`
	Path     string `json:"path"`
}

type saleMeans struct {
	TransferId     uint   `json:"transferId"`
	Certificate    string `json:"certificate"`
	VehicleLicense string `json:"vehicleLicense"`
	Invoice        string `json:"invoice"`
	GuaranteeSlip  string `json:"guaranteeSlip"`
}

// Info @Title 订单详情
func (s *saleLogic) Info(customerId uint, orderId uint) (result saleInfo, err error) {
	orderSale := model.OrderSale{Id: orderId, CustomerId: customerId}
	if mysql.Db.
		Preload("Car.Model").Preload("Contract").
		Preload("DepositPay").Preload("DownPaymentAudit").Preload("BalancePaymentAudit").
		Preload("Report").Preload("Transfer").
		Where(&orderSale).First(&orderSale).Error != nil {
		return result, errors.New("订单错误")
	}
	system := setting.SystemLogic.GetSystem()
	result = saleInfo{
		Id:         orderSale.Id,
		Status:     orderSale.Status,
		StatusName: orderSale.GetStatusName(orderSale.Status),
		Car: saleCar{
			CarId:         orderSale.CarId,
			MainPhoto:     orderSale.Car.MainPhoto,
			ModelName:     orderSale.Car.Model.Name,
			LicensingDate: orderSale.Car.LicensingDate.Time.Unix(),
			Mileage:       orderSale.Car.Mileage,
			Status:        orderSale.Status,
		},
		Contract: saleContract{
			Contract:       orderSale.Contract.Id,
			Amount:         orderSale.Contract.Amount,
			Deposit:        orderSale.Contract.Deposit,
			DownPayment:    orderSale.Contract.DownPayment,
			BalancePayment: orderSale.Contract.BalancePayment,
			ServiceFee:     orderSale.Contract.PurchaseServiceFee,
			TotalAmount:    orderSale.Contract.Amount.Add(orderSale.Contract.PurchaseServiceFee),
			SignAt:         orderSale.Contract.SignAt.Time.Unix(),
		},
		Bank: saleBank{
			AccountName: system.BankAccountName,
			BankName:    system.BankName,
			BankAccount: system.BankAccount,
		},
		Deposit: saleDeposit{
			Amount:    orderSale.DepositPay.Amount,
			PayType:   orderSale.DepositPay.GetPayTypeName(),
			CreatedAt: orderSale.DepositPay.CreatedAt.Unix(),
		},
		DownPayment: saleDownPayment{
			Amount:    orderSale.Contract.DownPayment,
			Proof:     orderSale.DownPaymentAudit.Proof,
			CreatedAt: orderSale.DownPaymentAudit.CreatedAt.Unix(),
		},
		BalancePayment: saleBalancePayment{
			Amount:    orderSale.Contract.BalancePayment,
			Proof:     orderSale.BalancePaymentAudit.Proof,
			CreatedAt: orderSale.BalancePaymentAudit.CreatedAt.Unix(),
		},
		Report: saleReport{
			ReportId: orderSale.Report.Id,
			Path:     orderSale.Report.Path,
		},
		Means: saleMeans{
			TransferId:     orderSale.Transfer.Id,
			Certificate:    orderSale.Transfer.Certificate,
			VehicleLicense: orderSale.Transfer.VehicleLicense,
			Invoice:        orderSale.Transfer.Invoice,
			GuaranteeSlip:  orderSale.Transfer.GuaranteeSlip,
		},
	}
	return
}
