package other

import (
	"base/app/config"
	"encoding/json"
	"errors"
	"fmt"
	"io/ioutil"
	"log"
	"net/http"
	"net/url"
	"strconv"
	"strings"
)

var WxOtherLogic = &wxOtherLogic{}

type wxOtherLogic struct {
}

type resGetAccessTokenData struct {
	AccessToken string `json:"access_token"`
	ExpiresIn   uint   `json:"expires_in"`
}
type resGetSchemeData struct {
	Errcode  uint   `json:"errcode"`
	Errmsg   string `json:"errmsg"`
	Openlink string `json:"openlink"`
}

type schemeRequestData struct {
	JumpWxa jumpWxaData `json:"jump_wxa"`
}

type jumpWxaData struct {
	Path       string `json:"path"`
	Query      string `json:"query"`
	EnvVersion string `json:"env_version"`
}

const (
	wxappEnvRelease = "release"
	wxappEnvTrial   = "trial"
	wxappEnvDevelop = "develop"
)

// H5ToWxAppCar @Title h5跳转到看车
func (w *wxOtherLogic) H5ToWxAppCar(carIds []uint, inviteCode string) (result resGetSchemeData, err error) {
	appid := config.Config.Wxapp.Appid
	secret := config.Config.Wxapp.Secret

	if len(carIds) == 0 {
		return result, errors.New("车辆id数组为空")
	}
	var schemeRequest schemeRequestData
	if len(carIds) == 1 {
		schemeRequest = schemeRequestData{
			jumpWxaData{
				Path:       "pages/index/carBuying/secHandCar/carDetail/index/index",
				Query:      "q=" + url.QueryEscape(fmt.Sprintf("inviteCode=%s&carId=%s", inviteCode, strconv.Itoa(int(carIds[0])))),
				EnvVersion: wxappEnvTrial,
			},
		}
	} else if len(carIds) > 1 {
		schemeRequest = schemeRequestData{
			jumpWxaData{
				Path:       "/pages/buy/buy",
				Query:      "q=" + url.QueryEscape(fmt.Sprintf("inviteCode=%s&carIds=%s", inviteCode, arrayToString(carIds))),
				EnvVersion: wxappEnvTrial,
			},
		}
	}
	resp, err := http.Get(fmt.Sprintf("https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=%s&secret=%s", appid, secret))
	if err != nil {
		return result, errors.New("获取access_token出错")
	}
	defer resp.Body.Close()
	b, err := ioutil.ReadAll(resp.Body)
	if err != nil {
		return result, errors.New("解析access_token出错")
	}
	var resGetAccessToken resGetAccessTokenData
	json.Unmarshal(b, &resGetAccessToken)
	schemeUrl := fmt.Sprintf("https://api.weixin.qq.com/wxa/generatescheme?access_token=%s", resGetAccessToken.AccessToken)
	configData, _ := json.Marshal(schemeRequest)
	request, err := http.NewRequest("POST", schemeUrl, strings.NewReader(string(configData)))
	if err != nil {
		return result, errors.New("获取小程序scheme码出错")
	}
	//request.Header.Set("Content-Type", "application/x-www-form-urlencoded")
	var response *http.Response
	if response, err = http.DefaultClient.Do(request); nil != err {
		return result, errors.New("请求小程序scheme码出错")
	}
	defer response.Body.Close()
	data, readErr := ioutil.ReadAll(response.Body)
	if readErr != nil {
		return result, errors.New("解析小程序scheme码出错")
	}
	var resGetScheme resGetSchemeData
	json.Unmarshal(data, &resGetScheme)
	log.Println("h5跳转参数：", schemeRequest.JumpWxa.Query)
	return resGetScheme, nil
}

func arrayToString(arr []uint) string {
	var result string
	for index, i := range arr {
		result += strconv.Itoa(int(i))
		if index != len(arr)-1 {
			result += ","
		}
	}
	return result
}
