package user

import (
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"gorm.io/gorm"
)

var BrokerLogic = &brokerLogic{}

type brokerLogic struct {
}

type brokerInfo struct {
	Id              uint   `json:"id"`
	Nickname        string `json:"nickname"`        //昵称
	HeadImg         string `json:"headImg"`         // 头像
	Phone           string `json:"phone"`           //手机号
	BusinessId      uint   `json:"businessId"`      // 所属入驻商
	BusinessNo      string `json:"businessNo"`      // 入驻商编号
	BusinessName    string `json:"businessName"`    // 入驻商名称
	BusinessAddress string `json:"businessAddress"` // 公司地址
	BusinessPhone   string `json:"businessPhone"`   // 公司联系电话
}

// Info @Title 获取用户经纪人信息
func (b *brokerLogic) Info(brokerId uint) (result brokerInfo, err error) {
	if brokerId == 0 {
		return result, errors.New("无经纪人")
	}
	broker := model.Broker{Id: brokerId}
	if mysql.Db.Preload("Business").Where(broker).First(&broker).Error != nil {
		return result, errors.New("经纪人查询错误")
	}
	result = brokerInfo{
		Id:              broker.Id,
		Nickname:        broker.Nickname,
		HeadImg:         broker.HeadImg,
		Phone:           broker.Phone,
		BusinessId:      broker.BusinessId,
		BusinessName:    broker.Business.Name,
		BusinessNo:      broker.Business.BusinessNo,
		BusinessAddress: broker.Business.Address,
		BusinessPhone:   broker.Business.Telephone,
	}
	return
}

type BrokerChange struct {
	NewBrokerId uint     `json:"newBrokerId"` //新经纪人id
	Type        uint     `json:"type"`        //分配形式
	Proofs      []string `binding:"required,min=1" label:"图片凭证"`
	Reason      string   `json:"reason"`
}

// Change @Title 提交更换经纪人申请
func (b *brokerLogic) Change(customerId uint, originBrokerId uint, data BrokerChange) error {
	if originBrokerId == data.NewBrokerId {
		return errors.New("经纪人未发生变化")
	}
	customerBrokerAudit := model.CustomerBrokerAudit{CustomerId: customerId, OriginBrokerId: originBrokerId}
	mysql.Db.Transaction(func(tx *gorm.DB) error {
		tx.Model(&model.CustomerBrokerAudit{}).Where("customer_id = ? and status = ?", customerBrokerAudit.CustomerId, model.CustomerBrokerAuditWait).UpdateColumn("status", model.CustomerBrokerAuditReject)
		customerBrokerAudit.NewBrokerId = data.NewBrokerId
		customerBrokerAudit.Reason = data.Reason
		customerBrokerAudit.Type = data.Type
		customerBrokerAudit.Status = model.CustomerBrokerAuditWait
		if customerBrokerAudit.Type == model.CustomerBrokerTypeAuto {
			broker := model.Broker{}
			mysql.Db.Where("business_id = ? and level = ?", 1, model.BrokerLevelBusiness).Order("rand()").First(&broker)
			customerBrokerAudit.NewBrokerId = broker.Id
		}

		if tx.Create(&customerBrokerAudit).Error != nil {
			return errors.New("发起失败")
		}
		var auditProof []model.CustomerBrokerAuditProof
		for _, proof := range data.Proofs {
			auditProof = append(auditProof, model.CustomerBrokerAuditProof{
				CustomerBrokerAuditId: customerBrokerAudit.Id,
				Path:                  proof,
			})
		}
		if tx.Create(&auditProof).Error != nil {
			return errors.New("提交失败")
		}
		return nil
	})
	return nil
}

// Search @Title 搜索经纪人
func (b *brokerLogic) Search(Phone string) (result brokerInfo, err error) {
	broker := model.Broker{Phone: Phone}
	if mysql.Db.Where(broker).First(&broker).Error != nil {
		return result, errors.New("经纪人查询错误")
	}
	result = brokerInfo{
		Id:       broker.Id,
		Nickname: broker.Nickname,
		Phone:    broker.Phone,
	}
	return
}
