package user

import (
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
	"time"
)

var CarLogic = &carLogic{}

type carLogic struct {
}
type carAllItem struct {
	Id           uint   `json:"id"`
	BrandName    string `json:"brandName"`
	ModelName    string `json:"modelName"`
	LicensePlate string `json:"licensePlate"`
}

// All @Title 获取车辆
func (c *carLogic) All(customerId uint) (result []carAllItem) {
	result = []carAllItem{}
	var customerCars []model.CustomerCar
	mysql.Db.Preload("Model.Brand").Where("customer_id = ?", customerId).Order("id desc").Find(&customerCars)
	for _, customerCar := range customerCars {
		result = append(result, carAllItem{
			Id:           customerCar.Id,
			BrandName:    customerCar.Model.Brand.Name,
			ModelName:    customerCar.Model.Name,
			LicensePlate: customerCar.LicensePlate,
		})
	}
	return
}

type CarAdd struct {
	ModelId       uint            // 车型id
	Owner         string          // 所属人
	LicensePlate  string          // 车牌号
	Vin           string          // 车架号
	Engine        string          // 发动机号
	LicensingDate string          // 上牌日期
	CarType       string          // 车辆类型
	Nature        string          // 使用性质
	Color         string          // 车身颜色
	Mileage       decimal.Decimal // 里程
}

// Add @Title 添加车辆
func (c *carLogic) Add(customerId uint, data CarAdd) error {
	licensingDate, err := time.ParseInLocation("2006-01-02", data.LicensingDate, time.Local)
	if err != nil {
		return errors.New("上牌日期错误")
	}
	car := model.CustomerCar{
		CustomerId:    customerId,
		ModelId:       data.ModelId,
		Owner:         data.Owner,
		LicensePlate:  data.LicensePlate,
		Vin:           data.Vin,
		Engine:        data.Engine,
		LicensingDate: licensingDate,
		CarType:       data.CarType,
		Nature:        data.Nature,
		Color:         data.Color,
		Mileage:       data.Mileage,
	}
	if mysql.Db.Create(&car).Error != nil {
		return errors.New("添加失败")
	}
	return nil
}

type carInfo struct {
	ModelId       uint            `json:"modelId"`
	Owner         string          `json:"owner"`
	LicensePlate  string          `json:"licensePlate"`
	Vin           string          `json:"vin"`
	Engine        string          `json:"engine"`
	LicensingDate int64           `json:"licensingDate"`
	CarType       string          `json:"carType"`
	Nature        string          `json:"nature"`
	Color         string          `json:"color"`
	Mileage       decimal.Decimal `json:"mileage"`
}

// Info @Title 车辆详情
func (c *carLogic) Info(customerId, carId uint) (result carInfo, err error) {
	customerCar := model.CustomerCar{Id: carId, CustomerId: customerId}
	if mysql.Db.Where(&customerCar).First(&customerCar).Error != nil {
		return result, errors.New("车辆错误")
	}
	result = carInfo{
		ModelId:       customerCar.ModelId,
		Owner:         customerCar.Owner,
		LicensePlate:  customerCar.LicensePlate,
		Vin:           customerCar.Vin,
		Engine:        customerCar.Engine,
		LicensingDate: customerCar.LicensingDate.Unix(),
		CarType:       customerCar.CarType,
		Nature:        customerCar.Nature,
		Color:         customerCar.Color,
		Mileage:       customerCar.Mileage,
	}
	return
}

// Edit @Title 编辑车辆
func (c *carLogic) Edit(customerId, carId uint, data CarAdd) error {
	customerCar := model.CustomerCar{Id: carId, CustomerId: customerId}
	if mysql.Db.Where(&customerCar).First(&customerCar).Error != nil {
		return errors.New("车辆错误")
	}
	licensingDate, err := time.ParseInLocation("2006-01-02", data.LicensingDate, time.Local)
	if err != nil {
		return errors.New("上牌日期错误")
	}
	customerCar.ModelId = data.ModelId
	customerCar.Owner = data.Owner
	customerCar.LicensePlate = data.LicensePlate
	customerCar.Vin = data.Vin
	customerCar.Engine = data.Engine
	customerCar.LicensingDate = licensingDate
	customerCar.CarType = data.CarType
	customerCar.Nature = data.Nature
	customerCar.Color = data.Color
	customerCar.Mileage = data.Mileage
	if mysql.Db.Save(&customerCar).Error != nil {
		return errors.New("保存失败")
	}
	return nil
}

// Delete @Title 删除车辆
func (c *carLogic) Delete(customerId, carId uint) error {
	if mysql.Db.Where("customer_id = ? and id = ?", customerId, carId).Delete(&model.CustomerCar{}).Error != nil {
		return errors.New("删除失败")
	}
	return nil
}
