package wallet

import (
	"base/app/common"
	"base/app/constant"
	"base/app/lib/bean"
	"base/app/logic/pay"
	"base/app/model"
	"errors"
	"fmt"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
	"gorm.io/gorm"
)

var AssessLogic = &assessLogic{}

type assessLogic struct {
}

// Count @Title 获取剩余评估次数
func (a *assessLogic) Count(customerId uint) int {
	assess := model.CustomerWalletAssess{CustomerId: customerId}
	mysql.Db.Where(&assess).First(&assess)
	return assess.Count
}

// Recharge @Title 充值
func (a *assessLogic) Recharge(customerId, count uint, openId string) (result interface{}, err error) {
	orderSn, err := common.GenNo(constant.NoPrefixOrderAssess)
	if err != nil {
		return result, errors.New("充值失败")
	}
	orderAssess := model.OrderAssess{
		OrderSn: orderSn,
		Type:    model.OrderAssessTypeCustomer,
		UserId:  customerId,
		Amount:  decimal.NewFromInt(int64(count)),
		Count:   count,
		PayType: model.PayTypeWxapp,
		Status:  model.OrderAssessStatusUnPay,
	}
	err = mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Create(&orderAssess).Error != nil {
			return errors.New("充值失败")
		}
		result, err = pay.PayLogic.Pay(orderAssess.Id, model.PayOrderTypeAssess, model.PayTypeWxapp, orderAssess.Amount, "评估次数充值", openId)
		if err != nil {
			return errors.New("充值失败")
		}
		return nil
	})
	return
}

type assessHistoryItem struct {
	Id        uint  `json:"id"`
	Type      uint  `json:"type"`
	Count     int   `json:"count"`
	CreatedAt int64 `json:"createdAt"`
}
type AssessHistorySearch struct {
	Date string
}

// History @Title 评估次数记录
func (a *assessLogic) History(customerId uint, search AssessHistorySearch, page bean.Page) (lists []assessHistoryItem, total int64) {
	lists = []assessHistoryItem{}
	var assessHistories []model.CustomerWalletAssessHistory
	where := mysql.Db.Where("customer_id = ?", customerId)
	if search.Date != "" {
		where = where.Where("created_at like ?", fmt.Sprintf("%s%%", search.Date))
	}
	mysql.Db.Model(&assessHistories).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Find(&assessHistories)
		for _, assessHistory := range assessHistories {
			lists = append(lists, assessHistoryItem{
				Id:        assessHistory.Id,
				Type:      assessHistory.Type,
				Count:     assessHistory.Count,
				CreatedAt: assessHistory.CreatedAt.Unix(),
			})
		}
	}
	return
}

// Add @Title 添加评估次数
func (a *assessLogic) Add(db *gorm.DB, customerId, orderId uint, count int) error {
	walletAssess := model.CustomerWalletAssess{CustomerId: customerId}
	mysql.Db.Where(&walletAssess).First(&walletAssess)
	if walletAssess.Id > 0 {
		if db.Model(&walletAssess).Where(&walletAssess).UpdateColumns(map[string]interface{}{
			"total_count": gorm.Expr("total_count + ?", count),
			"count":       gorm.Expr("count + ?", count),
		}).RowsAffected != 1 {
			return errors.New("系统错误")
		}
	} else {
		walletAssess.TotalCount = count
		walletAssess.Count = count
		if db.Create(&walletAssess).Error != nil {
			return errors.New("系统错误")
		}
	}
	assessHistory := model.CustomerWalletAssessHistory{
		CustomerId: customerId,
		Type:       model.CustomerWalletAssessHistoryRecharge,
		OrderId:    orderId,
		Count:      count,
	}
	if db.Create(&assessHistory).Error != nil {
		return errors.New("系统错误")
	}
	return nil
}

// Use @Title 使用评估次数
func (a *assessLogic) Use(db *gorm.DB, customerId, orderId uint, count int) error {
	if db.Model(&model.CustomerWalletAssess{}).Where("customer_id = ?", customerId).UpdateColumns(map[string]interface{}{
		"use_count": gorm.Expr("use_count + ?", count),
		"count":     gorm.Expr("count - ?", count),
	}).RowsAffected != 1 {
		return errors.New("系统错误")
	}
	assessHistory := model.CustomerWalletAssessHistory{
		CustomerId: customerId,
		Type:       model.CustomerWalletAssessHistoryAssess,
		OrderId:    orderId,
		Count:      count * -1,
	}
	if db.Create(&assessHistory).Error != nil {
		return errors.New("系统错误")
	}
	return nil
}
