package app

import (
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"fmt"
	"git.oa00.com/go/mysql"
)

var FeedbackLogic = &feedbackLogic{}

type feedbackLogic struct {
}

type feedbackItem struct {
	Id        uint   `json:"id"`
	Title     string `json:"title"`
	Phone     string `json:"phone"`
	CreatedAt int64  `json:"createdAt"`
}

type FeedbackSearch struct {
	Title string
	Phone string
}

// Lists @Title 意见列表
func (f *feedbackLogic) Lists(search FeedbackSearch, page bean.Page) (lists []feedbackItem, total int64) {
	lists = []feedbackItem{}
	var feedbacks []model.Feedback
	where := mysql.Db
	if search.Title != "" {
		where = where.Where("title like ?", fmt.Sprintf("%%%s%%", search.Title))
	}
	if search.Phone != "" {
		where = where.Where("phone like ?", fmt.Sprintf("%%%s%%", search.Phone))
	}
	mysql.Db.Model(&feedbacks).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("id desc").Find(&feedbacks)
		for _, feedback := range feedbacks {
			lists = append(lists, feedbackItem{
				Id:        feedback.Id,
				Title:     feedback.Title,
				Phone:     feedback.Phone,
				CreatedAt: feedback.CreatedAt.Unix(),
			})
		}
	}
	return
}

type feedbackInfo struct {
	Id      uint   `json:"id"`
	Name    string `json:"name"`
	Title   string `json:"title"`
	Phone   string `json:"phone"`
	Content string `json:"content"`
	Img     string `json:"img"`
}

// Info @Title 详情
func (f *feedbackLogic) Info(feedbackId uint) (result feedbackInfo, err error) {
	feedback := model.Feedback{Id: feedbackId}
	if mysql.Db.First(&feedback).Error != nil {
		return result, errors.New("")
	}
	result = feedbackInfo{
		Id:      feedback.Id,
		Name:    feedback.Name,
		Title:   feedback.Title,
		Phone:   feedback.Phone,
		Content: feedback.Content,
		Img:     feedback.Img,
	}
	return
}

// Delete @Title 删除意见
func (f *feedbackLogic) Delete(feedbackId uint) error {
	if mysql.Db.Delete(&model.Feedback{}, "id = ?", feedbackId).Error != nil {
		return errors.New("删除失败")
	}
	return nil
}
