package broker

import (
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
)

var AppLogic = &appLogic{}

type appLogic struct {
}
type appItem struct {
	Id              uint   `json:"id"`
	Image           string `json:"image"`
	Status          uint   `json:"status"`
	Sort            uint   `json:"sort"`
	CreatedUserName string `json:"createdUserName"`
	CreatedAt       int64  `json:"createdAt"`
}
type AppListsSearch struct {
}

// Lists @Title 经纪人app轮播图列表
func (a *appLogic) Lists(search AppListsSearch, page bean.Page) (lists []appItem, total int64) {
	lists = []appItem{}
	var brokerApps []model.BannerBrokerApp
	where := mysql.Db
	mysql.Db.Model(&brokerApps).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("CreatedUser").Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("sort desc,id desc").Find(&brokerApps)
		for _, brokerApp := range brokerApps {
			lists = append(lists, appItem{
				Id:              brokerApp.Id,
				Image:           brokerApp.Image,
				Status:          brokerApp.Status,
				Sort:            brokerApp.Sort,
				CreatedUserName: brokerApp.CreatedUser.Name,
				CreatedAt:       brokerApp.CreatedAt.Unix(),
			})
		}
	}
	return
}

type AppAdd struct {
	Image  string `binding:"required" label:"轮播图"`
	Path   string `binding:"required" label:"跳转地址"`
	Status uint   `binding:"required,oneof=1 2" label:"状态"`
	Sort   uint   `binding:"required" label:"排序"`
}

// Add @Title 添加轮播图
func (a *appLogic) Add(manageId uint, data AppAdd) error {
	brokerApp := model.BannerBrokerApp{
		Image:         data.Image,
		Status:        data.Status,
		Sort:          data.Sort,
		CreatedUserId: manageId,
		Path:          data.Path,
	}
	if mysql.Db.Create(&brokerApp).Error != nil {
		return errors.New("添加失败")
	}
	return nil
}

type appInfo struct {
	Id     uint   `json:"id"`
	Image  string `json:"image"`
	Status uint   `json:"status"`
	Sort   uint   `json:"sort"`
	Path   string `json:"path"`
}

// Info @Title 轮播图详情
func (a *appLogic) Info(bannerId uint) (result appInfo, err error) {
	brokerApp := model.BannerBrokerApp{Id: bannerId}
	if mysql.Db.First(&brokerApp).Error != nil {
		return result, errors.New("轮播图错误")
	}
	result = appInfo{
		Id:     brokerApp.Id,
		Image:  brokerApp.Image,
		Status: brokerApp.Status,
		Sort:   brokerApp.Sort,
		Path:   brokerApp.Path,
	}
	return
}

// Edit @Title 轮播图编辑
func (a *appLogic) Edit(bannerId uint, data AppAdd) error {
	brokerApp := model.BannerBrokerApp{Id: bannerId}
	if mysql.Db.First(&brokerApp).Error != nil {
		return errors.New("轮播图错误")
	}
	brokerApp.Image = data.Image
	brokerApp.Path = data.Path
	brokerApp.Status = data.Status
	brokerApp.Sort = data.Sort
	if mysql.Db.Updates(&brokerApp).Error != nil {
		return errors.New("编辑失败")
	}
	return nil
}
