package customer

import (
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
)

var WxappLogic = &wxappLogic{}

type wxappLogic struct {
}
type appItem struct {
	Id              uint   `json:"id"`
	Image           string `json:"image"`
	Status          uint   `json:"status"`
	Sort            uint   `json:"sort"`
	CreatedUserName string `json:"createdUserName"`
	CreatedAt       int64  `json:"createdAt"`
}
type WxappListsSearch struct {
}

// Lists @Title 客户wxapp轮播图列表
func (w *wxappLogic) Lists(search WxappListsSearch, page bean.Page) (lists []appItem, total int64) {
	lists = []appItem{}
	var customerWxapps []model.BannerCustomerWxapp
	where := mysql.Db
	mysql.Db.Model(&customerWxapps).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("CreatedUser").Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("sort desc,id desc").Find(&customerWxapps)
		for _, customerWxapp := range customerWxapps {
			lists = append(lists, appItem{
				Id:              customerWxapp.Id,
				Image:           customerWxapp.Image,
				Status:          customerWxapp.Status,
				Sort:            customerWxapp.Sort,
				CreatedUserName: customerWxapp.CreatedUser.Name,
				CreatedAt:       customerWxapp.CreatedAt.Unix(),
			})
		}
	}
	return
}

type WxappAdd struct {
	Image  string `binding:"required" label:"轮播图"`
	Path   string `binding:"required" label:"跳转地址"`
	Status uint   `binding:"required,oneof=1 2" label:"状态"`
	Sort   uint   `binding:"required" label:"排序"`
}

// Add @Title 添加轮播图
func (w *wxappLogic) Add(manageId uint, data WxappAdd) error {
	customerWxapp := model.BannerCustomerWxapp{
		Image:         data.Image,
		Status:        data.Status,
		Sort:          data.Sort,
		CreatedUserId: manageId,
		Path:          data.Path,
	}
	if mysql.Db.Create(&customerWxapp).Error != nil {
		return errors.New("添加失败")
	}
	return nil
}

type appInfo struct {
	Id     uint   `json:"id"`
	Image  string `json:"image"`
	Status uint   `json:"status"`
	Sort   uint   `json:"sort"`
	Path   string `json:"path"`
}

// Info @Title 轮播图详情
func (w *wxappLogic) Info(bannerId uint) (result appInfo, err error) {
	customerWxapp := model.BannerCustomerWxapp{Id: bannerId}
	if mysql.Db.First(&customerWxapp).Error != nil {
		return result, errors.New("轮播图错误")
	}
	result = appInfo{
		Id:     customerWxapp.Id,
		Image:  customerWxapp.Image,
		Status: customerWxapp.Status,
		Sort:   customerWxapp.Sort,
		Path:   customerWxapp.Path,
	}
	return
}

// Edit @Title 轮播图编辑
func (w *wxappLogic) Edit(bannerId uint, data WxappAdd) error {
	customerWxapp := model.BannerCustomerWxapp{Id: bannerId}
	if mysql.Db.First(&customerWxapp).Error != nil {
		return errors.New("轮播图错误")
	}
	customerWxapp.Image = data.Image
	customerWxapp.Path = data.Path
	customerWxapp.Status = data.Status
	customerWxapp.Sort = data.Sort
	if mysql.Db.Updates(&customerWxapp).Error != nil {
		return errors.New("编辑失败")
	}
	return nil
}

// Delete @Title 删除轮播图
func (w *wxappLogic) Delete(manageId uint, bannerId uint) error {
	if mysql.Db.Delete(&model.BannerCustomerWxapp{}, "id = ?", bannerId).Error != nil {
		return errors.New("删除失败")
	}
	return nil
}
