package car

import (
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"fmt"
	"git.oa00.com/go/mysql"
)

var BrandLogic = &brandLogic{}

type brandLogic struct {
}
type brandItem struct {
	Id     uint   `json:"id"`
	Icon   string `json:"icon"`
	Name   string `json:"name"`
	IsHot  uint   `json:"isHot"`
	Status uint   `json:"status"`
}

type BrandSearch struct {
	Id              uint
	Name            string
	Status          uint
	IsHot           uint
	HasImg          uint
	CreateTimeStart string
	CreateTimeEnd   string
}

// Lists @Title 品牌列表
func (b *brandLogic) Lists(search BrandSearch, page bean.Page) (lists []brandItem, total int64) {
	lists = []brandItem{}
	var brands []model.CarBrand
	where := mysql.Db
	if search.Id > 0 {
		where = where.Where("id = ?", search.Id)
	}
	if search.Name != "" {
		where = where.Where("name like ?", fmt.Sprintf("%%%s%%", search.Name))
	}
	if search.Status > 0 {
		switch search.Status {
		case 1: // 下架
			where = where.Where("status = ?", model.CarBrandStatusEnabled)
		case 2: // 上架
			where = where.Where("status = ?", model.CarBrandStatusDisabled)
		}
	}
	if search.IsHot == 1 {
		where = where.Where("is_hot = ?", model.CarBrandIsHot)
	}
	if search.CreateTimeStart != "" && search.CreateTimeEnd != "" {
		where = where.Where("created_at between ? and ?", search.CreateTimeStart, search.CreateTimeEnd)
	}
	if search.HasImg > 0 {
		switch search.HasImg {
		case 1: // 有图
			where = where.Where("icon <> ?", "")
		case 2: // 无图
			where = where.Where("icon = ?", "")
		}
	}
	mysql.Db.Model(&brands).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Find(&brands)
		for _, brand := range brands {
			lists = append(lists, brandItem{
				Id:     brand.Id,
				Icon:   brand.Icon,
				Name:   brand.Name,
				IsHot:  brand.IsHot,
				Status: brand.Status,
			})
		}
	}
	return
}

// Edit @Title 修改品牌信息
func (b *brandLogic) Edit(brandId, status uint, name, icon string) error {
	brand := model.CarBrand{Id: brandId}
	if mysql.Db.First(&brand).Error != nil {
		return errors.New("品牌错误")
	}
	brand.Status = status
	brand.Name = name
	brand.Icon = icon
	if mysql.Db.Save(&brand).Error != nil {
		return errors.New("修改失败")
	}
	return nil
}

// IsHot @Title 修改热门品牌
func (b *brandLogic) IsHot(brandId, isHot uint) error {
	brand := model.CarBrand{Id: brandId}
	if mysql.Db.First(&brand).Error != nil {
		return errors.New("品牌错误")
	}
	switch isHot {
	case 0:
		brand.IsHot = model.CarBrandIsHotFalse
	case 1:
		brand.IsHot = model.CarBrandIsHot
	default:
		return errors.New("未做选择")
	}
	if mysql.Db.Save(&brand).Error != nil {
		return errors.New("修改失败")
	}
	return nil
}
