package car

import (
	"base/app/common"
	"base/app/constant"
	"base/app/lib/bean"
	"base/app/logic/car"
	"base/app/model"
	"database/sql"
	"errors"
	"git.oa00.com/go/mysql"
	"gorm.io/gorm"
	"time"
)

var DealerConsignmentLogic = &dealerConsignmentLogic{}

type dealerConsignmentLogic struct {
}
type dealerConsignmentItem struct {
	Id        uint   `json:"id"`
	MainPhoto string `json:"mainPhoto"`
	ModelName string `json:"modelName"`
}
type DealerConsignmentSearch struct {
}

// Lists @Title 车辆审核列表
func (d *dealerConsignmentLogic) Lists(search DealerConsignmentSearch, page bean.Page) (lists []dealerConsignmentItem, total int64) {
	lists = []dealerConsignmentItem{}
	var dealerConsignmentCars []model.OrderDealerConsignmentCar
	where := mysql.Db
	mysql.Db.Model(&dealerConsignmentCars).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("Order.Model").Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Find(&dealerConsignmentCars)
		for _, dealerConsignmentCar := range dealerConsignmentCars {
			lists = append(lists, dealerConsignmentItem{
				Id:        dealerConsignmentCar.Id,
				MainPhoto: dealerConsignmentCar.MainPhoto,
				ModelName: dealerConsignmentCar.Order.Model.Name,
			})
		}
	}
	return
}

// Adopt @Title 审核通过
func (d *dealerConsignmentLogic) Adopt(manageId, dealerConsignmentCarId uint) error {
	dealerConsignmentCar := model.OrderDealerConsignmentCar{Id: dealerConsignmentCarId}
	if mysql.Db.Preload("Order.CarPrice").Preload("Order.Audit").First(&dealerConsignmentCar).Error != nil {
		return errors.New("车辆错误")
	}
	if dealerConsignmentCar.Order.Audit.Status != model.OrderDealerConsignmentAuditStatusAudit {
		return errors.New("已审核，请勿重复操作")
	}
	priceAmount := car.PriceLogic.Amount(dealerConsignmentCar.Order.Price)
	carSn, err := common.GenNo(constant.NoPrefixCar)
	if err != nil {
		return errors.New("审核失败")
	}
	carModel := model.Car{
		ModelId:       dealerConsignmentCar.ModelId,
		CarSn:         carSn,
		Type:          model.CarTypeSecond,
		OrderId:       dealerConsignmentCar.OrderId,
		OrderCarId:    dealerConsignmentCar.Id,
		CustomerId:    dealerConsignmentCar.DealerId,
		CustomerType:  model.CustomerTypeDealer,
		BrokerId:      dealerConsignmentCar.BrokerId,
		MainPhoto:     dealerConsignmentCar.MainPhoto,
		Status:        model.CarStatusNormal,
		ReckonPrice:   dealerConsignmentCar.Order.CarPrice.Price,
		Price:         dealerConsignmentCar.Order.Price,
		LicensingDate: sql.NullTime{Time: dealerConsignmentCar.Order.CarPrice.LicensingDate, Valid: true},
		DownPayment:   priceAmount.DownPayment,
		Mileage:       dealerConsignmentCar.Order.CarPrice.Mileage,
		Transfer:      dealerConsignmentCar.Order.CarPrice.Transfer,
		Color:         dealerConsignmentCar.Order.CarPrice.Color,
		InteriorColor: dealerConsignmentCar.InteriorColor,
		TheUpper:      model.CarTheUpperTrue,
		LastPrice:     dealerConsignmentCar.Order.Price,
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Create(&carModel).Error != nil {
			return errors.New("审核失败")
		}
		if tx.Model(&dealerConsignmentCar.Order.Audit).Where(&dealerConsignmentCar.Order.Audit).UpdateColumns(map[string]interface{}{
			"status":        model.OrderDealerConsignmentAuditStatusAdopt,
			"audit_at":      time.Now(),
			"audit_user_id": manageId,
		}).RowsAffected != 1 {
			return errors.New("审核失败")
		}
		if tx.Model(&model.OrderDealerConsignmentCar{}).Where("id = ?", dealerConsignmentCar.Id).UpdateColumns(map[string]interface{}{
			"car_id":    carModel.Id,
			"the_upper": model.OrderDealerConsignmentCarTheUpperTrue,
		}).RowsAffected != 1 {
			return errors.New("审核失败")
		}
		if tx.Model(&model.OrderDealerConsignment{}).Where("id = ?", dealerConsignmentCar.OrderId).UpdateColumns(map[string]interface{}{
			"status": model.OrderDealerConsignmentStatusTheUpper,
		}).RowsAffected != 1 {
			return errors.New("审核失败")
		}
		return nil
	})
}

// Reject @Title 审核驳回
func (d *dealerConsignmentLogic) Reject(manageId, dealerConsignmentCarId uint, reason string) error {
	dealerConsignmentCar := model.OrderDealerConsignmentCar{Id: dealerConsignmentCarId}
	if mysql.Db.Preload("Order.Audit").First(&dealerConsignmentCar).Error != nil {
		return errors.New("车辆错误")
	}
	if dealerConsignmentCar.Order.Audit.Status != model.OrderDealerConsignmentAuditStatusAudit {
		return errors.New("已审核，请勿重复操作")
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Model(&dealerConsignmentCar.Order.Audit).Where(&dealerConsignmentCar.Order.Audit).UpdateColumns(map[string]interface{}{
			"status":        model.OrderDealerConsignmentAuditStatusReject,
			"reason":        reason,
			"audit_at":      time.Now(),
			"audit_user_id": manageId,
		}).RowsAffected != 1 {
			return errors.New("审核失败")
		}
		return nil
	})
}
