package contract

import (
	"base/app/lib/bean"
	"base/app/model"
	"fmt"
	"git.oa00.com/go/mysql"
	"time"
)

var BusinessLogic = &businessLogic{}

type businessLogic struct {
}

type businessItem struct {
	Id         uint   `json:"id"`
	ContractNo string `json:"contractNo"`
	Contract   string `json:"contract"`
	BusinessNo string `json:"businessNo"`
	Name       string `json:"name"`
	ExpireDate int64  `json:"expireDate"`
	SaleName   string `json:"saleName"`
	SalePhone  string `json:"salePhone"`
}

type BusinessSearch struct {
	ContractNo      string
	BusinessNo      string
	Name            string
	ContractStatus  uint
	SaleName        string
	SalePhone       string
	ExpireDateStart string
	ExpireDateEnd   string
}

// Lists @Title 入驻商合同
func (b *businessLogic) Lists(search BusinessSearch, page bean.Page) (lists []businessItem, total int64) {
	lists = []businessItem{}
	var businesses []model.BrokerBusiness
	where := mysql.Db.Where("auditing_status = ?", model.BrokerBusinessAuditingStatusSuc)
	// 合同编号
	if search.ContractNo != "" {
		where = where.Where("contract_no like ?", fmt.Sprintf("%%%s%%", search.ContractNo))
	}
	// 入驻商编号
	if search.BusinessNo != "" {
		where = where.Where("business_no like ?", fmt.Sprintf("%%%s%%", search.BusinessNo))
	}
	// 入驻商名称
	if search.Name != "" {
		where = where.Where("name like ?", fmt.Sprintf("%%%s%%", search.Name))
	}
	// 合同状态
	if search.ContractStatus > 0 {
		now := time.Now()
		switch search.ContractStatus {
		case 1: // 正常
			where = where.Where("expire_date > ?", now)
		case 2: // 已到期
			where = where.Where("expire_date <= ?", now)
		}
	}
	// 合同到期日
	if search.ExpireDateStart != "" && search.ExpireDateEnd != "" {
		where = where.Where("expire_date >= ? and expire_date >= ?", search.ExpireDateStart, search.ExpireDateEnd)
	}
	// 业务员
	{
		saleWhere := mysql.Db.Model(&model.Manage{}).Select("id")
		// 姓名
		if search.SaleName != "" {
			saleWhere = saleWhere.Where("name like ?", fmt.Sprintf("%%%s%%", search.SaleName))
		}
		// 手机号
		if search.SalePhone != "" {
			saleWhere = saleWhere.Where("phone like ?", fmt.Sprintf("%%%s%%", search.SalePhone))
		}
		if _, ok := saleWhere.Statement.Clauses["WHERE"]; ok {
			where = where.Where("sale_id in (?)", saleWhere)
		}
	}
	mysql.Db.Model(&businesses).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("Sale").Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("id desc").Find(&businesses)
		for _, business := range businesses {
			lists = append(lists, businessItem{
				Id:         business.Id,
				ContractNo: business.ContractNo,
				Contract:   business.Contract,
				BusinessNo: business.BusinessNo,
				Name:       business.Name,
				ExpireDate: business.ExpireDate.Unix(),
				SaleName:   business.Sale.Name,
				SalePhone:  business.Sale.Phone,
			})
		}
	}
	return
}
