package contract

import (
	"base/app/lib/bean"
	"base/app/model"
	"fmt"
	"git.oa00.com/go/mysql"
)

var ConsignmentLogic = &consignmentLogic{}

type consignmentLogic struct {
}

type consignmentItem struct {
	Id             uint   `json:"id"`
	ContractSn     string `json:"contractSn"`
	ModelName      string `json:"modelName"`
	CustomerName   string `json:"customerName"`
	CustomerMobile string `json:"customerMobile"`
	SignAt         int64  `json:"signAt"`
	EssFileUrl     string `json:"essFileUrl"`
}

type ConsignmentSearch struct {
	ContractSn     string
	CustomerName   string
	CustomerMobile string
	SignDateStart  string
	SignDateEnd    string
}

// Lists @Title 寄卖合同
func (c *consignmentLogic) Lists(search ConsignmentSearch, page bean.Page) (lists []consignmentItem, total int64) {
	lists = []consignmentItem{}
	var contractConsignments []model.ContractConsignment
	where := mysql.Db
	// 合同编号
	if search.ContractSn != "" {
		where = where.Where("contract_sn like ?", fmt.Sprintf("%%%s%%", search.ContractSn))
	}
	// 客户信息
	{
		customerWhere := mysql.Db.Model(&model.Customer{}).Select("id")
		// 客户名称
		if search.CustomerName != "" {
			customerWhere = customerWhere.Where("nickname like ?", fmt.Sprintf("%%%s%%", search.CustomerName))
		}
		// 客户手机号
		if search.CustomerMobile != "" {
			customerWhere = customerWhere.Where("mobile like ?", fmt.Sprintf("%%%s%%", search.CustomerMobile))
		}
		if _, ok := customerWhere.Statement.Clauses["WHERE"]; ok {
			where = where.Where("customer_id in (?)", customerWhere)
		}
	}
	// 签订时间
	if search.SignDateStart != "" && search.SignDateEnd != "" {
		where = where.Where("sign_at >= ? and sign_at <= ?", search.SignDateStart, search.SignDateEnd+" 23:59:59")
	}
	mysql.Db.Model(&contractConsignments).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.
			Preload("Order.Model").Preload("Customer").Preload("EssFlow").
			Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("id desc").Find(&contractConsignments)
		for _, contractConsignment := range contractConsignments {
			lists = append(lists, consignmentItem{
				Id:             contractConsignment.Id,
				ContractSn:     contractConsignment.ContractSn,
				ModelName:      contractConsignment.Order.Model.Name,
				CustomerName:   contractConsignment.Customer.Nickname,
				CustomerMobile: contractConsignment.Customer.Mobile,
				SignAt:         contractConsignment.SignAt.Time.Unix(),
				EssFileUrl:     contractConsignment.EssFlow.Url,
			})
		}
	}
	return
}
