package contract

import (
	"base/app/constant"
	"base/app/lib/bean"
	"base/app/model"
	"fmt"
	"git.oa00.com/go/mysql"
)

var SaleLogic = &saleLogic{}

type saleLogic struct {
}

type saleItem struct {
	Id             uint   `json:"id"`
	ContractSn     string `json:"contractSn"`
	ModelName      string `json:"modelName"`
	CustomerName   string `json:"customerName"`
	CustomerMobile string `json:"customerMobile"`
	SignAt         int64  `json:"signAt"`
	EssFileUrl     string `json:"essFileUrl"`
}

type SaleSearch struct {
	ContractSn     string
	CustomerName   string
	CustomerMobile string
	SignDateStart  string
	SignDateEnd    string
}

// Lists @Title 售车合同列表
func (s *saleLogic) Lists(search SaleSearch, page bean.Page) (lists []saleItem, total int64) {
	lists = []saleItem{}
	var contractSales []model.ContractSale
	where := mysql.Db.Where("status > ?", constant.ContractStatusCreate)
	// 合同编号
	if search.ContractSn != "" {
		where = where.Where("contract_sn like ?", fmt.Sprintf("%%%s%%", search.ContractSn))
	}
	// 客户信息
	{
		customerWhere := mysql.Db.Model(&model.Customer{}).Select("id")
		// 客户名称
		if search.CustomerName != "" {
			customerWhere = customerWhere.Where("nickname like ?", fmt.Sprintf("%%%s%%", search.CustomerName))
		}
		// 客户手机号
		if search.CustomerMobile != "" {
			customerWhere = customerWhere.Where("mobile like ?", fmt.Sprintf("%%%s%%", search.CustomerMobile))
		}
		if _, ok := customerWhere.Statement.Clauses["WHERE"]; ok {
			where = where.Where("customer_id in (?)", customerWhere)
		}
	}
	// 签订时间
	if search.SignDateStart != "" && search.SignDateEnd != "" {
		where = where.Where("sign_at >= ? and sign_at <= ?", search.SignDateStart, search.SignDateEnd+" 23:59:59")
	}
	mysql.Db.Model(&contractSales).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.
			Preload("Car.Model").Preload("Customer").Preload("EssFlow").
			Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("id desc").Find(&contractSales)
		for _, contractSale := range contractSales {
			lists = append(lists, saleItem{
				Id:             contractSale.Id,
				ContractSn:     contractSale.ContractSn,
				ModelName:      contractSale.Car.Model.Name,
				CustomerName:   contractSale.Customer.Nickname,
				CustomerMobile: contractSale.Customer.Mobile,
				SignAt:         contractSale.SignAt.Time.Unix(),
				EssFileUrl:     contractSale.EssFlow.Url,
			})
		}
	}
	return
}
