package customer

import (
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"fmt"
	"git.oa00.com/go/mysql"
	"gorm.io/gorm"
	"time"
)

var CustomerBrokerLogic = &customerBrokerLogic{}

type customerBrokerLogic struct {
}
type CustomerBrokerSearch struct {
	CustomerName     string // 客户姓名
	CustomerTel      string // 客户手机号
	Status           uint   // 审核状态 0全部 1待审核 2审核通过 3审核驳回
	OriginBrokerName string // 原绑定经纪人姓名
	NewBrokerName    string // 申请绑定经纪人姓名
	CreateTimeStart  string // 申请日期搜索始
	CreateTimeEnd    string // 申请日期搜索末
}

type customerBrokerAuditItem struct {
	Id               uint   `json:"id"`
	OriginBrokerId   uint   `json:"originBrokerId"`
	OriginBrokerName string `json:"originBrokerName"`
	NewBrokerId      uint   `json:"newBrokerId"`
	NewBrokerName    string `json:"newBrokerName"`
	CustomerId       uint   `json:"customerId"`
	CustomerName     string `json:"customerName"`
	CustomerTel      string `json:"customerTel"`
	Type             uint   `json:"type"`
	Status           uint   `json:"status"`
	AuditAt          int64  `json:"auditAt"`
	Reason           string `json:"reason"`
	AuditUserId      uint   `json:"auditUserId"`
	AuditUserName    string `json:"auditUserName"`
	CreatedAt        int64  `json:"createdAt"`
	UpdateAt         int64  `json:"updateAt"`
}

// Lists @Title 申请列表
func (c *customerBrokerLogic) Lists(search CustomerBrokerSearch, page bean.Page) (lists []customerBrokerAuditItem, total int64) {
	lists = []customerBrokerAuditItem{}
	var customerBrokerAudits []model.CustomerBrokerAudit
	// 筛选
	where := mysql.Db
	if search.Status > 0 {
		switch search.Status {
		case 1: // 待审核
			where = where.Where("status = ?", model.CustomerBrokerAuditWait)
		case 2: // 审核通过
			where = where.Where("status = ?", model.CustomerBrokerAuditAdopt)
		case 3: // 审核驳回
			where = where.Where("status = ?", model.CustomerBrokerAuditReject)
		}
	}
	if createTimeStart, err := time.ParseInLocation("2006-01-02", search.CreateTimeStart, time.Local); err == nil {
		where = where.Where("created_at >= ?", createTimeStart)
	}
	if createTimeEnd, err := time.ParseInLocation("2006-01-02", search.CreateTimeEnd, time.Local); err == nil {
		where = where.Where("created_at <= ?", createTimeEnd)
	}

	{
		customerWhere := mysql.Db.Model(&model.Customer{}).Select("id")
		if search.CustomerName != "" {
			customerWhere = customerWhere.Where("nickname like ?", fmt.Sprintf("%%%s%%", search.CustomerName))
		}
		if search.CustomerTel != "" {
			customerWhere = customerWhere.Where("mobile like ?", fmt.Sprintf("%%%s%%", search.CustomerTel))
		}
		if _, ok := customerWhere.Statement.Clauses["WHERE"]; ok {
			where = where.Where("customer_id in (?)", customerWhere)
		}
	}
	if search.OriginBrokerName != "" {
		where = where.Where("origin_broker_id in (?)", mysql.Db.Model(&model.Broker{}).Select("id").
			Where("nickname like ?", fmt.Sprintf("%%%s%%", search.OriginBrokerName)))
	}
	if search.NewBrokerName != "" {
		where = where.Where("new_broker_id in (?)", mysql.Db.Model(&model.Broker{}).Select("id").
			Where("nickname like ?", fmt.Sprintf("%%%s%%", search.NewBrokerName)))
	}
	mysql.Db.Model(&customerBrokerAudits).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.
			Preload("OriginBroker").Preload("NewBroker").Preload("Customer").Preload("AuditUser").
			Where(where).
			Offset(page.GetStart()).Limit(page.GetLimit()).Order("id desc").Find(&customerBrokerAudits)
		for _, customerBrokerAudit := range customerBrokerAudits {
			lists = append(lists, customerBrokerAuditItem{
				Id:               customerBrokerAudit.Id,
				OriginBrokerId:   customerBrokerAudit.OriginBrokerId,
				OriginBrokerName: customerBrokerAudit.OriginBroker.Nickname,
				NewBrokerId:      customerBrokerAudit.NewBrokerId,
				NewBrokerName:    customerBrokerAudit.NewBroker.Nickname,
				CustomerId:       customerBrokerAudit.CustomerId,
				CustomerName:     customerBrokerAudit.Customer.Nickname,
				CustomerTel:      customerBrokerAudit.Customer.Mobile,
				Type:             customerBrokerAudit.Type,
				Status:           customerBrokerAudit.Status,
				AuditAt:          customerBrokerAudit.AuditAt.Time.Unix(),
				Reason:           customerBrokerAudit.Reason,
				AuditUserId:      customerBrokerAudit.AuditUserId,
				AuditUserName:    customerBrokerAudit.AuditUser.Name,
				CreatedAt:        customerBrokerAudit.CreatedAt.Unix(),
				UpdateAt:         customerBrokerAudit.UpdatedAt.Unix(),
			})
		}
	}
	return
}

type customerBrokerAuditInfo struct {
	Id           uint                        `json:"id"`
	AuditUser    string                      `json:"auditUser"`
	AuditStatus  uint                        `json:"audit_status"`
	AuditTime    int64                       `json:"auditTime"`
	CustomerInfo customerBrokerAuditCustomer `json:"customerInfo"`
	BrokerInfo   customerBrokerAuditBroker   `json:"brokerInfo"`
}
type customerBrokerAuditCustomer struct {
	Id           uint   `json:"id"`
	Name         string `json:"name"`
	Tel          string `json:"tel"`
	RegisterTime int64  `json:"registerTime"`
}
type customerBrokerAuditBroker struct {
	Reason   string                        `json:"reason"`
	CreateAt int64                         `json:"createAt"`
	Origin   customerBrokerAuditBrokerInfo `json:"origin"`
	New      customerBrokerAuditBrokerInfo `json:"new"`
}
type customerBrokerAuditBrokerInfo struct {
	Id           uint   `json:"id"`
	Name         string `json:"name"`
	Tel          string `json:"tel"`
	BusinessName string `json:"businessName"`
	BusinessTel  string `json:"businessTel"`
}

// Info @Title 申请详情
func (c *customerBrokerLogic) Info(auditId uint) (result customerBrokerAuditInfo, err error) {
	customerBrokerAudit := model.CustomerBrokerAudit{Id: auditId}
	if mysql.Db.Preload("OriginBroker.Business").Preload("NewBroker.Business").Preload("Customer").Preload("AuditUser").First(&customerBrokerAudit).Error != nil {
		return result, errors.New("申请单错误")
	}
	result = customerBrokerAuditInfo{
		Id:          customerBrokerAudit.Id,
		AuditUser:   customerBrokerAudit.AuditUser.Name,
		AuditStatus: customerBrokerAudit.Status,
		AuditTime:   customerBrokerAudit.AuditAt.Time.Unix(),
		CustomerInfo: customerBrokerAuditCustomer{
			Id:           customerBrokerAudit.CustomerId,
			Name:         customerBrokerAudit.Customer.Nickname,
			Tel:          customerBrokerAudit.Customer.Mobile,
			RegisterTime: customerBrokerAudit.Customer.CreatedAt.Unix(),
		},
		BrokerInfo: customerBrokerAuditBroker{
			Reason:   customerBrokerAudit.Reason,
			CreateAt: customerBrokerAudit.CreatedAt.Unix(),
			Origin: customerBrokerAuditBrokerInfo{
				Id:           customerBrokerAudit.OriginBrokerId,
				Name:         customerBrokerAudit.OriginBroker.Nickname,
				Tel:          customerBrokerAudit.OriginBroker.Phone,
				BusinessName: customerBrokerAudit.OriginBroker.Business.Name,
				BusinessTel:  customerBrokerAudit.OriginBroker.Business.Telephone,
			},
			New: customerBrokerAuditBrokerInfo{
				Id:           customerBrokerAudit.NewBrokerId,
				Name:         customerBrokerAudit.NewBroker.Nickname,
				Tel:          customerBrokerAudit.NewBroker.Phone,
				BusinessName: customerBrokerAudit.NewBroker.Business.Name,
				BusinessTel:  customerBrokerAudit.NewBroker.Business.Telephone,
			},
		},
	}
	return
}

// Adopt @Title 审核通过
func (c *customerBrokerLogic) Adopt(manageId, auditId uint) error {
	audit := model.CustomerBrokerAudit{Id: auditId}
	if mysql.Db.First(&audit).Error != nil {
		return errors.New("审核单错误")
	}
	if audit.Status != model.CustomerBrokerAuditWait {
		return errors.New("已审核，请勿重复操作")
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Model(&audit).Where(&audit).UpdateColumns(map[string]interface{}{
			"status":        model.CustomerBrokerAuditAdopt,
			"audit_at":      time.Now(),
			"audit_user_id": manageId,
		}).RowsAffected != 1 {
			return errors.New("审核失败")
		}
		if err := CustomerLogic.Distribute([]uint{audit.CustomerId}, model.Broker{Id: audit.NewBrokerId}); err != nil {
			return err
		}
		return nil
	})
}

// Reject @Title 审核驳回
func (c *customerBrokerLogic) Reject(manageId, auditId uint, reason string) error {
	audit := model.CustomerBrokerAudit{Id: auditId}
	if mysql.Db.First(&audit).Error != nil {
		return errors.New("审核单错误")
	}
	if audit.Status != model.CustomerBrokerAuditWait {
		return errors.New("已审核，请勿重复操作")
	}
	if mysql.Db.Model(&audit).Where(&audit).UpdateColumns(map[string]interface{}{
		"status":        model.CustomerBrokerAuditReject,
		"audit_at":      time.Now(),
		"reason":        reason,
		"audit_user_id": manageId,
	}).RowsAffected != 1 {
		return errors.New("审核失败")
	}
	return nil
}
