package message

import (
	"base/app/lib/websocket"
	"base/app/model"
	"encoding/json"
	"errors"
	"fmt"
	"gorm.io/gorm"
)

var MessageLogic = &messageLogic{}

type messageLogic struct {
}

type MessageItem struct {
	Title    string                 `json:"title"`
	Content  string                 `json:"content"`
	LinkedId uint                   `json:"linkedId"`
	Extras   map[string]interface{} `json:"extras"`
}

// MessageToCustomer @Title 发送消息步骤
func (m *messageLogic) MessageToCustomer(tx *gorm.DB, customerIds []uint, messageType uint, item MessageItem) error {
	if len(customerIds) == 0 {
		return nil
	}
	var customerMessages []model.CustomerMessage
	for _, customerId := range customerIds {
		customerMessages = append(customerMessages, model.CustomerMessage{
			CustomerId: customerId,
			Type:       messageType,
			Status:     model.CustomerMessageStatusNotRead,
			Title:      item.Title,
			Content:    item.Content,
		})
	}
	if tx.Create(&customerMessages).Error != nil {
		return errors.New("发送消息失败")
	}
	m.sendToCustomer(customerIds, item)
	return nil
}

// MessageToBroker @Title 发送消息步骤
func (m *messageLogic) MessageToBroker(tx *gorm.DB, brokerIds []uint, messageType uint, item MessageItem) error {
	if len(brokerIds) == 0 {
		return nil
	}
	extras, _ := json.Marshal(&item.Extras)
	var brokerMessages []model.BrokerMessage
	for _, brokerId := range brokerIds {
		brokerMessages = append(brokerMessages, model.BrokerMessage{
			BrokerId: brokerId,
			Type:     messageType,
			Status:   model.BrokerMessageStatusNotRead,
			Title:    item.Title,
			Content:  item.Content,
			LinkedId: item.LinkedId,
			Extras:   string(extras),
		})
	}
	if tx.Create(&brokerMessages).Error != nil {
		return errors.New("发送消息失败")
	}
	m.sendToBroker(brokerIds, item)
	return nil
}

// sendToCustomer @Title 发送消息到客户
func (m *messageLogic) sendToCustomer(customerIds []uint, item MessageItem) {
	body, _ := json.Marshal(&item)
	for _, customerId := range customerIds {
		websocket.WebsocketManager.SendGroup(fmt.Sprintf(websocket.CustomerKey, customerId), body)
	}
}

// sendToBroker @Title 发送消息到经纪人
func (m *messageLogic) sendToBroker(brokerIds []uint, item MessageItem) {
	body, _ := json.Marshal(&item)
	for _, brokerId := range brokerIds {
		websocket.WebsocketManager.SendGroup(fmt.Sprintf(websocket.BrokerKey, brokerId), body)
	}
}

//// Send @Title 发送消息
//func (m *messageLogic) Send(manageIds []uint, item MessageItem) {
//	log.Println(m)
//	m.sendWebsocket(manageIds, item)
//	return
//}
//
//// @Title 发送websocket消息
//func (m *messageLogic) sendWebsocket(manageIds []uint, item MessageItem) {
//	body, _ := json.Marshal(&item)
//	for _, manageId := range manageIds {
//		websocket.WebsocketManager.SendGroup(fmt.Sprintf(CustomerKey, manageId), body)
//	}
//}
