package order

import (
	"base/app/lib/bean"
	"base/app/model"
	"fmt"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
)

var DealerConsignmentLogic = &dealerConsignmentLogic{}

type dealerConsignmentLogic struct {
}
type dealerConsignmentItem struct {
	Id        uint            `json:"id"`
	OrderSn   string          `json:"orderSn"`
	MainPhoto string          `json:"mainPhoto"`
	ModelName string          `json:"modelName"`
	Price     decimal.Decimal `json:"price"`
	Status    uint            `json:"status"`
	CreatedAt int64           `json:"createdAt"`
}
type DealerConsignmentSearch struct {
	//Status           uint `binding:"oneof=0 1 2 3" label:"状态"` // 1=交易中 2=交易完成 3=交易取消
	OrderSn    string
	CarSn      string
	PriceType  uint
	Price      decimal.Decimal
	ContractSn string
	//SearchStatus     uint
	CreatedDateStart string
	CreatedDateEnd   string
	CancelDateStart  string
	CancelDateEnd    string
	FinishDateStart  string
	FinishDateEnd    string
}

// Lists @Title 寄卖订单列表
func (c *dealerConsignmentLogic) Lists(search DealerConsignmentSearch, page bean.Page) (lists []dealerConsignmentItem, total int64) {
	lists = []dealerConsignmentItem{}
	var consignments []model.OrderDealerConsignment
	where := mysql.Db
	// 车辆编号
	if search.CarSn != "" {
		where = where.Where("id in (?)",
			mysql.Db.Model(&model.OrderDealerConsignmentCar{}).Select("order_id").
				Where("car_id in (?)", mysql.Db.Model(&model.Car{}).Select("id").
					Where("car_sn like ?", fmt.Sprintf("%%%s%%", search.CarSn))))
	}
	// 成交价格
	if !search.Price.IsZero() {
		switch search.PriceType {
		case 1: // 大于等于
			where = where.Where("price >= ?", search.Price)
		case 2: // 小于等于
			where = where.Where("price <= ?", search.Price)
		}
	}
	// 合同编号
	if search.OrderSn != "" {
		where = where.Where("order_sn like ?", fmt.Sprintf("%%%s%%", search.OrderSn))
	}
	// 创建日期
	if search.CreatedDateStart != "" && search.CreatedDateEnd != "" {
		where = where.Where("created_at >= ? and created_at <= ?", search.CreatedDateStart, search.CreatedDateEnd+" 23:59:59")
	}
	// 取消日期
	if search.CancelDateStart != "" && search.CancelDateEnd != "" {
		where = where.Where("cancel_at >= ? and cancel_at <= ?", search.CancelDateStart, search.CancelDateEnd+" 23:59:59")
	}
	// 售出日期
	if search.FinishDateStart != "" && search.FinishDateEnd != "" {
		where = where.Where("sale_at >= ? and sale_at <= ?", search.FinishDateStart, search.FinishDateEnd+" 23:59:59")
	}
	mysql.Db.Model(&consignments).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("DealerCar.Model").Preload("DealerCar.Car").
			Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("id desc").Find(&consignments)
		for _, consignment := range consignments {
			lists = append(lists, dealerConsignmentItem{
				Id:        consignment.Id,
				OrderSn:   consignment.OrderSn,
				MainPhoto: consignment.DealerCar.MainPhoto,
				ModelName: consignment.DealerCar.Model.Name,
				Price:     consignment.DealerCar.Car.Price,
				Status:    consignment.Status,
				CreatedAt: consignment.CreatedAt.Unix(),
			})
		}
	}
	return
}
