package order

import (
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"fmt"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
	"gorm.io/gorm"
	"time"
)

var SalePaymentAuditLogic = &salePaymentAuditLogic{}

type salePaymentAuditLogic struct {
}
type salePaymentAuditItem struct {
	Id             uint            `json:"id"`
	OrderSn        string          `json:"orderSn"`
	CarSn          string          `json:"carSn"`
	ContractSn     string          `json:"contractSn"`
	MainPhoto      string          `json:"mainPhoto"`
	ModelName      string          `json:"modelName"`
	CarId          uint            `json:"carId"`
	Amount         decimal.Decimal `json:"amount"`
	DownPayment    decimal.Decimal `json:"downPayment"`
	BalancePayment decimal.Decimal `json:"balancePayment"`
	Customer       string          `json:"customer"`
	Mobile         string          `json:"mobile"`
	CreatedAt      int64           `json:"createdAt"`
	Type           uint            `json:"type"`
	Status         uint            `json:"status"`
}
type SalePaymentAuditSearch struct {
	Type             uint `binding:"oneof=0 1 2" label:"种类"`   // 1=首付审核 2=尾款审核
	Status           uint `binding:"oneof=0 1 2 3" label:"状态"` // 1=待审核 2=审核通过 3=审核驳回
	OrderSn          string
	CarSn            string
	TotalAmountType  uint
	TotalAmount      decimal.Decimal
	ContractSn       string
	CreatedDateStart string
	CreatedDateEnd   string
	AuditDateStart   string
	AuditDateEnd     string
}

// Lists @Title 款项审核列表
func (s *salePaymentAuditLogic) Lists(search SalePaymentAuditSearch, page bean.Page) (lists []salePaymentAuditItem, total int64) {
	lists = []salePaymentAuditItem{}
	var saleAudits []model.OrderSaleAudit
	where := mysql.Db
	switch search.Type {
	case 1: // 首付审核
		where = where.Where("type = ?", model.OrderSaleAuditTypeDownPayment)
	case 2: // 尾款审核
		where = where.Where("type = ?", model.OrderSaleAuditTypeBalancePayment)
	}
	switch search.Status {
	case 1: // 待审核
		where = where.Where("status = ?", model.OrderSaleAuditStatusAudit)
	case 2: // 审核通过
		where = where.Where("status = ?", model.OrderSaleAuditStatusAdopt)
	case 3: // 审核驳回
		where = where.Where("status = ?", model.OrderSaleAuditStatusReject)
	}
	// 订单编号
	if search.OrderSn != "" {
		where = where.Where("order_id in (?)", mysql.Db.Model(&model.OrderSale{}).Select("id").Where("order_sn like ?", fmt.Sprintf("%%%s%%", search.OrderSn)))
	}
	// 合同筛选
	{
		contractWhere := mysql.Db.Model(&model.ContractSale{}).Select("id")
		// 订单总价
		if !search.TotalAmount.IsZero() {
			switch search.TotalAmountType {
			case 1: // 大于等于
				contractWhere = contractWhere.Where("amount >= ?", search.TotalAmount)
			case 2: // 小于等于
				contractWhere = contractWhere.Where("amount <= ?", search.TotalAmount)
			}
		}
		// 合同编号
		if search.ContractSn != "" {
			contractWhere = contractWhere.Where("contract_sn like ?", fmt.Sprintf("%%%s%%", search.ContractSn))
		}
		if _, ok := contractWhere.Statement.Clauses["WHERE"]; ok {
			where = where.Where("order_id in (?)", mysql.Db.Model(&model.OrderSale{}).Select("id").Where("contract_id in (?)", contractWhere))
		}
	}
	// 车辆编号
	if search.CarSn != "" {
		where = where.Where("car_id in (?)", mysql.Db.Model(&model.Car{}).Select("id").Where("car_sn like ?", fmt.Sprintf("%%%s%%", search.CarSn)))
	}
	// 订单创建日期
	if search.CreatedDateStart != "" && search.CreatedDateEnd != "" {
		where = where.Where("created_at >= ? and created_at <= ?", search.CreatedDateStart, search.CreatedDateEnd+" 23:59:59")
	}
	// 订单审核日期
	if search.AuditDateStart != "" && search.AuditDateEnd != "" {
		where = where.Where("audit_at >= ? and audit_at <= ?", search.AuditDateStart, search.AuditDateEnd+" 23:59:59")
	}
	mysql.Db.Model(&saleAudits).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("Order.Car.Model").
			Preload("Order.Contract").Preload("Order.Customer").
			Where(where).Offset(page.GetStart()).Order("created_at desc").Limit(page.GetLimit()).Find(&saleAudits)
		for _, saleAudit := range saleAudits {
			lists = append(lists, salePaymentAuditItem{
				Id:             saleAudit.Id,
				OrderSn:        saleAudit.Order.OrderSn,
				CarSn:          saleAudit.Order.Car.CarSn,
				ContractSn:     saleAudit.Order.Contract.ContractSn,
				MainPhoto:      saleAudit.Order.Car.MainPhoto,
				ModelName:      saleAudit.Order.Car.Model.Name,
				CarId:          saleAudit.Order.Car.Id,
				Amount:         saleAudit.Order.Contract.Amount,
				DownPayment:    saleAudit.Order.Contract.DownPayment,
				BalancePayment: saleAudit.Order.Contract.BalancePayment,
				Customer:       saleAudit.Order.Customer.Nickname,
				Mobile:         saleAudit.Order.Customer.Mobile,
				CreatedAt:      saleAudit.CreatedAt.Unix(),
				Type:           saleAudit.Type,
				Status:         saleAudit.Status,
			})
		}
	}
	return
}

type saleAuditInfo struct {
	Id             uint               `json:"id"`
	OrderSn        string             `json:"orderSn"`
	BrokerName     string             `json:"brokerName"`
	CarModel       string             `json:"carModel"`
	CreatedAt      int64              `json:"createdAt"`
	Type           uint               `json:"type"`
	TypeName       string             `json:"typeName"`
	Status         uint               `json:"status"`
	StatusName     string             `json:"statusName"`
	AuditUserId    uint               `json:"auditUserId"`
	AuditUserName  string             `json:"auditUserName"`
	AuditAt        int64              `json:"auditAt"`
	CarSn          string             `json:"carSn"`
	ContractSn     string             `json:"contractSn"`
	Proof          string             `json:"proof"`
	ContractDetail ContractDetail     `json:"contractDetail"`
	BrokerBusiness SaleBrokerBusiness `json:"brokerBusiness"`
	Customer       SaleCustomer       `json:"customer"`
}

type ContractDetail struct {
	Price                  decimal.Decimal `json:"price"`          // 成交价
	Deposit                decimal.Decimal `json:"deposit"`        // 定金
	DownPayment            decimal.Decimal `json:"downPayment"`    // 首付
	BalancePayment         decimal.Decimal `json:"balancePayment"` // 尾款
	SaleServiceFee         decimal.Decimal `json:"saleServiceFee"`
	SaleServiceFeeRate     decimal.Decimal // 服务费比例
	PurchaseServiceFee     decimal.Decimal `json:"purchaseSaleServiceFee"`
	PurchaseServiceFeeRate decimal.Decimal // 服务费比例
}
type SaleBrokerBusiness struct {
	Broker   SaleBroker
	Business SaleBusiness
}

type SaleBroker struct {
	Id         uint            `json:"id"`
	Name       string          `json:"name"`
	Tel        string          `json:"tel"`
	Commission decimal.Decimal `json:"commission"`
}

type SaleBusiness struct {
	Id   uint   `json:"id"`
	Name string `json:"name"`
	Tel  string `json:"tel"`
}
type SaleCustomer struct {
	Id       uint   `json:"id"`
	Name     string `json:"name"`
	Tel      string `json:"tel"`
	RealName string `json:"realName"`
	IdCard   string `json:"idCard"`
	Address  string `json:"address"`
	OpenBank string `json:"openBank"`
	BankCard string `json:"bankCard"`
}

// Info @Title 款项审核详情
func (s *salePaymentAuditLogic) Info(auditId uint) (result saleAuditInfo, err error) {
	orderSaleAudit := model.OrderSaleAudit{Id: auditId}
	if mysql.Db.
		Preload("AuditUser").
		Preload("Order.Broker.Business").
		Preload("Order.Customer").
		Preload("Order.Car.Model").
		Preload("Order.Contract.BuyerMaster").
		First(&orderSaleAudit).Error != nil {
		return result, errors.New("审核单错误")
	}
	result = saleAuditInfo{
		Id:            orderSaleAudit.Id,
		OrderSn:       orderSaleAudit.Order.OrderSn,
		BrokerName:    orderSaleAudit.Order.Broker.Nickname,
		CarModel:      orderSaleAudit.Order.Car.Model.Name,
		CreatedAt:     orderSaleAudit.CreatedAt.Unix(),
		Type:          orderSaleAudit.Type,
		AuditUserId:   orderSaleAudit.AuditUserId,
		AuditUserName: orderSaleAudit.AuditUser.Name,
		AuditAt:       orderSaleAudit.AuditAt.Time.Unix(),
		TypeName:      orderSaleAudit.GetTypeName(orderSaleAudit.Type),
		Status:        orderSaleAudit.Status,
		StatusName:    orderSaleAudit.GetStatusName(orderSaleAudit.Status),
		CarSn:         orderSaleAudit.Order.Car.CarSn,
		ContractSn:    orderSaleAudit.Order.Contract.ContractSn,
		Proof:         orderSaleAudit.Proof,
		ContractDetail: ContractDetail{
			Price:                  orderSaleAudit.Order.Contract.Amount,
			Deposit:                orderSaleAudit.Order.Contract.Deposit,
			DownPayment:            orderSaleAudit.Order.Contract.DownPayment,
			BalancePayment:         orderSaleAudit.Order.Contract.BalancePayment,
			SaleServiceFee:         orderSaleAudit.Order.Contract.SaleServiceFee,
			SaleServiceFeeRate:     orderSaleAudit.Order.Contract.SaleServiceFeeRate,
			PurchaseServiceFee:     orderSaleAudit.Order.Contract.PurchaseServiceFee,
			PurchaseServiceFeeRate: orderSaleAudit.Order.Contract.PurchaseServiceFeeRate,
		},
		BrokerBusiness: SaleBrokerBusiness{
			Broker: SaleBroker{
				Id:         orderSaleAudit.Order.Broker.Id,
				Name:       orderSaleAudit.Order.Broker.Nickname,
				Tel:        orderSaleAudit.Order.Broker.Phone,
				Commission: orderSaleAudit.Order.Broker.Staff.Commission,
			},
			Business: SaleBusiness{
				Id:   orderSaleAudit.Order.Broker.Business.Id,
				Name: orderSaleAudit.Order.Broker.Business.Name,
				Tel:  orderSaleAudit.Order.Broker.Business.Telephone,
			},
		},
		Customer: SaleCustomer{
			Id:       orderSaleAudit.Order.Customer.Id,
			Name:     orderSaleAudit.Order.Customer.Nickname,
			Tel:      orderSaleAudit.Order.Contract.BuyerMaster.Phone,
			RealName: orderSaleAudit.Order.Contract.BuyerMaster.Name,
			IdCard:   orderSaleAudit.Order.Contract.BuyerMaster.IdCard,
			Address:  orderSaleAudit.Order.Contract.BuyerMaster.Address,
			OpenBank: orderSaleAudit.Order.Contract.BuyerMaster.Bank,
			BankCard: orderSaleAudit.Order.Contract.BuyerMaster.BankCard,
		},
	}
	return
}

// Adopt @Title 审核通过
func (s *salePaymentAuditLogic) Adopt(manageId, auditId uint) error {
	saleAudit := model.OrderSaleAudit{Id: auditId}
	if mysql.Db.First(&saleAudit).Error != nil {
		return errors.New("审核单错误")
	}
	if saleAudit.Status != model.OrderSaleAuditStatusAudit {
		return errors.New("已审核，请勿重复操作")
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Model(&saleAudit).Where(&saleAudit).UpdateColumns(map[string]interface{}{
			"status":        model.OrderSaleAuditStatusAdopt,
			"audit_at":      time.Now(),
			"audit_user_id": manageId,
		}).RowsAffected != 1 {
			return errors.New("审核失败")
		}
		switch saleAudit.Type {
		case model.OrderSaleAuditTypeDownPayment: //首付审核
			if tx.Model(&model.OrderSale{}).Where("id  = ? and status = ?", saleAudit.OrderId, model.OrderSaleStatusDownPaymentAudit).UpdateColumn("status", model.OrderSaleStatusDownPaymentAdopt).RowsAffected != 1 {
				return errors.New("审核失败")
			}
		case model.OrderSaleAuditTypeBalancePayment: //尾款审核
			if tx.Model(&model.OrderSale{}).Where("id  = ? and status = ?", saleAudit.OrderId, model.OrderSaleStatusBalancePaymentAudit).UpdateColumn("status", model.OrderSaleStatusBalancePaymentAdopt).RowsAffected != 1 {
				return errors.New("审核失败")
			}
		}
		return nil
	})
}

// Reject @Title 审核驳回
func (s *salePaymentAuditLogic) Reject(manageId, auditId uint, reason string) error {
	saleAudit := model.OrderSaleAudit{Id: auditId}
	if mysql.Db.First(&saleAudit).Error != nil {
		return errors.New("审核单错误")
	}
	if saleAudit.Status != model.OrderSaleAuditStatusAudit {
		return errors.New("已审核，请勿重复操作")
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if mysql.Db.Model(&saleAudit).Where(&saleAudit).UpdateColumns(map[string]interface{}{
			"status":        model.OrderSaleAuditStatusReject,
			"audit_at":      time.Now(),
			"reason":        reason,
			"audit_user_id": manageId,
		}).RowsAffected != 1 {
			return errors.New("审核失败")
		}
		switch saleAudit.Type {
		case model.OrderSaleAuditTypeDownPayment: //首付审核
			if tx.Model(&model.OrderSale{}).Where("id  = ? and status = ?", saleAudit.OrderId, model.OrderSaleStatusDownPaymentAudit).UpdateColumn("status", model.OrderSaleStatusUploadTestReport).RowsAffected != 1 {
				return errors.New("审核失败")
			}
		case model.OrderSaleAuditTypeBalancePayment: //尾款审核
			if tx.Model(&model.OrderSale{}).Where("id  = ? and status = ?", saleAudit.OrderId, model.OrderSaleStatusBalancePaymentAudit).UpdateColumn("status", model.OrderSaleStatusTransferFinal).RowsAffected != 1 {
				return errors.New("审核失败")
			}
		}
		return nil
	})
}
