package playbill

import (
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"git.oa00.com/go/mysql"
	"github.com/shopspring/decimal"
)

var PlaybillLogic = &playbillLogic{}

type playbillLogic struct {
}
type playbillItem struct {
	Id        uint   `json:"id"`
	Path      string `json:"path"`
	Status    uint   `json:"status"`
	Sort      uint   `json:"sort"`
	CreatedAt int64  `json:"createdAt"`
}
type PlaybillSearch struct {
	Status uint
}

// Lists @Title 海报列表
func (l *playbillLogic) Lists(search PlaybillSearch, page bean.Page) (lists []playbillItem, total int64) {
	lists = []playbillItem{}
	var playbills []model.Playbill
	where := mysql.Db
	if search.Status > 0 {
		switch search.Status {
		case 1: // 启用
			where = where.Where("status = ?", model.PlaybillStatusEnabled)
		case 2: // 停用
			where = where.Where("status = ?", model.PlaybillStatusDisabled)
		}
	}
	mysql.Db.Model(playbills).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Find(&playbills)
		for _, playbill := range playbills {
			lists = append(lists, playbillItem{
				Id:        playbill.Id,
				Path:      playbill.Path,
				Status:    playbill.Status,
				Sort:      playbill.Sort,
				CreatedAt: playbill.CreatedAt.Unix(),
			})
		}
	}
	return
}

type PlaybillAdd struct {
	Path   string          `binding:"required" label:"底图"`
	Status uint            `binding:"required,oneof=1 2" label:"状态"`
	AxisX  decimal.Decimal `binding:"required" label:"x轴"`
	AxisY  decimal.Decimal `binding:"required" label:"y轴"`
	Size   decimal.Decimal `binding:"required" label:"二维码尺寸"`
	Sort   uint            `binding:"required" label:"排序"`
}

// Add @Title 添加海报
func (l *playbillLogic) Add(data PlaybillAdd) error {
	playbill := model.Playbill{
		Path:   data.Path,
		Status: data.Status,
		AxisX:  data.AxisX,
		AxisY:  data.AxisY,
		Size:   data.Size,
		Sort:   data.Sort,
	}
	if mysql.Db.Create(&playbill).Error != nil {
		return errors.New("添加失败")
	}
	return nil
}

type playbillInfo struct {
	Id     uint            `json:"id"`
	Path   string          `json:"path"`
	Status uint            `json:"status"`
	AxisX  decimal.Decimal `json:"axisX"`
	AxisY  decimal.Decimal `json:"axisY"`
	Size   decimal.Decimal `json:"size"`
	Sort   uint            `json:"sort"`
}

// Info @Title 海报详情
func (l *playbillLogic) Info(playbillId uint) (result playbillInfo, err error) {
	playbill := model.Playbill{Id: playbillId}
	if mysql.Db.First(&playbill).Error != nil {
		return result, errors.New("海报错误")
	}
	result = playbillInfo{
		Id:     playbill.Id,
		Path:   playbill.Path,
		Status: playbill.Status,
		AxisX:  playbill.AxisX,
		AxisY:  playbill.AxisY,
		Size:   playbill.Size,
		Sort:   playbill.Sort,
	}
	return
}

// Edit @Title 编辑海报
func (l *playbillLogic) Edit(playbillId uint, data PlaybillAdd) error {
	playbill := model.Playbill{Id: playbillId}
	if mysql.Db.First(&playbill).Error != nil {
		return errors.New("海报错误")
	}
	playbill.Path = data.Path
	playbill.Status = data.Status
	playbill.AxisX = data.AxisX
	playbill.AxisY = data.AxisY
	playbill.Size = data.Size
	playbill.Sort = data.Sort
	if mysql.Db.Save(&playbill).Error != nil {
		return errors.New("编辑失败")
	}
	return nil
}

// Delete @Title 删除海报
func (l *playbillLogic) Delete(playbillId uint) error {
	playbill := model.Playbill{Id: playbillId}
	if mysql.Db.Delete(&playbill).Error != nil {
		return errors.New("删除失败")
	}
	return nil
}
