package popularize

import (
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"fmt"
	"git.oa00.com/go/mysql"
)

var BrandLogic = &brandLogic{}

type brandLogic struct {
}
type brandItem struct {
	Id              uint   `json:"id"`
	BrandName       string `json:"brandName"`
	BrandStatus     uint   `json:"brandStatus"`
	CreatedUserName string `json:"createdUserName"`
	Sort            uint   `json:"sort"`
	CreatedAt       int64  `json:"createdAt"`
}
type BrandSearch struct {
	BrandName        string
	BrandStatus      uint
	CreatedDateStart string
	CreatedDateEnd   string
}

// Lists @Title 品牌推广列表
func (b *brandLogic) Lists(search BrandSearch, page bean.Page) (lists []brandItem, total int64) {
	lists = []brandItem{}
	var popularizeCarBrands []model.PopularizeCarBrand
	where := mysql.Db
	// 品牌筛选
	if search.BrandName != "" || search.BrandStatus > 0 {
		brandWhere := mysql.Db.Model(&model.CarBrand{}).Select("id")
		if search.BrandName != "" {
			brandWhere = brandWhere.Where("name like ?", fmt.Sprintf("%%%s%%", search.BrandName))
		}
		if search.BrandStatus > 0 {
			switch search.BrandStatus {
			case 1: // 启用
				brandWhere = brandWhere.Where("status = ?", model.CarBrandStatusEnabled)
			case 2: // 停用
				brandWhere = brandWhere.Where("status = ?", model.CarBrandStatusDisabled)
			}
		}
		where = where.Where("brand_id in (?)", brandWhere)
	}
	if search.CreatedDateStart != "" || search.CreatedDateEnd != "" {
		where = where.Where("created_at >= ? and created_at >= ?", search.CreatedDateStart, search.CreatedDateEnd+" 23:59:59")
	}
	mysql.Db.Model(&popularizeCarBrands).Where(where).Count(&total)
	if page.HasPage(total) {
		mysql.Db.Preload("Brand").Preload("CreatedUser").
			Where(where).Offset(page.GetStart()).Limit(page.GetLimit()).Order("sort desc").Find(&popularizeCarBrands)
		for _, popularizeCarBrand := range popularizeCarBrands {
			lists = append(lists, brandItem{
				Id:              popularizeCarBrand.Id,
				BrandName:       popularizeCarBrand.Brand.Name,
				BrandStatus:     popularizeCarBrand.Brand.Status,
				CreatedUserName: popularizeCarBrand.CreatedUser.Name,
				Sort:            popularizeCarBrand.Sort,
				CreatedAt:       popularizeCarBrand.CreatedAt.Unix(),
			})
		}
	}
	return
}

// Add @Title 添加品牌
func (b *brandLogic) Add(manageId, brandId uint) error {
	brand := model.CarBrand{Id: brandId}
	if mysql.Db.First(&brand).Error != nil {
		return errors.New("品牌错误")
	}
	carBrand := model.PopularizeCarBrand{
		BrandId:       brandId,
		Sort:          100,
		CreatedUserId: manageId,
	}
	if mysql.Db.Create(&carBrand).Error != nil {
		return errors.New("品牌已添加，请勿重复操作")
	}
	return nil
}

// EditBrand @Title 编辑品牌
func (b *brandLogic) EditBrand(popularizeBrandId, brandId uint) error {
	popularizeCarBrand := model.PopularizeCarBrand{Id: popularizeBrandId}
	if mysql.Db.First(&popularizeCarBrand).Error != nil {
		return errors.New("推广品牌错误")
	}
	brand := model.CarBrand{Id: brandId}
	if mysql.Db.First(&brand).Error != nil {
		return errors.New("品牌错误")
	}
	popularizeCarBrand.BrandId = brandId
	if mysql.Db.Save(&popularizeCarBrand).Error != nil {
		return errors.New("品牌已添加，请勿重复操作")
	}
	return nil
}

// EditSort @Title 编辑排序
func (b *brandLogic) EditSort(popularizeBrandId, sort uint) error {
	popularizeCarBrand := model.PopularizeCarBrand{Id: popularizeBrandId}
	if mysql.Db.First(&popularizeCarBrand).Error != nil {
		return errors.New("推广品牌错误")
	}
	popularizeCarBrand.Sort = sort
	if mysql.Db.Save(&popularizeCarBrand).Error != nil {
		return errors.New("提交失败")
	}
	return nil
}

// Delete @Title 删除
func (b *brandLogic) Delete(popularizeBrandId uint) error {
	if mysql.Db.Where("id  = ?", popularizeBrandId).Delete(&model.PopularizeCarBrand{}).Error != nil {
		return errors.New("提交失败")
	}
	return nil
}
