package setting

import (
	"base/app/common"
	"base/app/lib/bean"
	"base/app/model"
	"errors"
	"fmt"
	"git.oa00.com/go/acs"
	"git.oa00.com/go/mysql"
	"gorm.io/gorm"
	"path"
)

var ApiLogic = &apiLogic{}

type apiLogic struct {
}

type apiItem struct {
	Id       uint       `json:"id"`
	ParentId uint       `json:"parentId"`
	Name     string     `json:"name"`
	Path     string     `json:"path"`
	Children []*apiItem `json:"children"`
}

// All @Title 获取全部接口
func (a *apiLogic) All() (result []apiItem) {
	var apis []model.SettingApi
	mysql.Db.Find(&apis)
	for _, api := range apis {
		result = append(result, apiItem{
			Id:       api.Id,
			ParentId: api.ParentId,
			Name:     api.Name,
			Path:     api.Path,
		})
	}
	return a.getTree(result)
}

// Add @Title 添加api接口
func (a *apiLogic) Add(parentId uint, apiName, apiPath string) error {
	apiPath = path.Join("/", apiPath)
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		api := model.SettingApi{
			ParentId: parentId,
			Name:     apiName,
			Path:     apiPath,
		}
		if tx.Create(&api).Error != nil {
			return errors.New("添加失败")
		}
		if _, err := acs.Enforcer.AddPolicy(fmt.Sprintf("api_%d", api.Id), apiPath, "POST"); err != nil {
			return errors.New("添加失败")
		}
		return nil
	})
}

// Edit @Title 编辑api接口
func (a *apiLogic) Edit(apiId, parentId uint, apiName, apiPath string) error {
	apiPath = path.Join("/", apiPath)
	api := model.SettingApi{Id: apiId}
	if mysql.Db.First(&api).Error != nil {
		return errors.New("接口错误")
	}
	if parentId > 0 && api.ParentId != parentId {
		if apiId == parentId {
			return errors.New("上级接口错误")
		}
		settingApi := model.SettingApi{Id: api.ParentId}
		if mysql.Db.First(&settingApi).Error != nil {
			return errors.New("上级接口错误")
		}
		var parents []model.SettingApi
		common.FindParents(mysql.Db.NamingStrategy.TableName("SettingApi"), "id", "parent_id", api.ParentId, &parents)
		for _, parent := range parents {
			if parent.Id == api.Id {
				return errors.New("上级接口错误")
			}
		}
	}
	api.ParentId = parentId
	api.Name = apiName
	api.Path = apiPath
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Updates(&api).Error != nil {
			return errors.New("编辑失败")
		}
		if _, err := acs.Enforcer.RemovePolicy(fmt.Sprintf("api_%d", api.Id)); err != nil {
			return errors.New("编辑失败")
		}
		if _, err := acs.Enforcer.AddPolicy(fmt.Sprintf("api_%d", api.Id), apiPath, "POST"); err != nil {
			return errors.New("编辑失败")
		}
		return nil
	})
}

// Del @Title 删除api接口
func (a *apiLogic) Del(apiId uint) error {
	var total int64
	api := model.SettingApi{}
	mysql.Db.Model(api).Where("parent_id = ?", apiId).Count(&total)
	if total > 0 {
		return errors.New("拥有下级接口，无法删除")
	}
	return mysql.Db.Transaction(func(tx *gorm.DB) error {
		if tx.Where("id = ?", apiId).Delete(&api).Error != nil {
			return errors.New("删除失败")
		}
		tx.Model(api).Where("parent_id = ?", apiId).Count(&total)
		if total > 0 {
			return errors.New("拥有下级接口，无法删除")
		}
		if _, err := acs.Enforcer.RemovePolicy(fmt.Sprintf("api_%d", api.Id)); err != nil {
			return errors.New("删除失败")
		}
		return nil
	})
}

// @Title 获取菜单树
func (a *apiLogic) getTree(datas []apiItem) (result []apiItem) {
	result = []apiItem{}
	for i, item := range datas {
		if item.ParentId > 0 {
			for index, value := range datas {
				if item.ParentId == value.Id {
					datas[index].Children = append(datas[index].Children, &datas[i])
					break
				}
			}
		}
	}
	for _, item := range datas {
		if item.ParentId == 0 {
			result = append(result, item)
		}
	}
	return
}

// Select @Title api接口筛选
func (a *apiLogic) Select() (result []bean.SelectItem) {
	all := a.All()
	for _, item := range all {
		result = append(result, bean.SelectItem{
			Id:   item.Id,
			Name: item.Name,
		})
		if item.Children != nil {
			result = append(result, a.sortSelect(item.Children)...)
		}
	}
	return
}

func (a *apiLogic) sortSelect(data []*apiItem) (result []bean.SelectItem) {
	for _, item := range data {
		result = append(result, bean.SelectItem{
			Id:   item.Id,
			Name: item.Name,
		})
		if item.Children != nil {
			result = append(result, a.sortSelect(item.Children)...)
		}
	}
	return result
}
