package order

import (
	"base/app/logic/broker/user/wallet"
	wallet2 "base/app/logic/customer/user/wallet"
	"base/app/logic/pay"
	"base/app/model"
	"errors"
	"gorm.io/gorm"
)

var AssessLogic = &assessLogic{}

type assessLogic struct {
}

func init() {
	pay.MapNotify[model.PayOrderTypeAssess] = AssessLogic
}

// Success @Title 付款成功
func (a *assessLogic) Success(db *gorm.DB, orderId uint, payModel model.Pay) error {
	orderAssess := model.OrderAssess{Id: orderId}
	if db.First(&orderAssess).Error != nil {
		return errors.New("订单错误")
	}
	if orderAssess.Status == model.OrderAssessStatusPay {
		return nil
	}
	if db.Model(&orderAssess).Where(&orderAssess).UpdateColumns(map[string]interface{}{
		"status": model.OrderAssessStatusPay,
	}).RowsAffected != 1 {
		return nil
	}
	switch orderAssess.Type {
	case model.OrderAssessTypeCustomer: // 客户订单
		if err := wallet2.AssessLogic.Add(db, orderAssess.UserId, orderAssess.Id, int(orderAssess.Count)); err != nil {
			return err
		}
	case model.OrderAssessTypeBroker: // 经纪人订单
		if err := wallet.AssessLogic.Add(db, orderAssess.UserId, orderAssess.Id, orderAssess.Kind, int(orderAssess.Count)); err != nil {
			return err
		}
	case model.OrderAssessTypeDealer: // 车商订单
		if err := wallet.AssessLogic.DealerAdd(db, orderAssess.UserId, orderAssess.Id, orderAssess.Kind, int(orderAssess.Count)); err != nil {
			return err
		}
	}
	return nil
}

// Fail @Title 付款失败
func (a *assessLogic) Fail(db *gorm.DB, orderId uint, payModel model.Pay) error {
	return nil
}

// RefundSuccess @Title 退款成功
func (a *assessLogic) RefundSuccess(db *gorm.DB, orderId uint, payModel model.Pay) error {
	return nil
}
