package order

import (
	"base/app/logic/pay"
	"base/app/model"
	"errors"
	"gorm.io/gorm"
)

var CallCarLogic = &callCarLogic{}

type callCarLogic struct {
}

func init() {
	pay.MapNotify[model.PayOrderTypeCallCar] = CallCarLogic
}

// Success @Title 付款成功
func (c *callCarLogic) Success(db *gorm.DB, orderId uint, payModel model.Pay) error {
	orderCallCar := model.OrderCallCar{Id: orderId}
	if db.First(&orderCallCar).Error != nil {
		return errors.New("订单错误")
	}
	if orderCallCar.Status == model.OrderCallCarStatusPay {
		return nil
	}
	if db.Model(&orderCallCar).Where(&orderCallCar).UpdateColumns(map[string]interface{}{
		"status": model.OrderCallCarStatusPay,
		"pay_id": payModel.Id,
	}).RowsAffected != 1 {
		return nil
	}
	return nil
}

// Fail @Title 付款失败
func (c *callCarLogic) Fail(db *gorm.DB, orderId uint, payModel model.Pay) error {
	return nil
}

// RefundSuccess @Title 退款成功
func (c *callCarLogic) RefundSuccess(db *gorm.DB, orderId uint, payModel model.Pay) error {
	orderCallCar := model.OrderCallCar{Id: orderId}
	if db.First(&orderCallCar).Error != nil {
		return errors.New("订单错误")
	}
	if orderCallCar.Status == model.OrderCallCarStatusRefund {
		return nil
	}
	if db.Model(&model.OrderCallCar{}).Where(&orderCallCar).Updates(map[string]interface{}{
		"status": model.OrderCallCarStatusRefund,
		"pay_id": payModel.Id,
	}).RowsAffected != 1 {
		return nil
	}
	return nil
}
