package order

import (
	"base/app/logic/customer/car"
	"base/app/logic/pay"
	"base/app/model"
	"errors"
	"gorm.io/gorm"
)

var EstimatePayLogic = &estimatePayLogic{}

type estimatePayLogic struct {
}

func init() {
	pay.MapNotify[model.PayOrderTypeEstimatePay] = EstimatePayLogic
}

// Success @Title 付款成功
func (e *estimatePayLogic) Success(db *gorm.DB, orderId uint, payModel model.Pay) error {
	orderEstimatePay := model.OrderEstimatePay{Id: orderId}
	if db.First(&orderEstimatePay).Error != nil {
		return errors.New("估价订单错误")
	}
	if orderEstimatePay.Status == model.OrderEstimatePayStatusPay {
		return nil
	}
	if db.Model(&orderEstimatePay).Where(&orderEstimatePay).UpdateColumns(map[string]interface{}{
		"status": model.OrderEstimatePayStatusPay,
	}).RowsAffected != 1 {
		return errors.New("修改估价订单完成支付状态失败")
	}
	customerCarPrice := model.CustomerCarPrice{OrderId: orderEstimatePay.Id}
	if db.Where(&customerCarPrice).First(&customerCarPrice).Error != nil {
		return errors.New("估价记录错误")
	}
	if customerCarPrice.PayStatus == model.OrderEstimatePayStatusPay {
		return nil
	}
	if db.Model(&customerCarPrice).Where(&customerCarPrice).UpdateColumns(map[string]interface{}{
		"pay_status": model.CustomerCarPricePayStatusPay,
	}).RowsAffected != 1 {
		return errors.New("修改估价记录完成支付状态失败")
	}
	if _, err := car.PriceLogic.GetCarPriceResult(db, customerCarPrice); err != nil {
		// 估价失败退款
		if err := pay.PayLogic.Refund(db, payModel.Id); err != nil {
			return err
		}
	}
	return nil
}

// Fail @Title 付款失败
func (e *estimatePayLogic) Fail(db *gorm.DB, orderId uint, payModel model.Pay) error {
	return nil
}

// RefundSuccess @Title 退款成功
func (e *estimatePayLogic) RefundSuccess(db *gorm.DB, orderId uint, payModel model.Pay) error {
	orderEstimatePay := model.OrderEstimatePay{Id: orderId}
	if db.First(&orderEstimatePay).Error != nil {
		return errors.New("估价订单错误")
	}
	if orderEstimatePay.Status == model.OrderEstimatePayStatusRefund {
		return nil
	}
	if db.Model(&orderEstimatePay).Where(&orderEstimatePay).UpdateColumns(map[string]interface{}{
		"status": model.OrderEstimatePayStatusRefund,
	}).RowsAffected != 1 {
		return errors.New("修改估价订单退款状态失败")
	}
	customerCarPrice := model.CustomerCarPrice{OrderId: orderEstimatePay.Id}
	if db.Model(&customerCarPrice).Where(&customerCarPrice).UpdateColumns(map[string]interface{}{
		"pay_status": model.CustomerCarPricePayStatusRefund,
	}).RowsAffected != 1 {
		return errors.New("修改估价记录退款状态失败")
	}
	return nil
}
