package order

import (
    "base/app/logic/pay"
    "base/app/model"
    "errors"
    "gorm.io/gorm"
    "time"
)

var PartnerLogic = &brokerLogic{}

type brokerLogic struct {
}

func init() {
    pay.MapNotify[model.PayOrderTypePartner] = PartnerLogic
}

// Success @Title 付款成功
func (b *brokerLogic) Success(db *gorm.DB, orderId uint, payModel model.Pay) error {
    orderPartner := model.OrderPartner{Id: orderId}
    if db.First(&orderPartner).Error != nil {
        return errors.New("订单错误")
    }
    if orderPartner.Status == model.OrderPartnerStatusPay {
        return nil
    }
    if db.Model(&orderPartner).Where(&orderPartner).UpdateColumns(map[string]interface{}{
        "status":   model.OrderPartnerStatusPay,
        "pay_type": payModel.PayType,
    }).RowsAffected != 1 {
        return nil
    }
    partner := model.BrokerPartner{BrokerId: orderPartner.BrokerId}
    db.Where(&partner).First(&partner)
    if db.Model(&model.Broker{}).Where("id = ?", orderPartner.BrokerId).UpdateColumn("level", model.BrokerLevelPartner).Error != nil {
        return errors.New("系统错误")
    }
    startTime := time.Now()
    if partner.Id > 0 {
        // 续费
        if partner.ExpireDate.Unix() < startTime.Unix() {
            // 过期续费
            expireDate := startTime.AddDate(1, 0, 0)
            if db.Model(&partner).Where(&partner).UpdateColumn("expire_date", expireDate).Error != nil {
                return errors.New("系统错误")
            }
            partnerHistory := model.BrokerPartnerHistory{
                BrokerId:   orderPartner.BrokerId,
                OrderId:    orderPartner.Id,
                ContractId: orderPartner.ContractId,
                StartDate:  startTime,
                EndDate:    expireDate,
            }
            if db.Create(&partnerHistory).Error != nil {
                return errors.New("系统错误")
            }
        } else {
            // 未过期续费
            expireDate := partner.ExpireDate.AddDate(1, 0, 0)
            if db.Model(&partner).Where(&partner).UpdateColumn("expire_date", expireDate).Error != nil {
                return errors.New("系统错误")
            }
            partnerHistory := model.BrokerPartnerHistory{
                BrokerId:   orderPartner.BrokerId,
                OrderId:    orderPartner.Id,
                ContractId: orderPartner.ContractId,
                StartDate:  partner.ExpireDate,
                EndDate:    expireDate,
            }
            if db.Create(&partnerHistory).Error != nil {
                return errors.New("系统错误")
            }
        }
    } else {
        // 第一次
        expireDate := startTime.AddDate(1, 0, 0)
        partner.ExpireDate = expireDate
        if db.Create(&partner).Error != nil {
            return errors.New("系统错误")
        }
        partnerHistory := model.BrokerPartnerHistory{
            BrokerId:   orderPartner.BrokerId,
            OrderId:    orderPartner.Id,
            ContractId: orderPartner.ContractId,
            StartDate:  startTime,
            EndDate:    expireDate,
        }
        if db.Create(&partnerHistory).Error != nil {
            return errors.New("系统错误")
        }
    }
    return nil
}

// Fail @Title 付款失败
func (b *brokerLogic) Fail(db *gorm.DB, orderId uint, payModel model.Pay) error {
    return nil
}

// RefundSuccess @Title 退款成功
func (b *brokerLogic) RefundSuccess(db *gorm.DB, orderId uint, payModel model.Pay) error {
    return nil
}
