package order

import (
	"base/app/logic/pay"
	"base/app/model"
	"errors"
	"gorm.io/gorm"
	"time"
)

var SaleDepositLogic = &saleDepositLogic{}

type saleDepositLogic struct {
}

func init() {
	pay.MapNotify[model.PayOrderTypeSaleDeposit] = SaleDepositLogic
}

// Success @Title 付款成功
func (s *saleDepositLogic) Success(db *gorm.DB, orderId uint, payModel model.Pay) error {
	orderSale := model.OrderSale{Id: orderId}
	if db.Preload("Car").First(&orderSale).Error != nil {
		return errors.New("订单错误")
	}
	// 付款成功
	if orderSale.Status == model.OrderSaleStatusDeposit {
		return nil
	}
	if orderSale.Status != model.OrderSaleStatusSign {
		return errors.New("订单状态错误")
	}
	if db.Model(&orderSale).Where("id = ?", orderSale.Id).UpdateColumns(map[string]interface{}{
		"status":         model.OrderSaleStatusDeposit,
		"deposit_pay_id": payModel.Id,
	}).RowsAffected != 1 {
		return nil
	}
	if db.Model(&model.Car{}).Where("id = ?", orderSale.CarId).UpdateColumns(map[string]interface{}{
		"status": model.CarStatusDeposit,
	}).RowsAffected != 1 {
		return nil
	}
	switch orderSale.Car.CustomerType {
	case model.CustomerTypeCustomer: // 普通客户
		if db.Model(&model.OrderConsignment{}).Where("id = ?", orderSale.Car.OrderId).UpdateColumns(map[string]interface{}{
			"status":      model.OrderConsignmentStatusSale,
			"sale_amount": orderSale.Car.Price,
			"sale_at":     time.Now(),
		}).RowsAffected != 1 {
			return nil
		}
	case model.CustomerTypeDealer: // 车商
		//if db.Model(&model.OrderDealerConsignment{}).Where("id = ?", orderSale.Car.OrderId).UpdateColumn("status", model.OrderConsignmentStatusSale).RowsAffected != 1 {
		//	return nil
		//}
	}
	return nil
}

// Fail @Title 付款失败
func (s *saleDepositLogic) Fail(db *gorm.DB, orderId uint, payModel model.Pay) error {
	return nil
}

// RefundSuccess @Title 退款成功
func (s *saleDepositLogic) RefundSuccess(db *gorm.DB, orderId uint, payModel model.Pay) error {
	return nil
}
