package model

import (
	"time"
)

const (
	BrokerBusinessStatusEnabled  = 1 // 启用
	BrokerBusinessStatusDisabled = 2 // 停用

	BrokerBusinessAuditingStatusSubmit = 1 // 提交审核
	BrokerBusinessAuditingStatusSuc    = 2 // 审核通过
	BrokerBusinessAuditingStatusFail   = 3 // 审核驳回
)

type BrokerBusiness struct {
	Id             uint                       `gorm:"primaryKey"`
	BusinessNo     string                     // 入驻商编号
	Name           string                     // 入驻商名称
	OwnerBrokerId  uint                       // 经纪人id
	OwnerBroker    *Broker                    `gorm:"foreignKey:OwnerBrokerId"`
	Address        string                     // 公司地址
	ContractNo     string                     // 合同编号
	Contract       string                     // 合同文件
	ExpireDate     time.Time                  // 到期日期
	Liaison        string                     // 联系人
	LiaisonPhone   string                     // 联系人手机号
	Telephone      string                     // 入驻商电话
	SaleId         uint                       // 所属业务
	Sale           Manage                     `gorm:"foreignKey:SaleId"`
	Status         uint                       // 状态
	Proof          string                     // 凭证
	AuditingStatus uint                       // 审核状态 1=提交审核 2=审核通过 3=审核驳回
	ApplyAt        time.Time                  // 申请时间
	ApplyUserId    uint                       // 录入人
	ApplyUser      Manage                     `gorm:"foreignKey:ApplyUserId"`
	Company        BrokerBusinessCompany      `gorm:"foreignKey:BusinessId"`
	Finance        BrokerBusinessFinance      `gorm:"foreignKey:BusinessId"`
	Auditing       []BrokerBusinessAuditing   `gorm:"foreignKey:BusinessId"`
	Staffs         []BrokerBusinessStoreStaff `gorm:"foreignKey:BusinessId"`
	CreatedAt      time.Time
	UpdatedAt      time.Time
}
