package model

import (
	"github.com/shopspring/decimal"
	"time"
)

const (
	CompanyQualityEnterprise = 1 // 企业
	CompanyQualityIndividual = 2 // 个体工商户
)

func (*BrokerBusinessCompany) GetQualityName(quality uint) (result string) {
	switch quality {
	case CompanyQualityEnterprise:
		return "企业"
	case CompanyQualityIndividual:
		return "个体工商户"
	default:
		return "未知"
	}
}

type BrokerBusinessCompany struct {
	Id                   uint            `gorm:"primaryKey"`
	BusinessId           uint            // 入驻商id
	Name                 string          // 公司名
	BusinessTermStart    time.Time       // 营业期限开始
	BusinessTermEnd      time.Time       // 营业期限截止
	RegisteredCapital    decimal.Decimal // 注册资本
	Quality              uint            // 性质 1=企业 2=个体工商户
	BusinessLicenseNo    string          // 营业执照号
	LegalPerson          string          // 法人
	LegalPersonCard      string          // 法人身份证号
	StorePhoto           string          // 门店照
	IdCardFront          string          // 身份证正面
	IdCardBack           string          // 身份证反面
	BusinessLicensePhoto string          // 营业执照
	CreatedAt            time.Time
	UpdatedAt            time.Time
}
