package model

import (
	"github.com/shopspring/decimal"
	"time"
)

const (
	BrokerBusinessStoreStatusEnabled  = 1 // 启用
	BrokerBusinessStoreStatusDisabled = 2 // 停用

	BrokerBusinessStoreAuditStatusSubmit = 1 // 提交审核
	BrokerBusinessStoreAuditStatusSuc    = 2 // 审核通过
	BrokerBusinessStoreAuditStatusFail   = 3 // 审核驳回
)

type BrokerBusinessStore struct {
	Id             uint                          `gorm:"primaryKey"`
	BusinessId     uint                          // 入驻商id
	Business       BrokerBusiness                `gorm:"foreignKey:BusinessId"`
	StoreNo        string                        // 入驻商编号
	Name           string                        // 门店名称
	Liaison        string                        // 联系方式
	Phone          string                        // 电话
	Address        string                        // 门店地址
	Commission     decimal.Decimal               // 销售提成
	Status         uint                          // 状态
	OwnerBrokerId  uint                          // 店长经纪人id
	OwnerBroker    *Broker                       `gorm:"foreignKey:OwnerBrokerId"`
	Staffs         []BrokerBusinessStoreStaff    `gorm:"foreignKey:StoreId"`
	Company        BrokerDealerCompany           `gorm:"foreignKey:DealerId"`
	AuditingStatus uint                          // 审核状态 1=提交审核 2=审核通过 3=审核驳回
	Auditing       []BrokerBusinessStoreAuditing `gorm:"foreignKey:StoreId"`
	CreatedAt      time.Time
	UpdatedAt      time.Time
}

func (b *BrokerBusinessStore) GetStatusName(status uint) string {
	switch status {
	case BrokerBusinessStoreStatusEnabled:
		return "启用"
	case BrokerBusinessStoreStatusDisabled:
		return "停用"
	default:
		return "未知"
	}
}

func (b *BrokerBusinessStore) GetAuditStatusName(status uint) string {
	switch status {
	case BrokerBusinessStoreAuditStatusSubmit:
		return "提交审核"
	case BrokerBusinessStoreAuditStatusSuc:
		return "审核通过"
	case BrokerBusinessStoreAuditStatusFail:
		return "审核驳回"
	default:
		return "未知"
	}
}
