package model

import (
	"github.com/shopspring/decimal"
	"time"
)

type CarModel struct {
	Id                uint      `gorm:"primaryKey"`
	BrandId           uint      // 品牌id
	Brand             CarBrand  `gorm:"foreignKey:BrandId;references:BrandId"`
	SeriesId          uint      // 车系id
	Series            CarSeries `gorm:"foreignKey:SeriesId;references:SeriesId"`
	ModelId           uint
	Name              string // 车型名称
	SeriesGroupId     uint
	MakerId           uint            // 生产商 id
	Year              uint            // 年份
	Price             decimal.Decimal // 指导价
	Liter             decimal.Decimal // 排量
	DischargeStandard string          // 排放标准
	FuelTypeId        uint            // 燃料类型
	FuelTypeName      string          // 燃料类型名称
	EnginePower       uint            // 马力
	EnginePowerKw     uint            // 马力转换功率
	IsGreen           uint            // 是否新能源车 0=否 1=是
	ModelCode         string          // 汽车公告型号
	DriveName         string          // 驱动类型
	DriveType         string          // 驱动类型
	ModelStatus       string          // 车型状态 在售/停售等
	GearType          string          // 变速箱类型 手动/自动
	MarketDate        string          // 生产日期
	MinRegYear        string          // 最小注册年
	MaxRegYear        string          // 最大注册年
	StopMakeYear      string          // 车型停产年份
	Intake            string          // 进气形式
	SeatNumber        string          // 座位数
	BodyType          string          // 车身类型
	DoorNumber        uint            // 门数
	CarStruct         string          // 车辆结构
	IsParallel        uint            // 是否平行进口车 0=否 1=是
	PriceAllowance    string          // 新能源车补贴
	CreatedAt         time.Time
	UpdatedAt         time.Time
}
