package model

import (
	"github.com/shopspring/decimal"
	"time"
)

const (
	CarPricePriceTypeCustomer = 1 // 客户报价
	CarPricePriceTypeBroker   = 2 // 经纪人报价
	CarPricePriceTypePlatform = 3 // 平台报价
)

type CarPrice struct {
	Id                   uint `gorm:"primaryKey"`
	ModelId              uint
	RegDate              time.Time       // 上牌时间
	LicensePlate         string          // 车牌
	CityId               uint            // 车300城市ID
	City                 City            `gorm:"foreignKey:CityId;references:CityId"`
	Mileage              decimal.Decimal // 行驶里程数
	PriceType            uint            // 报价类型 1=客户报价 2=经纪人报价 3=平台报价
	PriceUserId          uint            // 报价用户id
	ExcellentMaxPrice    decimal.Decimal // 优秀最高价
	ExcellentNormalPrice decimal.Decimal // 优秀一般价
	ExcellentMinPrice    decimal.Decimal // 优秀最低价
	GoodMaxPrice         decimal.Decimal // 良好最高价
	GoodNormalPrice      decimal.Decimal // 良好一般价
	GoodMinPrice         decimal.Decimal // 良好最低价
	NormalMaxPrice       decimal.Decimal // 一般最高价
	NormalNormalPrice    decimal.Decimal // 一般普通价
	NormalMinPrice       decimal.Decimal // 一般最低价
	CreatedAt            time.Time
	UpdatedAt            time.Time
}
