package model

import (
	"database/sql"
	"time"
)

const (
	DealerAuditingTypePublish     = 1  // 申请发布
	DealerAuditingTypeUpper       = 2  // 申请上架
	DealerAuditingTypeDown        = 3  // 申请下架
	DealerAuditingTypeEdit        = 4  // 申请编辑车辆
	DealerAuditingTypeConsignment = 11 // 寄售
	DealerAuditingTypePurchase    = 12 // 收购
	DealerAuditingTypeSale        = 13 // 出售
)

func (*DealerAuditing) GetTypeName(tp uint) (result string) {
	switch tp {
	case DealerAuditingTypePublish:
		return "申请发布"
	case DealerAuditingTypeUpper:
		return "申请上架"
	case DealerAuditingTypeDown:
		return "申请下架"
	case DealerAuditingTypeEdit:
		return "申请编辑车辆"
	case DealerAuditingTypeConsignment:
		return "寄售"
	case DealerAuditingTypePurchase:
		return "收购"
	case DealerAuditingTypeSale:
		return "出售"
	default:
		return "未知"
	}
}

type DealerAuditing struct {
	Id            uint `gorm:"primaryKey"`
	Type          uint // 1=申请发布 2=申请上架 3=申请下架
	DealerId      uint
	Dealer        BrokerBusinessStore `gorm:"foreignKey:DealerId"`
	ApplyBrokerId uint
	ApplyBroker   Broker `gorm:"foreignKey:ApplyBrokerId"`
	Status        uint   // 1=未审核 2=审核通过 3=审核驳回
	LinkId        uint
	AuditAt       sql.NullTime // 审核时间
	Reason        string       // 驳回原因
	CreatedAt     time.Time
	UpdatedAt     time.Time
}
