package model

import (
	"database/sql"
	"github.com/shopspring/decimal"
	"time"
)

const (
	OrderCallCarStatusUnPay        = 1 // 待付款
	OrderCallCarStatusPay          = 2 // 付款成功
	OrderCallCarStatusFinal        = 3 // 交车完成
	OrderCallCarStatusRefundAudit  = 4 // 退款申请
	OrderCallCarStatusRefund       = 5 // 已退款
	OrderCallCarStatusRefundReject = 6 // 退款驳回
)

func (*OrderCallCar) GetStatusName(status uint) (result string) {
	switch status {
	case OrderCallCarStatusUnPay:
		return "待付款"
	case OrderCallCarStatusPay:
		return "付款成功"
	case OrderCallCarStatusFinal:
		return "交车完成"
	case OrderCallCarStatusRefundAudit:
		return "退款申请"
	case OrderCallCarStatusRefund:
		return "已退款"
	case OrderCallCarStatusRefundReject:
		return "退款驳回"
	default:
		return "未知"
	}
}

type OrderCallCar struct {
	Id          uint               `gorm:"primaryKey"`
	OrderSn     string             // 订单编号
	CarId       uint               // 车辆id
	Car         Car                `gorm:"foreignKey:CarId"`
	CustomerId  uint               // 客户id
	Customer    Customer           `gorm:"foreignKey:CustomerId"`
	BrokerId    uint               // 经纪人id
	Broker      Broker             `gorm:"foreignKey:BrokerId"`
	CarBrokerId uint               // 车辆经纪人id
	CarBroker   Broker             `gorm:"foreignKey:CarBrokerId"`
	Phone       string             // 手机号
	ReserveAt   time.Time          // 预定时间
	Address     string             // 预定地址
	Remark      string             // 备注
	Amount      decimal.Decimal    // 叫车费用
	PayId       uint               // 付款id
	Status      uint               // 订单状态 1=待付款 2=付款成功 3=交车完成 4=退款
	RefundId    uint               // 退款id
	Refund      OrderCallCarRefund `gorm:"foreignKey:RefundId"`
	FinalAt     sql.NullTime       // 交车时间
	CreatedAt   time.Time
	UpdatedAt   time.Time
}
