package model

import (
	"database/sql"
	"github.com/shopspring/decimal"
	"time"
)

const (
	OrderDealerConsignmentCompulsoryInsuranceFalse = 0 // 无交强险
	OrderDealerConsignmentCompulsoryInsuranceTrue  = 1 // 有交强险

	OrderDealerConsignmentCommercialInsuranceFalse = 0 // 无商业险
	OrderDealerConsignmentCommercialInsuranceTrue  = 1 // 有商业险

	OrderDealerConsignmentStatusCancel     = 0 // 订单取消
	OrderDealerConsignmentStatusUnTheUpper = 1 // 待上架
	OrderDealerConsignmentStatusTheUpper   = 2 // 已上架
)

type OrderDealerConsignment struct {
	Id                       uint                        `gorm:"primaryKey"`
	DealerId                 uint                        // 车商id
	BrokerId                 uint                        // 经纪人id
	OrderSn                  string                      // 订单编号
	ModelId                  uint                        // 车型id
	Model                    CarModel                    `gorm:"foreignKey:ModelId;references:ModelId"`
	PriceId                  uint                        // 车型id
	CarPrice                 BrokerCarPrice              `gorm:"foreignKey:Id;references:PriceId"`
	Status                   uint                        // 订单状态
	Price                    decimal.Decimal             // 展示金额
	KeyCount                 uint                        // 钥匙数量
	CompulsoryInsurance      uint                        // 交强险
	CompulsoryInsuranceDate  sql.NullTime                // 交强险到期日期
	CommercialInsurance      uint                        // 商业险
	CommercialInsuranceDate  sql.NullTime                // 商业险到期日期
	CommercialInsurancePrice decimal.Decimal             // 商业险金额
	AuditId                  uint                        // 审核id
	Audit                    OrderDealerConsignmentAudit `gorm:"foreignKey:AuditId"`
	DealerCar                OrderDealerConsignmentCar   `gorm:"foreignKey:OrderId"`
	CreatedAt                time.Time
	UpdatedAt                time.Time
}
