package model

import (
	"github.com/shopspring/decimal"
	"time"
)

const (
	OrderDealerConsignmentCarTheUpperFalse = 1 // 未上架
	OrderDealerConsignmentCarTheUpperTrue  = 2 // 已上架
)

type OrderDealerConsignmentCar struct {
	Id                    uint                             `gorm:"primaryKey"`
	DealerId              uint                             // 车商id
	BrokerId              uint                             // 经纪人id
	OrderId               uint                             // 订单id
	Order                 *OrderDealerConsignment          `gorm:"foreignKey:OrderId"`
	ModelId               uint                             // 车型id
	Model                 CarModel                         `gorm:"foreignKey:ModelId;references:ModelId"`
	CarId                 uint                             // 车辆id
	Car                   Car                              `gorm:"foreignKey:CarId"`
	Type                  string                           // 车辆类型
	InteriorColor         string                           // 内饰颜色
	Displacement          decimal.Decimal                  // 排量
	Gearbox               string                           // 变速箱
	EmissionStandard      string                           // 排放标准
	UseCharacter          string                           // 使用性质
	LocationProvinceId    uint                             // 车辆所在地-省
	LocationCityId        uint                             // 车辆所在地-市
	LocationCity          Area                             `gorm:"foreignKey:LocationCityId"`
	AttributionProvinceId uint                             // 车辆归属地-省
	AttributionCityId     uint                             // 车辆归属地-市
	ConditionIn           string                           // 车况（对内）
	ConditionOut          string                           // 车况（对外）
	MainPhoto             string                           // 车辆主图
	Photos                []OrderDealerConsignmentCarPhoto `gorm:"foreignKey:OrderId;References:OrderId"`
	TheUpper              uint                             // 上架 1=未上架 2=已上架
	CreatedAt             time.Time
	UpdatedAt             time.Time
}
