package model

import (
	"time"
)

const (
	OrderSaleCustomerChannelWxApp   = 1 // 小程序
	OrderSaleCustomerChannelOffline = 2 // 线下

	OrderSaleStatusCancel  = 60 // 订单取消
	OrderSaleStatusUnSign  = 1  // 待签订
	OrderSaleStatusSign    = 2  // 已签订
	OrderSaleStatusDeposit = 3  // 已支付定金

	OrderSaleStatusTestReport       = 10 // 等待申请检测
	OrderSaleStatusUploadTestReport = 11 // 已上传检测报告

	OrderSaleStatusDownPaymentAudit = 20 // 已提交首付审核
	OrderSaleStatusDownPaymentAdopt = 21 // 首付审核通过

	OrderSaleStatusTransfer      = 30 // 等待过户
	OrderSaleStatusTransferFinal = 31 // 过户完成

	OrderSaleStatusBalancePaymentAudit = 40 // 尾款审核
	OrderSaleStatusBalancePaymentAdopt = 41 // 尾款审核通过

	OrderSaleStatusFinal = 50 // 交车/完结
)

func (*OrderSale) GetCustomerChannelName(channel uint) (result string) {
	switch channel {
	case OrderSaleCustomerChannelWxApp:
		return "小程序"
	case OrderSaleCustomerChannelOffline:
		return "线下"
	default:
		return "未知"
	}
}

func (*OrderSale) GetStatusName(status uint) (result string) {
	switch status {
	case OrderSaleStatusCancel:
		return "订单取消"
	case OrderConsignmentStatusUnSign:
		return "待签订"
	case OrderSaleStatusSign:
		return "已签订"
	case OrderSaleStatusDeposit:
		return "已支付定金"
	case OrderSaleStatusTestReport:
		return "申请检测"
	case OrderSaleStatusUploadTestReport:
		return "已上传报告"
	case OrderSaleStatusDownPaymentAudit:
		return "首付审核"
	case OrderSaleStatusDownPaymentAdopt:
		return "首付审核通过"
	case OrderSaleStatusTransfer:
		return "过户中"
	case OrderSaleStatusTransferFinal:
		return "过户完成"
	case OrderSaleStatusBalancePaymentAudit:
		return "尾款审核中"
	case OrderSaleStatusBalancePaymentAdopt:
		return "尾款审核通过"
	case OrderSaleStatusFinal:
		return "交车/完结"
	default:
		return "未知状态"
	}
}

type OrderSale struct {
	Id                    uint              `gorm:"primaryKey"`
	CustomerChannel       uint              // 客户渠道 1=小程序 2=线下
	CustomerId            uint              // 客户id
	Customer              Customer          `gorm:"foreignKey:CustomerId"`
	BrokerId              uint              // 经纪人id
	Broker                Broker            `gorm:"foreignKey:BrokerId"`
	OrderSn               string            // 订单编号
	CarId                 uint              // 车辆id
	Car                   Car               `gorm:"foreignKey:CarId"`
	ContractId            uint              // 合同id
	Contract              ContractSale      `gorm:"foreignKey:ContractId"`
	Status                uint              // 订单状态 0=订单取消 1=待签订 2=待支付定金 检测 首付 过户 尾款 交车
	Report                OrderSaleReport   `gorm:"foreignKey:OrderId"`
	DepositPayId          uint              // 定金支付id
	DepositPay            Pay               `gorm:"foreignKey:DepositPayId"`
	DownPaymentAuditId    uint              // 首付审核id
	DownPaymentAudit      OrderSaleAudit    `gorm:"foreignKey:DownPaymentAuditId"`
	BalancePaymentAuditId uint              // 首付审核id
	BalancePaymentAudit   OrderSaleAudit    `gorm:"foreignKey:BalancePaymentAuditId"`
	Transfer              OrderSaleTransfer `gorm:"foreignKey:OrderId"`
	//SaleAt              sql.NullTime              // 售出时间
	//CancelAt            sql.NullTime              // 取消时间
	CreatedAt time.Time
	UpdatedAt time.Time
}
