package model

import (
	"database/sql"
	"github.com/shopspring/decimal"
	"time"
)

const (
	PayTypeAli   = 1 // 支付宝
	PayTypeWx    = 2 // 微信
	PayTypeWxapp = 3 // 小程序
	PayTypeH5Ali = 4 // H5支付宝
	PayTypeH5Wx  = 5 // H5微信

	PayStatusTimeout = 0 // 超时未支付
	PayStatusUnPay   = 1 // 未付款
	PayStatusPay     = 2 // 已付款
	PayStatusRefund  = 3 // 已退款

	PayOrderTypeAssess      = 1 // 钱包次数充值订单
	PayOrderTypePartner     = 2 // 独立经纪人续费
	PayOrderTypeSaleDeposit = 3 // 买车定金
	PayOrderTypeCallCar     = 4 // 叫车费用
	PayOrderTypeEstimatePay = 5 // 付费估价
)

type Pay struct {
	Id         uint            `gorm:"primaryKey"`
	PaySn      string          // 付款编号
	OrderType  uint            // 订单类型
	OrderId    uint            // 订单id
	Amount     decimal.Decimal // 金额
	Status     uint            // 付款状态 0=超时未支付 1=未付款 2=已付款 3=已退款
	PayTime    sql.NullTime    // 付款时间
	RefundTime sql.NullTime    // 退款时间
	PayType    uint            // 付款类型 1=支付宝 2=微信 3=微信小程序
	PayNo      string          // 第三方支付单号
	CreatedAt  time.Time
	UpdatedAt  time.Time
}

// GetPayTypeName @Title 获取支付类型名称
func (p *Pay) GetPayTypeName() string {
	switch p.PayType {
	case PayTypeAli: // 支付宝
		return "支付宝支付"
	case PayTypeWx: // 微信
		return "微信支付"
	case PayTypeWxapp: // 小程序
		return "微信支付"
	}
	return ""
}
