package model

import (
	"database/sql"
	"time"
)

const (
	EssFlowStatusInit      = 1 // 合同创建
	EssFlowStatusALL       = 2 // 合同签署完成
	EssFlowStatusREJECT    = 3 // 合同拒签
	EssFlowStatusCANCEL    = 4 // 合同撤回
	EssFlowStatusDEADLINE  = 5 // 合同过期
	EssFlowStatusEXCEPTION = 6 // 合同异常

	EssFlowConsignment = 1 // 寄售合同
	EssFLowPurchase    = 2 // 收购合同
	EssFlowSale        = 3 // 卖车合同
)

type ThirdTencentEssFlow struct {
	Id         uint         `gorm:"primaryKey"`
	FlowId     string       // 电子签合同id
	ContractId uint         // 合同id
	ContractSn string       // 合同编码
	Name       string       // 合同名称
	Status     uint         // 合同状态
	Url        string       // 文件地址
	CreateOn   sql.NullTime // 发起时间
	Deadline   sql.NullTime // 截止时间
	Reason     string
	RejectAt   sql.NullTime
	CancelAt   sql.NullTime
	CreatedAt  time.Time
	UpdatedAt  time.Time
}

const (
	EssApproverTypePerson       = "PERSON"
	EssApproverTypeORGANIZATION = "ORGANIZATION"
)

var ConsignmentParams = map[string]string{
	"FlowName":     "云云问车车辆寄卖服务协议",
	"TemplateId":   "yDRT5UU3a2oiuUxwgruyx6ohaATD4Fvx",
	"RecipientId":  "yDRT5UU3a2uaqUuozLjQNSIp6V6LzyBO", // 企业静默签模板中签署人Id
	"RecipientId1": "yDRT5UU3a2ua8UuozLjQSlrOrbp5ZO5R", // 甲方模板中签署人Id

	"P1A1B1": "ComponentId_16", // 甲方姓名
	"P1A1B2": "ComponentId_17", // 甲方联系方式
	"P1A1B3": "ComponentId_18", // 甲方身份证号码

	"P1A2B1": "ComponentId_20", // 车主姓名
	"P1A2B2": "ComponentId_19", // 车牌号码
	"P1A2B3": "ComponentId_21", // 品牌车型
	"P1A2B4": "ComponentId_22", // 车架号
	"P1A2B5": "ComponentId_23", // 发动机号
	"P1A2B6": "ComponentId_24", // 初次上牌日期
	"P1A2B7": "ComponentId_25", // 表显里程

	// 车辆使用性质选项卡
	"P1A3B1": "ComponentId_26",
	"P1A3B2": "ComponentId_27",
	"P1A3B3": "ComponentId_28",
	"P1A3B4": "ComponentId_29",
	"P1A3B5": "ComponentId_30",

	"P1A4B1": "ComponentId_352", // 代销价大写
	"P1A4B2": "ComponentId_10",  // 代销价小写

	"P2A1B1": "ComponentId_33", // 甲方账户名称
	"P2A1B2": "ComponentId_34", // 甲方账户
	"P2A1B3": "ComponentId_35", // 开户行

	"P2A2B1": "ComponentId_36", // 代销期限起
	"P2A2B2": "ComponentId_37", // 代销期限止

	"P2A3B1": "ComponentId_11", // 是否包含行驶证
	"P2A3B2": "ComponentId_12", // 是否包含车辆登记证书
	"P2A3B3": "ComponentId_13", // 是否包含保险
	"P2A3B4": "ComponentId_53", // 车钥匙数量

	"P3A1B1": "ComponentId_4", // 备注
}

var PurchaseCompanyParams = map[string]string{
	"FlowName":     "云云问车二手车收购合同（甲方为公司）",
	"TemplateId":   "yDRT5UU3asrmlUuwiIx7ygmrqVxPZ0oe",
	"RecipientId1": "yDRT5UU3as9quUuozLjQSvegkdkjba7v", // 甲方模板中签署人Id
	"RecipientId2": "yDRT5UU3as9qaUuozLjQvGVFdaRekgJE", // 乙方模板中签署人Id

	"P1A1B1": "ComponentId_80", // 甲方名称
	"P1A1B2": "ComponentId_81", // 甲方法人姓名
	"P1A1B3": "ComponentId_86", // 甲方社会信用代码/身份证号码
	"P1A1B4": "ComponentId_84", // 甲方联系方式
	"P1A1B5": "ComponentId_88", // 甲方地址
	"P1A2B1": "ComponentId_82", // 乙方姓名
	"P1A2B2": "ComponentId_87", // 乙方身份证号码
	"P1A2B3": "ComponentId_89", // 乙方地址
	"P1A2B4": "ComponentId_85", // 乙方联系方式

	"P2A1B1": "ComponentId_90", // 厂牌型号
	"P2A1B2": "ComponentId_91", // 车架号
	"P2A1B3": "ComponentId_92", // 初次上牌日期
	"P2A1B4": "ComponentId_95", // 车辆类型
	"P2A1B5": "ComponentId_94", // 发动机号
	"P2A1B6": "ComponentId_93", // 强制保险至
	"P2A1B7": "ComponentId_96", // 车牌号码
	"P2A1B8": "ComponentId_97", // 表显里程
	"P2A1B9": "ComponentId_98", // 环保等级

	"P3A1B1": "ComponentId_122", // 成交价人民币大写
	"P3A1B2": "ComponentId_123", // 成交价
	//"P3A1B3": "ComponentId_102", // 定金时限
	"P3A1B4": "ComponentId_124", // 定金大写
	"P3A1B5": "ComponentId_125", // 定金小写
	//"P3A1B6": "ComponentId_128", // 余款时限
	"P3A1B7": "ComponentId_126", // 余款大写
	"P3A1B8": "ComponentId_127", // 余款小写

	"P4A1B1": "ComponentId_103", // 甲方户名
	"P4A1B2": "ComponentId_111", // 甲方账户
	"P4A1B3": "ComponentId_109", // 甲方开户行
	"P4A2B1": "ComponentId_104", // 乙方户名
	"P4A2B2": "ComponentId_112", // 乙方账户
	"P4A2B3": "ComponentId_110", // 乙方开户行

	"P5A1B1": "ComponentId_4", // 备注

	"file": "ComponentId_5", // 附件
}

var PurchasePersonParams = map[string]string{
	"FlowName":     "云云问车二手车收购合同（甲方为个人）",
	"TemplateId":   "yDRT5UU3a1gplUx9VnCLSZRaxYB0CCcu",
	"RecipientId1": "yDRT5UU3ajg6aUxGsx12SlyLaTaM5a9R", // 甲方模板中签署人Id
	"RecipientId2": "yDRT5UU3ajg6wUxGsx1214AEoG4pmALE", // 乙方模板中签署人Id

	"P1A1B1": "ComponentId_135", // 甲方名称
	"P1A1B3": "ComponentId_137", // 甲方社会信用代码/身份证号码
	"P1A1B4": "ComponentId_136", // 甲方联系方式
	"P1A2B1": "ComponentId_138", // 乙方姓名
	"P1A2B2": "ComponentId_141", // 乙方身份证号码
	"P1A2B3": "ComponentId_142", // 乙方地址
	"P1A2B4": "ComponentId_140", // 乙方联系方式

	"P2A1B1": "ComponentId_143", // 厂牌型号
	"P2A1B2": "ComponentId_144", // 车架号
	"P2A1B3": "ComponentId_145", // 初次上牌日期
	"P2A1B4": "ComponentId_149", // 车辆类型
	"P2A1B5": "ComponentId_148", // 发动机号
	"P2A1B6": "ComponentId_146", // 强制保险至
	"P2A1B7": "ComponentId_150", // 车牌号码
	"P2A1B8": "ComponentId_151", // 表显里程
	"P2A1B9": "ComponentId_147", // 环保等级

	"P3A1B1": "ComponentId_152", // 成交价人民币大写
	"P3A1B2": "ComponentId_155", // 成交价
	//"P3A1B3": "ComponentId_158", // 定金时限
	"P3A1B4": "ComponentId_17", // 定金大写
	"P3A1B5": "ComponentId_18", // 定金小写
	//"P3A1B6": "ComponentId_159", // 余款时限
	"P3A1B7": "ComponentId_154", // 余款大写
	"P3A1B8": "ComponentId_157", // 余款小写

	"P4A1B1": "ComponentId_160", // 甲方户名
	"P4A1B2": "ComponentId_162", // 甲方账户
	"P4A1B3": "ComponentId_164", // 甲方开户行
	"P4A2B1": "ComponentId_161", // 乙方户名
	"P4A2B2": "ComponentId_163", // 乙方账户
	"P4A2B3": "ComponentId_165", // 乙方开户行

	"P5A1B1": "ComponentId_7", // 备注

	"file": "ComponentId_6", // 附件
}

// 卖方个人、无第三方
var SaleSellerPersonThirdPartNoneParams = map[string]string{
	"FlowName":     "云云问车二手车买卖合同",
	"TemplateId":   "yDRT5UU3a3kdvUx9VnCL1HR9SY2LA7C1",
	"RecipientId1": "yDw97UUo6tw9rUETfbOTSYguPuXj2y4y", // 甲方模板中签署人Id
	"RecipientId2": "yDw97UUo6tw95UETfbOTyBqEmPQvcnf1", // 乙方模板中签署人Id

	"P1A1B1": "ComponentId_209", // 甲方名称
	"P1A1B2": "ComponentId_215", // 甲方法人姓名
	"P1A1B3": "ComponentId_213", // 甲方社会信用代码/身份证号码
	"P1A1B4": "ComponentId_212", // 甲方联系方式
	"P1A1B5": "ComponentId_216", // 甲方地址
	"P1A2B1": "ComponentId_210", // 乙方姓名
	"P1A2B2": "ComponentId_214", // 乙方身份证号码
	"P1A2B3": "ComponentId_211", // 乙方联系方式

	"P2A1B1": "ComponentId_20", // 厂牌型号
	"P2A1B2": "ComponentId_22", // 车架号
	"P2A1B3": "ComponentId_23", // 初次上牌日期
	"P2A1B4": "ComponentId_21", // 车辆类型
	"P2A1B5": "ComponentId_26", // 发动机号
	"P2A1B6": "ComponentId_24", // 强制保险至
	"P2A1B7": "ComponentId_29", // 车牌号码
	"P2A1B8": "ComponentId_30", // 表显里程
	"P2A1B9": "ComponentId_31", // 车辆使用性质

	"P3A1B1": "ComponentId_32",  // 成交价人民币大写
	"P3A1B2": "ComponentId_33",  // 成交价
	"P3A1B3": "ComponentId_34",  // 定金人民币大写
	"P3A1B4": "ComponentId_35",  // 定金
	"P3A1B5": "ComponentId_36",  // 余额支付方式
	"P3A1B6": "ComponentId_37",  // 交付时间
	"P3A1B7": "ComponentId_38",  // 交付地点
	"P3A1B8": "ComponentId_232", // 首付金额大写
	"P3A1B9": "ComponentId_233", // 首付金额

	"P3A2B1": "ComponentId_236", // 过户税费大写
	"P3A2B2": "ComponentId_234", // 过户税费
	"P3A2B3": "ComponentId_238", // 过户税费承担方名称
	"P3A2B4": "ComponentId_237", // 代办手续费大写
	"P3A2B5": "ComponentId_235", // 代办手续费
	"P3A2B6": "ComponentId_239", // 代办手续费承担方名称

	"P3A3B7": "ComponentId_240", // 服务费大写
	"P3A3B8": "ComponentId_241", // 服务费小写

	"P3A4B1": "ComponentId_8", // 备注

	"P4A1B1": "ComponentId_354", // 甲方户名
	"P4A1B2": "ComponentId_355", // 甲方开户行
	"P4A1B3": "ComponentId_254", // 甲方账户
	"P4A2B1": "ComponentId_356", // 乙方户名
	"P4A2B2": "ComponentId_357", // 乙方开户行
	"P4A2B3": "ComponentId_108", // 乙方账户

	"carPhotos":      "ComponentId_4", // 车辆照片
	"interiorPhotos": "ComponentId_6", // 内饰照片
	"defectPhotos":   "ComponentId_7", // 缺陷照片
	"dataPhotos":     "ComponentId_9", // 资料照片
}

// 卖方车商、无第三方
var SaleSellerDealerThirdPartNoneParams = map[string]string{
	"FlowName":     "云云问车二手车买卖合同",
	"TemplateId":   "yDwcuUU36ejtxUyCnpi9SJrFVW1PDShC",
	"RecipientId1": "yDw97UUo6y6ntUuVz2QT1T0cvetEKptu", // 甲方模板中签署人Id
	"RecipientId2": "yDw97UUo6y6nwUuVz2QTExdG0CEctPoR", // 乙方模板中签署人Id

	"P1A1B1": "ComponentId_209", // 甲方名称
	"P1A1B2": "ComponentId_215", // 甲方法人姓名
	"P1A1B3": "ComponentId_213", // 甲方社会信用代码/身份证号码
	"P1A1B4": "ComponentId_212", // 甲方联系方式
	"P1A1B5": "ComponentId_216", // 甲方地址
	"P1A2B1": "ComponentId_210", // 乙方姓名
	"P1A2B2": "ComponentId_214", // 乙方身份证号码
	"P1A2B3": "ComponentId_211", // 乙方联系方式

	"P2A1B1": "ComponentId_41",  // 厂牌型号
	"P2A1B2": "ComponentId_42",  // 车架号
	"P2A1B3": "ComponentId_43",  // 初次上牌日期
	"P2A1B4": "ComponentId_44",  // 车辆类型
	"P2A1B5": "ComponentId_45",  // 发动机号
	"P2A1B6": "ComponentId_46",  // 强制保险至
	"P2A1B7": "ComponentId_225", // 车牌号码
	"P2A1B8": "ComponentId_223", // 表显里程
	"P2A1B9": "ComponentId_221", // 环保等级

	"P3A1B1": "ComponentId_48",  // 成交价人民币大写
	"P3A1B2": "ComponentId_52",  // 成交价
	"P3A1B3": "ComponentId_49",  // 定金人民币大写
	"P3A1B4": "ComponentId_53",  // 定金
	"P3A1B5": "ComponentId_56",  // 余额支付方式
	"P3A1B6": "ComponentId_50",  // 交付时间
	"P3A1B7": "ComponentId_51",  // 交付地点
	"P3A1B8": "ComponentId_232", // 首付金额大写
	"P3A1B9": "ComponentId_233", // 首付金额

	"P3A2B1": "ComponentId_236", // 过户税费大写
	"P3A2B2": "ComponentId_234", // 过户税费
	"P3A2B3": "ComponentId_238", // 过户税费承担方名称
	"P3A2B4": "ComponentId_237", // 代办手续费大写
	"P3A2B5": "ComponentId_235", // 代办手续费
	"P3A2B6": "ComponentId_239", // 代办手续费承担方名称

	"P3A3B7": "ComponentId_240", // 服务费大写
	"P3A3B8": "ComponentId_241", // 服务费小写

	"P3A4B1": "ComponentId_6", // 备注

	"P4A1B1": "ComponentId_354", // 甲方户名
	"P4A1B2": "ComponentId_355", // 甲方开户行
	"P4A1B3": "ComponentId_254", // 甲方账户
	"P4A2B1": "ComponentId_356", // 乙方户名
	"P4A2B2": "ComponentId_357", // 乙方开户行
	"P4A2B3": "ComponentId_47",  // 乙方账户

	"carPhotos":      "ComponentId_21", // 车辆照片
	"interiorPhotos": "ComponentId_22", // 内饰照片
	"defectPhotos":   "ComponentId_23", // 缺陷照片
	"dataPhotos":     "ComponentId_24", // 资料照片
}

// 卖方个人、第三方平台
var SaleSellerPersonThirdPartPlatFormParams = map[string]string{
	"FlowName":     "云云问车二手车买卖中介合同",
	"TemplateId":   "yDRT5UU3ao3csUuozLjQ8aoptxHYAltE",
	"RecipientId1": "yDw97UUo6a22pUy40ipVRIToCoktYi0T", // 甲方模板中签署人Id
	"RecipientId2": "yDw97UUo6a225Uy40ipVEzKmFSoksGMR", // 乙方模板中签署人Id
	"RecipientId3": "yDw97UUo6a22rUy40ipVRi17ePMBVRR1", // 丙方(企业静默签)模板中签署人Id

	"P1A1B1": "ComponentId_259", // 甲方名称
	"P1A1B2": "ComponentId_262", // 甲方法人姓名
	"P1A1B3": "ComponentId_266", // 甲方社会信用代码/身份证号码
	"P1A1B4": "ComponentId_263", // 甲方联系方式
	"P1A1B5": "ComponentId_308", // 甲方地址
	"P1A2B1": "ComponentId_260", // 乙方姓名
	"P1A2B2": "ComponentId_268", // 乙方身份证号码
	"P1A2B3": "ComponentId_264", // 乙方联系方式
	"P1A3B1": "ComponentId_261", // 丙方姓名
	"P1A3B2": "ComponentId_267", // 丙方统一社会信用代码
	"P1A3B3": "ComponentId_265", // 丙方联系方式
	"P1A3B4": "ComponentId_307", // 丙方地址

	"P2A1B1": "ComponentId_92",  // 厂牌型号
	"P2A1B2": "ComponentId_93",  // 车架号
	"P2A1B3": "ComponentId_94",  // 初次上牌日期
	"P2A1B4": "ComponentId_95",  // 车辆类型
	"P2A1B5": "ComponentId_96",  // 发动机号
	"P2A1B6": "ComponentId_97",  // 强制保险至
	"P2A1B7": "ComponentId_278", // 车牌号码
	"P2A1B8": "ComponentId_276", // 表显里程
	"P2A1B9": "ComponentId_274", // 环保等级

	"P3A1B1": "ComponentId_279", // 成交价人民币大写
	"P3A1B2": "ComponentId_282", // 成交价
	"P3A1B3": "ComponentId_115", // 定金人民币大写
	"P3A1B4": "ComponentId_283", // 定金
	"P3A1B5": "ComponentId_284", // 余额支付方式
	"P3A1B6": "ComponentId_286", // 交付时间
	"P3A1B7": "ComponentId_285", // 交付地点
	"P3A1B8": "ComponentId_288", // 首付金额大写
	"P3A1B9": "ComponentId_287", // 首付金额

	"P3A2B1": "ComponentId_280", // 过户税费大写
	"P3A2B2": "ComponentId_289", // 过户税费
	"P3A2B3": "ComponentId_293", // 过户税费承担方名称
	"P3A2B4": "ComponentId_281", // 代办手续费大写
	"P3A2B5": "ComponentId_290", // 代办手续费
	"P3A2B6": "ComponentId_294", // 代办手续费承担方名称

	"P3A3B1": "ComponentId_297", // 成交服务费比率(甲->丙)
	"P3A3B2": "ComponentId_291", // 成交服务费(甲->丙)
	"P3A3B3": "ComponentId_296", // 成交服务费(乙->丙)
	"P3A3B4": "ComponentId_292", // 成交服务费(乙->丙)

	"P4A1B1": "ComponentId_312", // 甲方户名
	"P4A1B2": "ComponentId_313", // 甲方开户行
	"P4A1B3": "ComponentId_314", // 甲方账户
	"P4A2B1": "ComponentId_315", // 乙方户名
	"P4A2B2": "ComponentId_316", // 乙方开户行
	"P4A2B3": "ComponentId_317", // 乙方账户
	"P4A3B1": "ComponentId_318", // 丙方户名
	"P4A3B2": "ComponentId_319", // 丙方开户行
	"P4A3B3": "ComponentId_320", // 丙方账户

	"carPhotos":      "ComponentId_16", // 车辆照片
	"interiorPhotos": "ComponentId_17", // 内饰照片
	"defectPhotos":   "ComponentId_18", // 缺陷照片
	"dataPhotos":     "ComponentId_19", // 资料照片

}

// 卖方车商、第三方平台
var SaleSellerDealerThirdPartPlatFormParams = map[string]string{
	"FlowName":     "云云问车二手车买卖中介合同",
	"TemplateId":   "yDwcuUU3cra3rUy1xqjOy7SMmJFr2HR8",
	"RecipientId1": "yDw97UUo6agbzU1HmDZCbuLuLFgzZVSZ", // 甲方模板中签署人Id
	"RecipientId2": "yDw97UUo6agbiU1HmDZx8sFpnK3qthw1", // 乙方模板中签署人Id
	"RecipientId3": "yDw97UUo6agbcU1HmDZufjEPFucDjkws", // 丙方(企业静默签)模板中签署人Id

	"P1A1B1": "ComponentId_259", // 甲方名称
	"P1A1B2": "ComponentId_262", // 甲方法人姓名
	"P1A1B3": "ComponentId_266", // 甲方社会信用代码/身份证号码
	"P1A1B4": "ComponentId_263", // 甲方联系方式
	"P1A1B5": "ComponentId_308", // 甲方地址
	"P1A2B1": "ComponentId_260", // 乙方姓名
	"P1A2B2": "ComponentId_268", // 乙方身份证号码
	"P1A2B3": "ComponentId_264", // 乙方联系方式
	"P1A3B1": "ComponentId_261", // 丙方姓名
	"P1A3B2": "ComponentId_267", // 丙方统一社会信用代码
	"P1A3B3": "ComponentId_265", // 丙方联系方式
	"P1A3B4": "ComponentId_307", // 丙方地址

	"P2A1B1": "ComponentId_117", // 厂牌型号
	"P2A1B2": "ComponentId_118", // 车架号
	"P2A1B3": "ComponentId_119", // 初次上牌日期
	"P2A1B4": "ComponentId_120", // 车辆类型
	"P2A1B5": "ComponentId_121", // 发动机号
	"P2A1B6": "ComponentId_122", // 强制保险至
	"P2A1B7": "ComponentId_278", // 车牌号码
	"P2A1B8": "ComponentId_276", // 表显里程
	"P2A1B9": "ComponentId_274", // 环保等级

	"P3A1B1": "ComponentId_279", // 成交价人民币大写
	"P3A1B2": "ComponentId_282", // 成交价
	"P3A1B3": "ComponentId_132", // 定金人民币大写
	"P3A1B4": "ComponentId_283", // 定金
	"P3A1B5": "ComponentId_284", // 余额支付方式
	"P3A1B6": "ComponentId_286", // 交付时间
	"P3A1B7": "ComponentId_285", // 交付地点
	"P3A1B8": "ComponentId_288", // 首付金额大写
	"P3A1B9": "ComponentId_287", // 首付金额

	"P3A2B1": "ComponentId_280", // 过户税费大写
	"P3A2B2": "ComponentId_289", // 过户税费
	"P3A2B3": "ComponentId_293", // 过户税费承担方名称
	"P3A2B4": "ComponentId_281", // 代办手续费大写
	"P3A2B5": "ComponentId_290", // 代办手续费
	"P3A2B6": "ComponentId_294", // 代办手续费承担方名称

	"P3A3B1": "ComponentId_297", // 成交服务费比率(甲->丙)
	"P3A3B2": "ComponentId_291", // 成交服务费(甲->丙)
	"P3A3B3": "ComponentId_296", // 成交服务费(乙->丙)
	"P3A3B4": "ComponentId_292", // 成交服务费(乙->丙)

	"P4A1B1": "ComponentId_312", // 甲方户名
	"P4A1B2": "ComponentId_313", // 甲方开户行
	"P4A1B3": "ComponentId_314", // 甲方账户
	"P4A2B1": "ComponentId_315", // 乙方户名
	"P4A2B2": "ComponentId_316", // 乙方开户行
	"P4A2B3": "ComponentId_317", // 乙方账户
	"P4A3B1": "ComponentId_318", // 丙方户名
	"P4A3B2": "ComponentId_319", // 丙方开户行
	"P4A3B3": "ComponentId_320", // 丙方账户

	"carPhotos":      "ComponentId_31", // 车辆照片
	"interiorPhotos": "ComponentId_32", // 内饰照片
	"defectPhotos":   "ComponentId_33", // 缺陷照片
	"dataPhotos":     "ComponentId_34", // 资料照片
}

// 卖方个人、第三方车商
var SaleSellerPersonThirdPartDealerParams = map[string]string{
	"FlowName":     "云云问车二手车买卖车商中介合同",
	"TemplateId":   "yDRT5UU3akvoeUyudcuCMYzpCdmWgRBA",
	"RecipientId1": "yDw97UUo6y56vUy40ipVE7N4NOqxuj9x", // 甲方模板中签署人Id
	"RecipientId2": "yDw97UUo6y56bUy40ipV8u3wW2bQRsi8", // 乙方模板中签署人Id
	"RecipientId3": "yDw97UUo6y56yUy40ipVECqeMWhTi3EC", // 丙方模板中签署人Id

	"P1A1B1": "ComponentId_259", // 甲方名称
	"P1A1B2": "ComponentId_262", // 甲方法人姓名
	"P1A1B3": "ComponentId_266", // 甲方社会信用代码/身份证号码
	"P1A1B4": "ComponentId_263", // 甲方联系方式
	"P1A1B5": "ComponentId_308", // 甲方地址
	"P1A2B1": "ComponentId_260", // 乙方姓名
	"P1A2B2": "ComponentId_268", // 乙方身份证号码
	"P1A2B3": "ComponentId_264", // 乙方联系方式
	"P1A3B1": "ComponentId_261", // 丙方姓名
	"P1A3B2": "ComponentId_267", // 丙方统一社会信用代码
	"P1A3B3": "ComponentId_265", // 丙方联系方式
	"P1A3B4": "ComponentId_307", // 丙方地址

	"P2A1B1": "ComponentId_58",  // 厂牌型号
	"P2A1B2": "ComponentId_59",  // 车架号
	"P2A1B3": "ComponentId_60",  // 初次上牌日期
	"P2A1B4": "ComponentId_61",  // 车辆类型
	"P2A1B5": "ComponentId_62",  // 发动机号
	"P2A1B6": "ComponentId_63",  // 强制保险至
	"P2A1B7": "ComponentId_278", // 车牌号码
	"P2A1B8": "ComponentId_276", // 表显里程
	"P2A1B9": "ComponentId_274", // 环保等级

	"P3A1B1": "ComponentId_279", // 成交价人民币大写
	"P3A1B2": "ComponentId_282", // 成交价
	"P3A1B3": "ComponentId_111", // 定金人民币大写
	"P3A1B4": "ComponentId_283", // 定金
	"P3A1B5": "ComponentId_284", // 余额支付方式
	"P3A1B6": "ComponentId_286", // 交付时间
	"P3A1B7": "ComponentId_285", // 交付地点
	"P3A1B8": "ComponentId_288", // 首付金额大写
	"P3A1B9": "ComponentId_287", // 首付金额

	"P3A2B1": "ComponentId_280", // 过户税费大写
	"P3A2B2": "ComponentId_289", // 过户税费
	"P3A2B3": "ComponentId_293", // 过户税费承担方名称
	"P3A2B4": "ComponentId_281", // 代办手续费大写
	"P3A2B5": "ComponentId_290", // 代办手续费
	"P3A2B6": "ComponentId_294", // 代办手续费承担方名称

	"P3A3B1": "ComponentId_297", // 成交服务费比率(甲->丙)
	"P3A3B2": "ComponentId_291", // 成交服务费(甲->丙)
	"P3A3B3": "ComponentId_296", // 成交服务费(乙->丙)
	"P3A3B4": "ComponentId_292", // 成交服务费(乙->丙)

	"P3A4B1": "ComponentId_17", // 备注

	"P4A1B1": "ComponentId_66", // 甲方户名
	"P4A1B2": "ComponentId_18", // 甲方开户行
	"P4A1B3": "ComponentId_68", // 甲方账户
	"P4A2B1": "ComponentId_69", // 乙方户名
	"P4A2B2": "ComponentId_70", // 乙方开户行
	"P4A2B3": "ComponentId_71", // 乙方账户
	"P4A3B1": "ComponentId_72", // 丙方户名
	"P4A3B2": "ComponentId_73", // 丙方开户行
	"P4A3B3": "ComponentId_74", // 丙方账户

	"carPhotos":      "ComponentId_5",  // 车辆照片
	"interiorPhotos": "ComponentId_8",  // 内饰照片
	"defectPhotos":   "ComponentId_11", // 缺陷照片
	"dataPhotos":     "ComponentId_14", // 资料照片

}

// 卖方车商、第三方车商
var SaleSellerDealerThirdPartDealerParams = map[string]string{
	"FlowName":     "云云问车二手车买卖车商中介合同",
	"TemplateId":   "yDwcuUU3clf30UEAxd2rS6Ms2JpDnY0R",
	"RecipientId1": "yDw97UUo6ak3xUx7cfq0yfzs7lW45jVy", // 甲方模板中签署人Id
	"RecipientId2": "yDw97UUo6ak3zUx7cfq0xxuQ4tNzxTNx", // 乙方模板中签署人Id
	"RecipientId3": "yDw97UUo6ak3fUx7cfq0xY4xIx775lER", // 丙方模板中签署人Id

	"P1A1B1": "ComponentId_259", // 甲方名称
	"P1A1B2": "ComponentId_262", // 甲方法人姓名
	"P1A1B3": "ComponentId_266", // 甲方社会信用代码/身份证号码
	"P1A1B4": "ComponentId_263", // 甲方联系方式
	"P1A1B5": "ComponentId_308", // 甲方地址
	"P1A2B1": "ComponentId_260", // 乙方姓名
	"P1A2B2": "ComponentId_268", // 乙方身份证号码
	"P1A2B3": "ComponentId_264", // 乙方联系方式
	"P1A3B1": "ComponentId_261", // 丙方姓名
	"P1A3B2": "ComponentId_267", // 丙方统一社会信用代码
	"P1A3B3": "ComponentId_265", // 丙方联系方式
	"P1A3B4": "ComponentId_307", // 丙方地址

	"P2A1B1": "ComponentId_76",  // 厂牌型号
	"P2A1B2": "ComponentId_77",  // 车架号
	"P2A1B3": "ComponentId_78",  // 初次上牌日期
	"P2A1B4": "ComponentId_79",  // 车辆类型
	"P2A1B5": "ComponentId_80",  // 发动机号
	"P2A1B6": "ComponentId_81",  // 强制保险至
	"P2A1B7": "ComponentId_278", // 车牌号码
	"P2A1B8": "ComponentId_276", // 表显里程
	"P2A1B9": "ComponentId_274", // 环保等级

	"P3A1B1": "ComponentId_279", // 成交价人民币大写
	"P3A1B2": "ComponentId_282", // 成交价
	"P3A1B3": "ComponentId_113", // 定金人民币大写
	"P3A1B4": "ComponentId_283", // 定金
	"P3A1B5": "ComponentId_284", // 余额支付方式
	"P3A1B6": "ComponentId_286", // 交付时间
	"P3A1B7": "ComponentId_285", // 交付地点
	"P3A1B8": "ComponentId_288", // 首付金额大写
	"P3A1B9": "ComponentId_287", // 首付金额

	"P3A2B1": "ComponentId_280", // 过户税费大写
	"P3A2B2": "ComponentId_289", // 过户税费
	"P3A2B3": "ComponentId_293", // 过户税费承担方名称
	"P3A2B4": "ComponentId_281", // 代办手续费大写
	"P3A2B5": "ComponentId_290", // 代办手续费
	"P3A2B6": "ComponentId_294", // 代办手续费承担方名称

	"P3A3B1": "ComponentId_297", // 成交服务费比率(甲->丙)
	"P3A3B2": "ComponentId_291", // 成交服务费(甲->丙)
	"P3A3B3": "ComponentId_296", // 成交服务费(乙->丙)
	"P3A3B4": "ComponentId_292", // 成交服务费(乙->丙)

	"P3A4B1": "ComponentId_14", // 备注

	"P4A1B1": "ComponentId_82", // 甲方户名
	"P4A1B2": "ComponentId_15", // 甲方开户行
	"P4A1B3": "ComponentId_84", // 甲方账户
	"P4A2B1": "ComponentId_85", // 乙方户名
	"P4A2B2": "ComponentId_86", // 乙方开户行
	"P4A2B3": "ComponentId_87", // 乙方账户
	"P4A3B1": "ComponentId_88", // 丙方户名
	"P4A3B2": "ComponentId_89", // 丙方开户行
	"P4A3B3": "ComponentId_90", // 丙方账户

	"carPhotos":      "ComponentId_26", // 车辆照片
	"interiorPhotos": "ComponentId_27", // 内饰照片
	"defectPhotos":   "ComponentId_28", // 缺陷照片
	"dataPhotos":     "ComponentId_29", // 资料照片

}

// 测试ess
//var ConsignmentParams = map[string]string{
//	"FlowName":     "云云问车车辆寄卖服务协议",
//	"TemplateId":   "yDRspUUgyg17jjhsUEABqd38ICXK3HV6",
//	"RecipientId":  "yDRspUUgyg17jjlqUEABqd3y46njoRJG", // 企业静默签模板中签署人Id
//	"RecipientId1": "yDRspUUgyg17jjl8UEABqd3RvLRHZi3M", // 甲方模板中签署人Id
//
//	"P1A1B1": "a-nDanXMEew_", // 甲方姓名
//	"P1A1B2": "9mVtYy6XOuPw", // 甲方联系方式
//	"P1A1B3": "XC9Q0WGqH7Eu", // 甲方身份证号码
//
//	"P1A2B1": "48zF8ZKtNNKA", // 原车主姓名
//	"P1A2B2": "hTE1y_xigIZv", // 车牌号码
//	"P1A2B3": "I_qgit3cLinv", // 品牌车型
//	"P1A2B4": "qbTDwLWnAlZ-", // 车架号
//	"P1A2B5": "HW8Ph9HD9SsC", // 发动机号
//	"P1A2B6": "lniy3EOtMCb3", // 初次上牌日期
//	"P1A2B7": "LBgcj8ZnmqMj", // 表显里程
//
//	// 车辆使用性质选项卡
//	"P1A3B1": "X2Spqqqa4QVZ",
//	"P1A3B2": "-Q-dHesrjdcE",
//	"P1A3B3": "uwIcPcgRjUCD",
//	"P1A3B4": "9my7WyyHyP1V",
//	"P1A3B5": "oWRxZXI38iFw",
//
//	"P1A4B1": "S9McNLH562B6", // 代销价大写
//	"P1A4B2": "DSCNGioDQLpW", // 代销价小写
//
//	"P2A1B1": "PFQ0IbW7-MEz", // 甲方账户名称
//	"P2A1B2": "QsPpxAFGli8L", // 甲方账户
//
//	"P2A2B1": "BVowJQYUKOwW", // 代销期限起
//	"P2A2B2": "AILqkYueQrT5", // 代销期限止
//}
//
//var PurchaseParams = map[string]string{
//	"FlowName":   "云云问车二手车收购合同",
//	"TemplateId": "yDR41UUgyg11q0bwUxXpjTiuGGh746eu",
//	//"RecipientId":  "yDR4RUUgyg11gplpUEyZccEEf30rd7pu", // 企业静默签模板中签署人Id
//	"RecipientId1": "yDR4vUUgyg1tun4tUxNOFhfvIqnmgIQJ", // 甲方模板中签署人Id
//	"RecipientId2": "yDRsqUUgyg3deim0UEtr9nG1CM0XGjA3", // 乙方模板中签署人Id
//	"P1A1B1":       "nSveQgX2GO64",                     // 甲方姓名
//	"P1A1B2":       "o_k-ycqavfJA",                     // 乙方姓名
//	"P1A2B1":       "2P8MOujCokev",                     // 原车主名称
//	"P1A2B2":       "DSB0J7N4Iyws",                     // 品牌车型
//	"P1A2B3":       "e8Yju6LE_b4s",                     // 车辆牌照
//	"P1A2B4":       "nHVGykdSsKdA",                     // 证件类型
//	"P1A2B5":       "E6hZ-tY9M54c",                     // 证件号码
//	"P1A2B6":       "RvG8tKpxbDLN",                     // 外观内饰
//	"P1A2B7":       "Bk5Crc7dXv9g",                     // 发动机号
//	"P1A2B8":       "-vwdfC9SHBYB",                     // 车架号
//	"P1A2B9":       "sd4ZXmtNjLbY",                     // 表显里程
//	"P1A2B10":      "kDDbl-cbXVTY",                     // 出厂日期
//	"P1A2B11":      "M5GSOVQQ_O-P",                     // 初次登记日期
//	"P1A2B12":      "gdkGcpWqLVLk",                     // 保险费交付至
//	"P1A2B13":      "FnhRHUvfDFJB",                     // 车辆使用性质
//	"P1A3B1":       "y94mzBq2Wvw-",                     // 成交金额中文
//	"P1A3B2":       "EnH0M4NGbSqn",                     // 成交金额
//	"P1A3B3":       "4Qp8ScOynW46",                     // 首付时限
//	"P1A3B4":       "AHhYC7GwoEc2",                     // 首付比例
//	"P1A3B5":       "fe44mNdAzF4B",                     // 首付金额
//	"P1A3B6":       "yJ6VA6EpFqk8",                     // 余款时限
//	"P1A3B7":       "64nNl679hUXO",                     // 余款比例
//	"P1A3B8":       "4qb63eeEICZ1",                     // 余款金额
//	"P2A1B3":       "9U0KqocTfQgF",                     // 过户时限
//	"SIGN1":        "A-rdXhkWCabg",                     // 经办人
//	"SIGN2":        "MDR5o60oaNjC",                     // 经办人电话
//	"SIGN3":        "SvinIkqk1Exz",                     // 委托人
//	"SIGN4":        "luh1GNiifgFl",                     // 委托人电话
//}
//
//var SaleThirdPartKindNoneParams = map[string]string{
//	"FlowName":     "云云问车二手车买卖合同",
//	"TemplateId":   "yDRT3UUgyg3l5855Uxpbd37dZSfqcaTG",
//	"RecipientId1": "yDRT3UUgyg3l5b0hUucrNT6upPqX5adu", // 甲方模板中签署人Id
//	"RecipientId2": "yDRT3UUgyg3l5b0rUucrNT6wo4fWXlLR", // 乙方模板中签署人Id
//
//	"P1A1B1": "9GyymRcMub4J", // 甲方姓名
//	"P1A1B2": "tToAYcQBbIre", // 甲方身份证号码
//	"P1A1B3": "Sqzm7tIqZ3Tj", // 甲方联系方式
//	"P1A1B4": "VuCcV_mU_usw", // 乙方姓名
//	"P1A1B5": "QpQ_QI_jHudJ", // 乙方身份证号码
//	"P1A1B6": "e8GZMh7l1LOG", // 乙方联系方式
//
//	"P1A2B1": "SvsV76uI9Ku5", // 厂牌型号
//	"P1A2B2": "XimpUNh_v5z5", // 车架号后六位
//	"P1A2B3": "JsHbVLURqu7j", // 初次上牌日期
//	"P1A2B4": "KQWjeTKE3b6h", // 车辆类型
//	"P1A2B5": "ZSEV5B7BmUBn", // 发动机号后六位
//	"P1A2B6": "sJy-ra_ZWfDX", // 强制保险至
//	"P1A2B7": "OXVxeRU4Ugbf", // 车牌号码
//	"P1A2B8": "1NTmS8ffTqA_", // 表显里程
//	"P1A2B9": "35UfgsDok6Rm", // 环保等级
//
//	"P2A1B1": "t0xGodb343hg", // 成交价人民币大写
//	"P2A1B2": "6lFep1rU5NbB", // 成交价
//	"P2A1B3": "4Y0Lquv4yNb9", // 定金
//	"P2A1B4": "MNob-rC-7t5i", // 余额支付方式
//	"P2A1B5": "IO-qmNPIVWsI", // 交付时间
//	"P2A1B6": "uDra6RJJgI0w", // 交付地点
//	"P2A1B7": "mHTxPxbdT0fk", // 首付金额大写
//	"P2A1B8": "-Mb4zqcnzC3-", // 首付金额
//
//	"P2A2B1": "", // 过户税费大写
//	"P2A2B2": "", // 过户税费
//	"P2A2B3": "", // 过户税费承担方名称
//	"P2A2B4": "", // 代办手续费大写
//	"P2A2B5": "", // 代办手续费
//	"P2A2B6": "", // 代办手续费承担方名称
//}
//
//var SaleThirdPartKindPlatFormParams = map[string]string{
//	"FlowName":     "云云问车二手车买卖中介合同",
//	"TemplateId":   "yDR4vUUgyg1tunegUxNOFhfSa3ZEzYLl",
//	"RecipientId1": "yDR4vUUgyg1tunmoUxNOFhf8IZQ3z3Do", // 甲方模板中签署人Id
//	"RecipientId2": "yDRsFUUgyg16svr6UEq91gTET4SuvSmY", // 乙方模板中签署人Id
//	"RecipientId3": "yDR4vUUgyg1tunmvUxNOFhfwT88LOvYW", // 丙方(企业静默签)模板中签署人Id
//
//	"P1A1B1": "1Ie2lwwsfHIZ", // 甲方姓名
//	"P1A1B2": "rKnvuJKG2Fqr", // 甲方身份证号码
//	"P1A1B3": "zaut5N1U3vvT", // 甲方联系方式
//	"P1A1B4": "JncpPGJdpj-H", // 乙方姓名
//	"P1A1B5": "acmoccFAchS2", // 乙方身份证号码
//	"P1A1B6": "R74933gxuS5j", // 乙方联系方式
//	"P1A1B7": "60G3x8JSs5sF", // 丙方姓名
//	"P1A1B8": "B8JRIqRA-Kbb", // 丙方统一社会信用代码
//	"P1A1B9": "CAcq1C6DoCrn", // 丙方联系方式
//
//	"P1A2B1": "ykjPFeZ1JuhU", // 厂牌型号
//	"P1A2B2": "SYWJOtild8Wr", // 车架号后六位
//	"P1A2B3": "kdWw6tyLyEsi", // 初次上牌日期
//	"P1A2B4": "GdouSoOUq7d7", // 车辆类型
//	"P1A2B5": "yXqrZ-JolRYY", // 发动机号后六位
//	"P1A2B6": "9xk585F_ZD2D", // 强制保险至
//	"P1A2B7": "1y85lD6jJnZL", // 车牌号码
//	"P1A2B8": "MvaWcNyAE-lf", // 表显里程
//	"P1A2B9": "MNojX-di8AeI", // 环保等级
//
//	"P2A1B1": "XMx2O8HU1Bp0", // 成交价人民币大写
//	"P2A1B2": "UQFKh08wUy2g", // 成交价
//	"P2A1B3": "znD2Ae0ICGMT", // 定金
//	"P2A1B4": "0OJezahkQZJN", // 余额支付方式
//	"P2A1B5": "7MpwMZi6srGu", // 交付时间
//	"P2A1B6": "LegtTvg0FpI2", // 交付地点
//	"P2A1B7": "0Lzcvbq9O2wi", // 首付金额大写
//	"P2A1B8": "Jio_mrjmPCDS", // 首付金额
//
//	"P2A2B1": "yVplwSAgdBVs", // 过户税费大写
//	"P2A2B2": "ADJooDIuCsus", // 过户税费
//	"P2A2B3": "G7Cd-bl--Pbv", // 过户税费承担方名称
//	"P2A2B4": "vL_LXB-qdNdO", // 代办手续费大写
//	"P2A2B5": "3E0PkSEcBf5c", // 代办手续费
//	"P2A2B6": "DGa2TaNhhq0d", // 代办手续费承担方名称
//
//	"P2A3B1": "tk_dI2OrnyGD", // 成交服务费比率(甲->丙)
//	"P2A3B2": "YnBFyv4eh8VN", // 成交服务费(甲->丙)
//	"P2A3B3": "YNBQwvEKg8vB", // 成交服务费(乙->丙)
//	"P2A3B4": "qJgVStJBZYRI", // 成交服务费(乙->丙)
//}
//
//var SaleThirdPartKindDealerParams = map[string]string{
//	"FlowName":     "云云问车二手车买卖车商中介合同",
//	"TemplateId":   "yDRT0UUgyg357yd9UTdkDrCqC9rXnOi6",
//	"RecipientId1": "yDRT0UUgyg3594uoUxbDXn5upxTEf0SR", // 甲方模板中签署人Id
//	"RecipientId2": "yDRT0UUgyg3594usUxbDXn5Bh9xdeVHc", // 乙方模板中签署人Id
//	"RecipientId3": "yDRT0UUgyg3594u3UxbDXn5ChJ2AkfWx", // 丙方模板中签署人Id
//
//	"P1A1B1": "VzRJ2qF3no9O", // 甲方姓名
//	"P1A1B2": "KXq0dSXdIW9p", // 甲方身份证号码
//	"P1A1B3": "N9nMAcfmX4AV", // 甲方联系方式
//	"P1A1B4": "oxvddoCGIcrv", // 乙方姓名
//	"P1A1B5": "nmYTV-h4pKHQ", // 乙方身份证号码
//	"P1A1B6": "i1QPuzUetKKO", // 乙方联系方式
//	"P1A1B7": "WDdbXZ9M2Tn7", // 丙方姓名
//	"P1A1B8": "a48YCqhVkplh", // 丙方统一社会信用代码
//	"P1A1B9": "1ggUCyWiwLzr", // 丙方联系方式
//
//	"P1A2B1": "VlK0e2zAk99K", // 厂牌型号
//	"P1A2B2": "noJrPHwFiC2v", // 车架号后六位
//	"P1A2B3": "bXhqmhKemqfM", // 初次上牌日期
//	"P1A2B4": "gC2IeFgFwoHL", // 车辆类型
//	"P1A2B5": "xXsjVNVKTRXa", // 发动机号后六位
//	"P1A2B6": "XfYtWJqV7DKz", // 强制保险至
//	"P1A2B7": "TJY3uGyWWSu5", // 车牌号码
//	"P1A2B8": "VxOtPR5Os54N", // 表显里程
//	"P1A2B9": "szrS9duJqfFw", // 环保等级
//
//	"P2A1B1": "dt39n53sUrjD", // 成交价人民币大写
//	"P2A1B2": "7fqDknmeljqN", // 成交价
//	"P2A1B3": "DHVsuS22CAbr", // 定金
//	"P2A1B4": "X-jEL_RhWlv_", // 余额支付方式
//	"P2A1B5": "y7qby1Fq6Mne", // 交付时间
//	"P2A1B6": "47M0-HRAVPPf", // 交付地点
//	"P2A1B7": "Mqu0Q_6qxlzZ", // 首付金额大写
//	"P2A1B8": "TCo65ZYDdgg_", // 首付金额
//
//	"P2A2B1": "", // 过户税费大写
//	"P2A2B2": "", // 过户税费
//	"P2A2B3": "", // 过户税费承担方名称
//	"P2A2B4": "", // 代办手续费大写
//	"P2A2B5": "", // 代办手续费
//	"P2A2B6": "", // 代办手续费承担方名称
//
//	"P2A3B1": "A1rBcRGsAVuV", // 成交服务费比率(甲->丙)
//	"P2A3B2": "FFSg5nIvcSrZ", // 成交服务费(甲->丙)
//	"P2A3B3": "_pJIpj9yA4Pu", // 成交服务费比率(乙->丙)
//	"P2A3B4": "tDD33h3DjBMv", // 成交服务费(乙->丙)
//}
