package app

import (
	"base/app/controller/area"
	"base/app/controller/broker"
	"base/app/controller/broker/app"
	"base/app/controller/broker/audit"
	"base/app/controller/broker/business"
	"base/app/controller/broker/car"
	"base/app/controller/broker/contract"
	"base/app/controller/broker/customer"
	"base/app/controller/broker/dealer"
	"base/app/controller/broker/h5"
	"base/app/controller/broker/message"
	"base/app/controller/broker/order"
	"base/app/controller/broker/playbill"
	"base/app/controller/broker/split"
	"base/app/controller/broker/task"
	"base/app/controller/broker/user"
	"base/app/controller/broker/user/wallet"
	"base/app/router/middleware"
	"github.com/gin-gonic/gin"
)

func BrokerRouter(router *gin.RouterGroup) {
	// 登录
	loginController := broker.Login{}
	{
		router.POST("login/phone", loginController.LoginPhone)             // 手机号一键登录
		router.POST("login/wechat", loginController.LoginWechat)           // 微信登录
		router.POST("login/code", loginController.LoginPhoneCode)          // 验证码登录
		router.POST("login/bind/wechat", loginController.WechatBindBroker) // 绑定微信账号
		router.POST("login/bind/apple", loginController.AppleBindBroker)   // 绑定苹果账号
		router.POST("login/sms", loginController.Sms)                      // 发送短信
		router.POST("login/logout", loginController.Logout)                // 退出登录
		router.POST("login/apple", loginController.LoginApple)             // 苹果登录
	}
	// 地区数据
	areaController := area.Area{}
	{
		router.POST("city/all", areaController.City)        // 获取城市数据
		router.POST("area/all", areaController.All)         // 获取省市区数据
		router.POST("area/version", areaController.Version) // 获取省市区数据版本
	}
	// 用户
	userRouter := router.Group("user", middleware.BrokerAuth)
	{
		userController := user.User{}
		{
			//userRouter.POST("all", userController.All)       // 全部经纪人
			userRouter.POST("broker/search", userController.Search) // 搜索经纪人
			userRouter.POST("info", userController.Info)            // 用户详情
			userRouter.POST("update", userController.Update)        // 更新用户信息
			userRouter.POST("logoff", userController.Logoff)        // 注销
		}

		walletRouetr := userRouter.Group("wallet")
		{
			assessController := wallet.Assess{}
			{
				walletRouetr.POST("assess/count", assessController.Count)       // 获取钱包余量
				walletRouetr.POST("assess/recharge", assessController.Recharge) // 充值
				walletRouetr.POST("assess/history", assessController.History)   // 评估记录列表
			}
		}
		certifyController := user.Certify{}
		{
			userRouter.POST("certify/ali", certifyController.Ali)              // 支付宝实名认证
			userRouter.POST("certify/ali/result", certifyController.AliResult) // 获取支付宝实名认证结果
		}
		partnerController := user.Partner{}
		{
			//userRouter.POST("partner/contract/sign", partnerController.ContractSign) // 合同签订
			userRouter.POST("partner/order/create", partnerController.CreateOrder) // 创建订单
			userRouter.POST("partner/pay", partnerController.Pay)                  // 支付
			userRouter.POST("partner/orderInfo", partnerController.OrderInfo)      // 合伙人订单详情
		}
	}
	// 文件
	fileRouter := router.Group("file", middleware.BrokerAuth)
	{
		uploadController := broker.Upload{}
		{
			fileRouter.POST("upload/image", uploadController.Image) // 图片上传
			fileRouter.POST("upload/file", uploadController.File)   // 文件上传
		}
	}
	// 车辆
	carRouter := router.Group("car", middleware.BrokerAuth)
	{
		brandController := car.Brand{}
		{
			carRouter.POST("brand/all", brandController.All) // 获取品牌
		}
		seriesController := car.Series{}
		{
			carRouter.POST("series/all", seriesController.All) // 品牌下所有车系
		}
		modelController := car.Model{}
		{
			carRouter.POST("model/all", modelController.All)   // 车系下所有车型
			carRouter.POST("model/info", modelController.Info) // 车型详情
		}
		ocrController := car.Ocr{}
		{
			carRouter.POST("cor/vehicle", ocrController.Vehicle)   // 行驶证识别
			carRouter.POST("cor/idCard", ocrController.IdCard)     // 身份证识别
			carRouter.POST("cor/bankCard", ocrController.BankCard) // 银行卡识别
		}
		priceController := car.Price{}
		{
			carRouter.POST("price/estimate", priceController.Estimate)          // 估算价格
			carRouter.POST("price/fast/estimate", priceController.FastEstimate) // 快速估算价格
			carRouter.POST("price/amount", priceController.Amount)              // 费用计算
			carRouter.POST("price/fast/lists", priceController.FastLists)       // 快速估价列表
			carRouter.POST("price/lists", priceController.Lists)                // 估价列表
			carRouter.POST("price/info", priceController.Info)                  // 估价详情
		}
		// 收藏
		collectController := car.Collect{}
		{
			carRouter.POST("collect/lists", collectController.Lists)   // 收藏列表
			carRouter.POST("collect/add", collectController.Add)       // 添加收藏
			carRouter.POST("collect/cancel", collectController.Cancel) // 取消收藏
		}
		carController := car.Car{}
		{
			carRouter.POST("lists", carController.Lists)         // 车辆列表
			carRouter.POST("count", carController.CarCount)      // 车辆统计
			carRouter.POST("info", carController.Info)           // 车辆详情
			carRouter.POST("parameter", carController.Parameter) // 车辆参数

			carRouter.POST("self", carController.Self)            // 我的车辆列表
			carRouter.POST("self/count", carController.SelfCount) // 我的车辆统计
			carRouter.POST("vin/check", carController.VinCheck)   // 验证vin合理性

			carRouter.POST("adjustPrice", middleware.RoleStoreOwner, carController.AdjustPrice) // 调价
			carRouter.POST("priceHistory", carController.PriceHistory)                          //  价格历史（至多10次）
			carRouter.POST("upper", middleware.RoleBusinessStaffWorker, carController.Upper)    // 申请上架车辆
			carRouter.POST("down", middleware.RoleBusinessStaffWorker, carController.Down)      // 申请下架车辆
		}

		carEditController := car.Edit{}
		{
			carRouter.POST("edit/add", middleware.RoleBusinessStaffWorker, carEditController.Add)         // 申请编辑车辆
			carRouter.POST("edit/lists", middleware.RoleBusinessStaffWorker, carEditController.Lists)     // 编辑记录
			carRouter.POST("edit/dealer/lists", middleware.RoleStoreOwner, carEditController.DealerLists) // 车商审批车辆编辑记录
			carRouter.POST("edit/info", middleware.RoleBusinessStaffWorker, carEditController.Info)       // 详情
			carRouter.POST("edit/adopt", middleware.RoleStoreOwner, carEditController.Adopt)              // 编辑车商通过
			carRouter.POST("edit/reject", middleware.RoleStoreOwner, carEditController.Reject)            // 编辑车商拒绝
		}

		carBaseController := car.Base{}
		{
			carRouter.POST("publish", middleware.RoleBusinessStaffWorker, carBaseController.Publish)         // 申请发布车辆
			carRouter.POST("publish/lists", middleware.RoleBusinessStaffWorker, carBaseController.Lists)     // 发布列表
			carRouter.POST("publish/dealer/lists", middleware.RoleStoreOwner, carBaseController.DealerLists) // 车商审批发布列表
			carRouter.POST("publish/info", middleware.RoleBusinessStaffWorker, carBaseController.Info)       // 发布详情
			carRouter.POST("publish/adopt", middleware.RoleStoreOwner, carBaseController.Adopt)              // 发布车商通过
			carRouter.POST("publish/reject", middleware.RoleStoreOwner, carBaseController.Reject)            // 发布车商拒绝
		}
	}
	// 审批
	auditRouter := router.Group("audit", middleware.BrokerAuth)
	{
		// 车商审批
		dealerAuditController := audit.DealerAudit{}
		{
			auditRouter.POST("dealer/count", dealerAuditController.AuditCount) // 统计
		}
	}
	// 合同
	contractRouter := router.Group("contract", middleware.BrokerAuth, middleware.BrokerLevelNotBase)
	{
		consignmentController := contract.Consignment{}
		{
			contractRouter.POST("consignment/lists", consignmentController.Lists)   // 列表
			contractRouter.POST("consignment/add", consignmentController.Add)       // 发起
			contractRouter.POST("consignment/cancel", consignmentController.Cancel) // 取消
		}
		purchaseController := contract.Purchase{}
		{
			contractRouter.POST("purchase/lists", middleware.RoleBusinessStaffWorker, purchaseController.Lists)     // 列表
			contractRouter.POST("purchase/dealer/lists", middleware.RoleStoreOwner, purchaseController.DealerLists) // 车商审批列表
			contractRouter.POST("purchase/info", middleware.RoleBusinessStaffWorker, purchaseController.Info)       // 详情
			contractRouter.POST("purchase/add", middleware.RoleBusinessStaffWorker, purchaseController.Add)         // 发起
			contractRouter.POST("purchase/adopt", middleware.RoleStoreOwner, purchaseController.Adopt)              // 车商审核通过
			contractRouter.POST("purchase/reject", middleware.RoleStoreOwner, purchaseController.Reject)            // 车商审核拒绝
			contractRouter.POST("purchase/cancel", middleware.RoleBusinessStaffWorker, purchaseController.Cancel)   // 取消
		}
		saleController := contract.Sale{}
		{
			contractRouter.POST("sale/lists", saleController.Lists)                                         // 列表
			contractRouter.POST("sale/dealer/lists", middleware.RoleStoreOwner, saleController.DealerLists) // 车商审批列表
			contractRouter.POST("sale/info", middleware.RoleBusinessStaffWorker, saleController.Info)       // 详情
			contractRouter.POST("sale/add", saleController.Add)                                             // 添加
			contractRouter.POST("sale/adopt", middleware.RoleStoreOwner, saleController.Adopt)              // 车商审核通过
			contractRouter.POST("sale/reject", middleware.RoleStoreOwner, saleController.Reject)            // 车商审核拒绝
			contractRouter.POST("sale/cancel", saleController.Cancel)                                       // 取消
		}
		contractController := contract.Contract{}
		{
			contractRouter.POST("ess/signUrl", contractController.EssSignUrl) // 获取合同签署地址
			contractRouter.POST("ess/file", contractController.EssFile)       // 获取最新合同文件
		}
	}
	// 客户
	customerRouter := router.Group("customer", middleware.BrokerAuth)
	{
		customerController := customer.Customer{}
		{
			customerRouter.POST("lists", customerController.Lists)                      // 客户列表
			customerRouter.POST("count", customerController.Count)                      // 客户统计
			customerRouter.POST("info", customerController.Info)                        // 客户详情
			customerRouter.POST("important", customerController.Important)              // 设为重要
			customerRouter.POST("important/cancel", customerController.ImportantCancel) // 取消重要
			customerRouter.POST("select", customerController.Select)                    // 客户筛选
		}
		browseController := customer.Browse{}
		{
			customerRouter.POST("browse/lists", browseController.Lists) // 浏览车辆列表
		}
		trailController := customer.Trail{}
		{
			customerRouter.POST("trail/all", trailController.All) // 客户轨迹
		}
	}
	// 车商
	dealerRouter := router.Group("dealer", middleware.BrokerAuth)
	{
		dealerController := dealer.Dealer{}
		{
			dealerRouter.POST("select", dealerController.Select) // 车商筛选
		}
	}

	// 分账
	splitRouter := router.Group("split", middleware.BrokerAuth)
	{
		accountController := split.Account{}
		{
			splitRouter.POST("account/list", accountController.List)         // 分账列表
			splitRouter.POST("account/create", accountController.Create)     // 创建分账
			splitRouter.POST("account/info", accountController.AccountInfo)  // 分账明细
			splitRouter.POST("account/editName", accountController.EditName) // 编辑名称
			splitRouter.POST("account/addBill", accountController.AddBill)   // 添加账单
			splitRouter.POST("account/profit", accountController.Profit)     // 利润统计
			splitRouter.POST("account/finish", accountController.Finish)     // 结束分账
		}
		contactController := split.Contact{}
		{
			splitRouter.POST("contact/all", contactController.All)       // 获取常用联系人
			splitRouter.POST("contact/update", contactController.Update) // 更新常用联系人状态
		}
	}

	// 订单
	orderRouter := router.Group("order", middleware.BrokerAuth, middleware.BrokerLevelNotBase)
	{
		// 寄卖
		consignmentController := order.Consignment{}
		{
			orderRouter.POST("consignment/lists", consignmentController.Lists)                                                      // 寄卖订单列表
			orderRouter.POST("consignment/business/lists", middleware.RoleBusinessStaffWorker, consignmentController.BusinessLists) // 入驻商下寄卖订单列表
			orderRouter.POST("consignment/info", consignmentController.Info)                                                        // 车辆详情
			orderRouter.POST("consignment/info/car", consignmentController.InfoCar)                                                 // 订单车辆详情
		}
		// 车商寄卖
		dealerConsignmentController := order.DealerConsignment{}
		{
			orderRouter.POST("dealer/consignment/lists", dealerConsignmentController.Lists) // 寄卖订单列表
			orderRouter.POST("dealer/consignment/add", dealerConsignmentController.Add)     // 添加车商寄卖订单
		}
		// 售车
		saleController := order.Sale{}
		{
			orderRouter.POST("sale/lists", saleController.Lists)                           // 售车订单
			orderRouter.POST("sale/test_report", saleController.TestReport)                // 检车报告
			orderRouter.POST("sale/transfer", saleController.Transfer)                     // 过户
			orderRouter.POST("sale/offline/transfer", saleController.OfflineTransfer)      // 线下客户过户
			orderRouter.POST("sale/offline/payment", saleController.OfflineBalancePayment) // 线下订单上传尾款支付
			orderRouter.POST("sale/final", saleController.Final)                           // 完结订单
			orderRouter.POST("sale/info", saleController.Info)                             // 订单详情
		}
		// 邀约
		inviteController := order.Invite{}
		{
			orderRouter.POST("invite/add", inviteController.Add) // 发起邀约
		}
		// 叫车
		callCarController := order.CallCar{}
		{
			orderRouter.POST("call/car/lists", callCarController.Lists) // 叫车订单列表
			orderRouter.POST("call/car/info", callCarController.Info)   // 叫车订单详情
			orderRouter.POST("call/car/add", callCarController.Add)     // 添加叫车订单
			orderRouter.POST("call/car/final", callCarController.Final) // 交车完成
		}
		dataController := order.Data{}
		{
			orderRouter.POST("data/count", dataController.Count) // 订单统计
		}
	}
	// 海报
	playbillRouter := router.Group("playbill", middleware.BrokerAuth)
	{
		playbillController := playbill.Playbill{}
		{
			playbillRouter.POST("lists", playbillController.Lists) // 海报列表
		}
	}
	// 任务中心
	taskRouter := router.Group("task", middleware.BrokerAuth)
	{
		inviteController := task.Invite{}
		{
			taskRouter.POST("invite/lists", inviteController.Lists) // 客户邀约列表
			taskRouter.POST("invite/add", inviteController.Add)     // 看车邀约
		}
	}
	// 企业管理
	businessRouter := router.Group("business", middleware.BrokerAuth)
	{
		businessController := business.Business{}
		{
			businessRouter.POST("allBusiness", businessController.AllBusiness) // 获取全部入驻商
			businessRouter.POST("allStaff", businessController.AllStaff)       // 获取全部入驻商员工
		}
		roleController := business.Role{}
		{
			businessRouter.POST("role/all", roleController.All) // 获取全部角色
		}
		storeController := business.Store{}
		{
			businessRouter.POST("all", storeController.StructAll)                               // 组织架构
			businessRouter.POST("store/all", storeController.All)                               // 全部门店
			businessRouter.POST("store/add", middleware.RoleBusinessOwner, storeController.Add) // 添加门店
			businessRouter.POST("store/select", storeController.Select)                         // 门店筛选
		}
		staffController := business.Staff{}
		{
			businessRouter.POST("staff/all", staffController.All)                                  // 全部员工
			businessRouter.POST("staff/add", middleware.RoleStoreOwner, staffController.Add)       // 添加员工
			businessRouter.POST("staff/info", staffController.Info)                                // 员工详情
			businessRouter.POST("staff/edit", middleware.RoleStoreOwner, staffController.Edit)     // 编辑员工
			businessRouter.POST("staff/delete", middleware.RoleStoreOwner, staffController.Delete) // 删除员工
		}
	}
	messageController := message.Message{}
	{
		router.GET("message", middleware.BrokerAuth, messageController.Message)        // 消息websocket
		router.POST("message/count", middleware.BrokerAuth, messageController.Count)   // 未读消息统计
		router.POST("message/lists", middleware.BrokerAuth, messageController.Lists)   // 消息列表
		router.POST("message/info", middleware.BrokerAuth, messageController.Info)     // 消息详情
		router.POST("message/send", middleware.BrokerAuth, messageController.TestSend) // 发送消息测试
	}
	// app相关
	appRouter := router.Group("app", middleware.BrokerAuth)
	{
		feedbackController := app.Feedback{}
		{
			appRouter.POST("feedback/submit", feedbackController.Submit) // 提交意见
		}
		handbookController := app.Handbook{}
		{
			appRouter.POST("handbook/all", handbookController.All)   // 获取手册
			appRouter.POST("handbook/info", handbookController.Info) // 手册详情
		}
	}

	// H5经纪人相关
	h5Router := router.Group("h5", middleware.H5BrokerAuth)
	{
		h5PartnerController := h5.Partner{}
		{
			h5Router.POST("partner/order/create", h5PartnerController.CreateOrder) // 创建订单
			h5Router.POST("partner/pay", h5PartnerController.Pay)                  // 支付
			h5Router.POST("partner/orderInfo", h5PartnerController.OrderInfo)      // 合伙人订单详情
		}
	}
}
