package web

import (
	"base/app/controller/manage"
	"base/app/controller/manage/app"
	"base/app/controller/manage/banner/broker"
	"base/app/controller/manage/banner/customer"
	broker2 "base/app/controller/manage/broker"
	"base/app/controller/manage/business"
	"base/app/controller/manage/car"
	"base/app/controller/manage/contract"
	customer2 "base/app/controller/manage/customer"
	"base/app/controller/manage/dealer"
	"base/app/controller/manage/order"
	"base/app/controller/manage/partner"
	"base/app/controller/manage/playbill"
	"base/app/controller/manage/popularize"
	"base/app/controller/manage/setting"
	"base/app/controller/manage/user"
	"base/app/router/middleware"
	"github.com/gin-gonic/gin"
)

func ManageRouter(router *gin.RouterGroup) {
	// 登录
	loginController := manage.Login{}
	{
		router.POST("login", loginController.Login)                                 // 登录
		router.POST("login/logout", middleware.ManageLogin, loginController.Logout) // 退出登录
	}
	// 用户
	userRouter := router.Group("user", middleware.ManageAuth)
	{
		manageController := user.Manage{}
		{
			userRouter.POST("manage/repass", manageController.Repass) // 重设密码
			userRouter.POST("manage/update", manageController.Update) // 更新用户信息
			userRouter.POST("manage/menu", manageController.Menu)     // 用户角色菜单
		}
	}
	// 文件
	fileRouter := router.Group("file", middleware.ManageAuth)
	{
		uploadController := manage.Upload{}
		{
			fileRouter.POST("upload/image", uploadController.Image) // 图片上传
			fileRouter.POST("upload/file", uploadController.File)   // 文件上传
		}
	}
	// 系统配置
	settingRouter := router.Group("setting", middleware.ManageAuth)
	{
		menuController := setting.Menu{}
		{
			settingRouter.POST("menu/all", menuController.All)       // 获取全部菜单
			settingRouter.POST("menu/add", menuController.Add)       // 添加菜单
			settingRouter.POST("menu/info", menuController.Info)     // 菜单详情
			settingRouter.POST("menu/edit", menuController.Edit)     // 编辑菜单
			settingRouter.POST("menu/delete", menuController.Delete) // 删除菜单
		}

		apiController := setting.Api{}
		{
			settingRouter.POST("api/all", apiController.All)       // 获取全部api接口
			settingRouter.POST("api/add", apiController.Add)       // 添加api接口
			settingRouter.POST("api/edit", apiController.Edit)     // 编辑api接口
			settingRouter.POST("api/delete", apiController.Del)    // 删除api接口
			settingRouter.POST("api/select", apiController.Select) // api接口筛选
		}

		roleController := setting.Role{}
		{
			settingRouter.POST("role/lists", roleController.Lists)   // 角色列表
			settingRouter.POST("role/add", roleController.Add)       // 添加角色
			settingRouter.POST("role/info", roleController.Info)     // 角色详情
			settingRouter.POST("role/edit", roleController.Edit)     // 编辑角色
			settingRouter.POST("role/delete", roleController.Delete) // 删除角色
			settingRouter.POST("role/select", roleController.Select) // 角色筛选
		}

		manageController := setting.Manage{}
		{
			settingRouter.POST("user/lists", manageController.Lists)       // 用户列表
			settingRouter.POST("user/add", manageController.Add)           // 添加用户
			settingRouter.POST("user/edit", manageController.Edit)         // 编辑用户
			settingRouter.POST("user/enabled", manageController.Enabled)   // 启用用户
			settingRouter.POST("user/disabled", manageController.Disabled) // 停用用户
			settingRouter.POST("user/select", manageController.Select)     // 用户筛选
		}
		// 业务
		saleController := setting.Sale{}
		{
			settingRouter.POST("sale/select", saleController.Select) // 业务员筛选
		}
		// 使用参数配置
		parameterController := setting.Parameter{}
		{
			settingRouter.POST("parameter/all", parameterController.All)   // 全部参数
			settingRouter.POST("parameter/edit", parameterController.Edit) // 编辑
		}
	}
	// 轮播图
	bannerRouter := router.Group("banner", middleware.ManageAuth)
	{
		appController := broker.App{}
		{
			bannerRouter.POST("broker/app/lists", appController.Lists) // 经纪人app轮播图列表
			bannerRouter.POST("broker/app/add", appController.Add)     // 添加轮播图
			bannerRouter.POST("broker/app/info", appController.Info)   // 轮播图详情
			bannerRouter.POST("broker/app/edit", appController.Edit)   // 轮播图编辑
		}
		wxappController := customer.Wxapp{}
		{
			bannerRouter.POST("customer/wxapp/lists", wxappController.Lists)   // 客户wxapp轮播图列表
			bannerRouter.POST("customer/wxapp/add", wxappController.Add)       // 添加轮播图
			bannerRouter.POST("customer/wxapp/info", wxappController.Info)     // 轮播图详情
			bannerRouter.POST("customer/wxapp/edit", wxappController.Edit)     // 轮播图编辑
			bannerRouter.POST("customer/wxapp/delete", wxappController.Delete) // 轮播图删除
		}
	}
	// 推广
	popularizeRouter := router.Group("popularize", middleware.ManageAuth)
	{
		brandController := popularize.Brand{}
		{
			popularizeRouter.POST("brand/lists", brandController.Lists)          // 品牌推广列表
			popularizeRouter.POST("brand/add", brandController.Add)              // 添加品牌
			popularizeRouter.POST("brand/edit/brand", brandController.EditBrand) // 编辑品牌
			popularizeRouter.POST("brand/edit/sort", brandController.EditSort)   // 编辑排序
			popularizeRouter.POST("brand/delete", brandController.Delete)        // 删除
		}
	}
	// 入驻商
	businessRouter := router.Group("business", middleware.ManageAuth)
	{
		businessController := business.Business{}
		{
			businessRouter.POST("lists", businessController.Lists)               // 入驻商列表
			businessRouter.POST("add", businessController.Add)                   // 添加入驻商
			businessRouter.POST("info", businessController.Info)                 // 入驻商详情
			businessRouter.POST("edit", businessController.Edit)                 // 编辑入驻商数据
			businessRouter.POST("auditing/lists", businessController.AuditLists) // 入驻商审核列表
			businessRouter.POST("auditing/adopt", businessController.Adopt)      // 审核通过
			businessRouter.POST("auditing/reject", businessController.Reject)    // 审核驳回
		}

		storeController := business.Store{}
		{
			businessRouter.POST("store/lists", storeController.Lists)            // 门店列表
			businessRouter.POST("store/audit/lists", storeController.AuditLists) // 审核列表
			businessRouter.POST("store/info", storeController.Info)              // 详情
			businessRouter.POST("store/adopt", storeController.Adopt)            // 审核通过
			businessRouter.POST("store/reject", storeController.Reject)          // 审核驳回
		}

		staffController := business.Staff{}
		{
			businessRouter.POST("staff/lists", staffController.Lists)   // 子账户审核列表
			businessRouter.POST("staff/info", staffController.Info)     // 详情
			businessRouter.POST("staff/adopt", staffController.Adopt)   // 审核通过
			businessRouter.POST("staff/reject", staffController.Reject) // 审核驳回
			businessRouter.POST("staff/direct", staffController.Direct) // 直营经纪人
		}
	}
	// 车辆
	carRouter := router.Group("car", middleware.ManageAuth)
	{
		brandController := car.Brand{}
		{
			carRouter.POST("brand/lists", brandController.Lists) // 品牌列表
			carRouter.POST("brand/edit", brandController.Edit)   // 修改品牌信息
			carRouter.POST("brand/isHot", brandController.IsHot) // 修改热门品牌
		}
		carBaseController := car.CarBase{}
		{
			carRouter.POST("consignment/lists", carBaseController.Lists)   // 车辆审核列表
			carRouter.POST("consignment/info", carBaseController.Info)     // 审核车辆详情
			carRouter.POST("consignment/adopt", carBaseController.Adopt)   // 审核通过
			carRouter.POST("consignment/reject", carBaseController.Reject) // 审核驳回
		}
		dealerConsignmentController := car.DealerConsignment{}
		{
			carRouter.POST("dealer/consignment/lists", dealerConsignmentController.Lists)   // 车辆审核列表
			carRouter.POST("dealer/consignment/adopt", dealerConsignmentController.Adopt)   // 审核通过
			carRouter.POST("dealer/consignment/reject", dealerConsignmentController.Reject) // 审核驳回
		}
		// 二手车
		secondController := car.Second{}
		{
			carRouter.POST("second/lists", secondController.Lists) // 二手车列表
			carRouter.POST("second/info", secondController.Info)   // 二手车详情
			carRouter.POST("second/upper", secondController.Upper) // 二手车上架
			carRouter.POST("second/down", secondController.Down)   // 二手车下架
		}
	}
	// 海报
	playbillRouter := router.Group("playbill", middleware.ManageAuth)
	{
		playbillController := playbill.Playbill{}
		{
			playbillRouter.POST("lists", playbillController.Lists)   // 海报列表
			playbillRouter.POST("add", playbillController.Add)       // 添加海报
			playbillRouter.POST("info", playbillController.Info)     // 海报详情
			playbillRouter.POST("edit", playbillController.Edit)     // 编辑海报
			playbillRouter.POST("delete", playbillController.Delete) // 删除海报
		}
	}
	// 独立合伙人
	partnerRouter := router.Group("partner", middleware.ManageAuth)
	{
		partnerController := partner.Partner{}
		{
			partnerRouter.POST("lists", partnerController.Lists) // 合伙人列表
		}
	}
	// 经纪人管理
	brokerRouter := router.Group("broker", middleware.ManageAuth)
	{
		brokerController := broker2.Broker{}
		{
			brokerRouter.POST("lists", brokerController.Lists)       // 经纪人列表
			brokerRouter.POST("info", brokerController.Info)         // 经纪人详情
			brokerRouter.POST("recharge", brokerController.Recharge) // 经纪人充值
		}
	}
	// 客户管理
	customerRouter := router.Group("customer", middleware.ManageAuth)
	{
		customerController := customer2.Customer{}
		{
			customerRouter.POST("lists", customerController.Lists)           // 客户列表
			customerRouter.POST("distribute", customerController.Distribute) // 分配经纪人
			customerRouter.POST("info", customerController.Info)             // 客户详情
		}

		// 客户经纪人调整
		customerBrokerController := customer2.CustomerBroker{}
		{
			customerRouter.POST("audit/lists", customerBrokerController.Lists)   // 申请列表
			customerRouter.POST("audit/info", customerBrokerController.Info)     // 申请详情
			customerRouter.POST("audit/adopt", customerBrokerController.Adopt)   // 审核通过
			customerRouter.POST("audit/reject", customerBrokerController.Reject) // 审核驳回
		}
	}
	// 车商管理
	dealerRouter := router.Group("dealer", middleware.ManageAuth)
	{
		// 车商管理
		dealerController := dealer.Dealer{}
		{
			dealerRouter.POST("lists", dealerController.Lists)   // 车商列表
			dealerRouter.POST("add", dealerController.Add)       // 添加车商
			dealerRouter.POST("info", dealerController.Info)     // 车商详情
			dealerRouter.POST("able", dealerController.Able)     // 车商启用停用
			dealerRouter.POST("delete", dealerController.Delete) // 车商删除
		}
		// 车商审核
		auditController := dealer.Audit{}
		{
			dealerRouter.POST("audit/lists", auditController.Lists)   // 审核列表
			dealerRouter.POST("audit/adopt", auditController.Adopt)   // 审核通过
			dealerRouter.POST("audit/reject", auditController.Reject) // 审核驳回
			dealerRouter.POST("audit/info", auditController.Info)     // 审核详情
		}
	}
	// 订单管理
	orderRouter := router.Group("order", middleware.ManageAuth)
	{
		// 售车订单
		saleController := order.Sale{}
		{
			saleRouter := orderRouter.Group("sale")
			saleRouter.POST("lists", saleController.Lists) // 车辆出售订单列表
			saleRouter.POST("info", saleController.Info)   // 出售订单详情

			// 款项审核
			salePaymentAuditController := order.SalePaymentAudit{}
			{
				saleRouter.POST("payment/audit/lists", salePaymentAuditController.Lists)   // 款项审核列表
				saleRouter.POST("payment/audit/info", salePaymentAuditController.Info)     // 款项审核详情
				saleRouter.POST("payment/audit/adopt", salePaymentAuditController.Adopt)   // 审核通过
				saleRouter.POST("payment/audit/reject", salePaymentAuditController.Reject) // 审核驳回
			}
		}
		// 寄卖订单
		consignmentController := order.Consignment{}
		{
			orderRouter.POST("consignment/lists", consignmentController.Lists)     // 寄卖订单列表
			orderRouter.POST("consignment/info", consignmentController.Info)       // 寄卖订单详情
			orderRouter.POST("consignment/cancel", consignmentController.Cancel)   // 寄卖订单取消
			orderRouter.POST("consignment/payment", consignmentController.Payment) // 打款
		}
		// 车商寄卖订单
		dealerConsignmentController := order.DealerConsignment{}
		{
			orderRouter.POST("dealer/consignment/lists", dealerConsignmentController.Lists) // 车身寄卖列表
		}
		// 叫车订单
		callCarController := order.CallCar{}
		{
			orderRouter.POST("call/car/lists", callCarController.Lists) // 叫车订单列表
			orderRouter.POST("call/car/info", callCarController.Info)   // 订单详情

			// 退款审核
			callCarRefundController := order.CallCarRefund{}
			{
				orderRouter.POST("call/car/refund/lists", callCarRefundController.Lists)   // 叫车退款审核
				orderRouter.POST("call/car/refund/info", callCarRefundController.Info)     // 订单详情
				orderRouter.POST("call/car/refund/adopt", callCarRefundController.Adopt)   // 审核通过
				orderRouter.POST("call/car/refund/reject", callCarRefundController.Reject) // 审核驳回
				//orderRouter.POST("refund", callCarRefundController.Refund)                 // 退款测试
			}
		}
	}
	// app相关
	appRouter := router.Group("app", middleware.ManageAuth)
	{
		// 意见反馈
		feedbackController := app.Feedback{}
		{
			appRouter.POST("feedback/lists", feedbackController.Lists)   // 意见列表
			appRouter.POST("feedback/info", feedbackController.Info)     // 详情
			appRouter.POST("feedback/delete", feedbackController.Delete) // 删除意见
		}
	}
	// 合同
	contractRouter := router.Group("contract", middleware.ManageAuth)
	{
		saleController := contract.Sale{}
		{
			contractRouter.POST("sale/lists", saleController.Lists) // 售车合同列表
		}
		consignmentController := contract.Consignment{}
		{
			contractRouter.POST("consignment/lists", consignmentController.Lists) // 寄卖合同
		}
		//purchaseController := contract.Purchase{}
		//{
		//    contractRouter.POST("purchase/lists", purchaseController.Lists) // 收购合同
		//}
		businessController := contract.Business{}
		{
			contractRouter.POST("business/lists", businessController.Lists) // 入驻商合同
		}
	}
}
